<?php

return [
    '🧑🏻‍❤‍💋‍🧑🏼' => 'atla: mogolo, mogolo, letlalo le lesweu, letlalo le le bosweu jo bo mo magareng',
    '🧑🏻‍❤‍💋‍🧑🏽' => 'atla: mogolo, mogolo, letlalo le lesweu, letlalo la mmala o o mo magareng',
    '🧑🏻‍❤‍💋‍🧑🏾' => 'atla: mogolo, mogolo, letlalo le lesweu, letlalo la mmala wa bontsho jo bo mo magareng',
    '🧑🏻‍❤‍💋‍🧑🏿' => 'atla: mogolo, mogolo, letlalo le lesweu, letlalo la mmala o montsho',
    '🧑🏼‍❤‍💋‍🧑🏻' => 'atla: mogolo, mogolo, letlalo le le bosweu jo bo mo magareng, letlalo le lesweu',
    '🧑🏼‍❤‍💋‍🧑🏽' => 'atla: mogolo, mogolo, letlalo le le bosweu jo bo mo magareng, letlalo la mmala o o mo magareng',
    '🧑🏼‍❤‍💋‍🧑🏾' => 'atla: mogolo, mogolo, letlalo le le bosweu jo bo mo magareng, letlalo la mmala wa bontsho jo bo mo magareng',
    '🧑🏼‍❤‍💋‍🧑🏿' => 'atla: mogolo, mogolo, letlalo le le bosweu jo bo mo magareng, letlalo la mmala o montsho',
    '🧑🏽‍❤‍💋‍🧑🏻' => 'atla: mogolo, mogolo, letlalo la mmala o o mo magareng, letlalo le lesweu',
    '🧑🏽‍❤‍💋‍🧑🏼' => 'atla: mogolo, mogolo, letlalo la mmala o o mo magareng, letlalo le le bosweu jo bo mo magareng',
    '🧑🏽‍❤‍💋‍🧑🏾' => 'atla: mogolo, mogolo, letlalo la mmala o o mo magareng, letlalo la mmala wa bontsho jo bo mo magareng',
    '🧑🏽‍❤‍💋‍🧑🏿' => 'atla: mogolo, mogolo, letlalo la mmala o o mo magareng, letlalo la mmala o montsho',
    '🧑🏾‍❤‍💋‍🧑🏻' => 'atla: mogolo, mogolo, letlalo la mmala wa bontsho jo bo mo magareng, letlalo le lesweu',
    '🧑🏾‍❤‍💋‍🧑🏼' => 'atla: mogolo, mogolo, letlalo la mmala wa bontsho jo bo mo magareng, letlalo le le bosweu jo bo mo magareng',
    '🧑🏾‍❤‍💋‍🧑🏽' => 'atla: mogolo, mogolo, letlalo la mmala wa bontsho jo bo mo magareng, letlalo la mmala o o mo magareng',
    '🧑🏾‍❤‍💋‍🧑🏿' => 'atla: mogolo, mogolo, letlalo la mmala wa bontsho jo bo mo magareng, letlalo la mmala o montsho',
    '🧑🏿‍❤‍💋‍🧑🏻' => 'atla: mogolo, mogolo, letlalo la mmala o montsho, letlalo le lesweu',
    '🧑🏿‍❤‍💋‍🧑🏼' => 'atla: mogolo, mogolo, letlalo la mmala o montsho, letlalo le le bosweu jo bo mo magareng',
    '🧑🏿‍❤‍💋‍🧑🏽' => 'atla: mogolo, mogolo, letlalo la mmala o montsho, letlalo la mmala o o mo magareng',
    '🧑🏿‍❤‍💋‍🧑🏾' => 'atla: mogolo, mogolo, letlalo la mmala o montsho, letlalo la mmala wa bontsho jo bo mo magareng',
    '👨🏻‍❤‍💋‍👨🏻' => 'atla: monna, monna, letlalo le lesweu',
    '👨🏻‍❤‍💋‍👨🏼' => 'atla: monna, monna, letlalo le lesweu, letlalo le le bosweu jo bo mo magareng',
    '👨🏻‍❤‍💋‍👨🏽' => 'atla: monna, monna, letlalo le lesweu, letlalo la mmala o o mo magareng',
    '👨🏻‍❤‍💋‍👨🏾' => 'atla: monna, monna, letlalo le lesweu, letlalo la mmala wa bontsho jo bo mo magareng',
    '👨🏻‍❤‍💋‍👨🏿' => 'atla: monna, monna, letlalo le lesweu, letlalo la mmala o montsho',
    '👨🏼‍❤‍💋‍👨🏻' => 'atla: monna, monna, letlalo le le bosweu jo bo mo magareng, letlalo le lesweu',
    '👨🏼‍❤‍💋‍👨🏼' => 'atla: monna, monna, letlalo le le bosweu jo bo mo magareng',
    '👨🏼‍❤‍💋‍👨🏽' => 'atla: monna, monna, letlalo le le bosweu jo bo mo magareng, letlalo la mmala o o mo magareng',
    '👨🏼‍❤‍💋‍👨🏾' => 'atla: monna, monna, letlalo le le bosweu jo bo mo magareng, letlalo la mmala wa bontsho jo bo mo magareng',
    '👨🏼‍❤‍💋‍👨🏿' => 'atla: monna, monna, letlalo le le bosweu jo bo mo magareng, letlalo la mmala o montsho',
    '👨🏽‍❤‍💋‍👨🏻' => 'atla: monna, monna, letlalo la mmala o o mo magareng, letlalo le lesweu',
    '👨🏽‍❤‍💋‍👨🏼' => 'atla: monna, monna, letlalo la mmala o o mo magareng, letlalo le le bosweu jo bo mo magareng',
    '👨🏽‍❤‍💋‍👨🏽' => 'atla: monna, monna, letlalo la mmala o o mo magareng',
    '👨🏽‍❤‍💋‍👨🏾' => 'atla: monna, monna, letlalo la mmala o o mo magareng, letlalo la mmala wa bontsho jo bo mo magareng',
    '👨🏽‍❤‍💋‍👨🏿' => 'atla: monna, monna, letlalo la mmala o o mo magareng, letlalo la mmala o montsho',
    '👨🏾‍❤‍💋‍👨🏻' => 'atla: monna, monna, letlalo la mmala wa bontsho jo bo mo magareng, letlalo le lesweu',
    '👨🏾‍❤‍💋‍👨🏼' => 'atla: monna, monna, letlalo la mmala wa bontsho jo bo mo magareng, letlalo le le bosweu jo bo mo magareng',
    '👨🏾‍❤‍💋‍👨🏽' => 'atla: monna, monna, letlalo la mmala wa bontsho jo bo mo magareng, letlalo la mmala o o mo magareng',
    '👨🏾‍❤‍💋‍👨🏾' => 'atla: monna, monna, letlalo la mmala wa bontsho jo bo mo magareng',
    '👨🏾‍❤‍💋‍👨🏿' => 'atla: monna, monna, letlalo la mmala wa bontsho jo bo mo magareng, letlalo la mmala o montsho',
    '👨🏿‍❤‍💋‍👨🏻' => 'atla: monna, monna, letlalo la mmala o montsho, letlalo le lesweu',
    '👨🏿‍❤‍💋‍👨🏼' => 'atla: monna, monna, letlalo la mmala o montsho, letlalo le le bosweu jo bo mo magareng',
    '👨🏿‍❤‍💋‍👨🏽' => 'atla: monna, monna, letlalo la mmala o montsho, letlalo la mmala o o mo magareng',
    '👨🏿‍❤‍💋‍👨🏾' => 'atla: monna, monna, letlalo la mmala o montsho, letlalo la mmala wa bontsho jo bo mo magareng',
    '👨🏿‍❤‍💋‍👨🏿' => 'atla: monna, monna, letlalo la mmala o montsho',
    '👩🏻‍❤‍💋‍👨🏻' => 'atla: mosadi, monna, letlalo le lesweu',
    '👩🏻‍❤‍💋‍👨🏼' => 'atla: mosadi, monna, letlalo le lesweu, letlalo le le bosweu jo bo mo magareng',
    '👩🏻‍❤‍💋‍👨🏽' => 'atla: mosadi, monna, letlalo le lesweu, letlalo la mmala o o mo magareng',
    '👩🏻‍❤‍💋‍👨🏾' => 'atla: mosadi, monna, letlalo le lesweu, letlalo la mmala wa bontsho jo bo mo magareng',
    '👩🏻‍❤‍💋‍👨🏿' => 'atla: mosadi, monna, letlalo le lesweu, letlalo la mmala o montsho',
    '👩🏼‍❤‍💋‍👨🏻' => 'atla: mosadi, monna, letlalo le le bosweu jo bo mo magareng, letlalo le lesweu',
    '👩🏼‍❤‍💋‍👨🏼' => 'atla: mosadi, monna, letlalo le le bosweu jo bo mo magareng',
    '👩🏼‍❤‍💋‍👨🏽' => 'atla: mosadi, monna, letlalo le le bosweu jo bo mo magareng, letlalo la mmala o o mo magareng',
    '👩🏼‍❤‍💋‍👨🏾' => 'atla: mosadi, monna, letlalo le le bosweu jo bo mo magareng, letlalo la mmala wa bontsho jo bo mo magareng',
    '👩🏼‍❤‍💋‍👨🏿' => 'atla: mosadi, monna, letlalo le le bosweu jo bo mo magareng, letlalo la mmala o montsho',
    '👩🏽‍❤‍💋‍👨🏻' => 'atla: mosadi, monna, letlalo la mmala o o mo magareng, letlalo le lesweu',
    '👩🏽‍❤‍💋‍👨🏼' => 'atla: mosadi, monna, letlalo la mmala o o mo magareng, letlalo le le bosweu jo bo mo magareng',
    '👩🏽‍❤‍💋‍👨🏽' => 'atla: mosadi, monna, letlalo la mmala o o mo magareng',
    '👩🏽‍❤‍💋‍👨🏾' => 'atla: mosadi, monna, letlalo la mmala o o mo magareng, letlalo la mmala wa bontsho jo bo mo magareng',
    '👩🏽‍❤‍💋‍👨🏿' => 'atla: mosadi, monna, letlalo la mmala o o mo magareng, letlalo la mmala o montsho',
    '👩🏾‍❤‍💋‍👨🏻' => 'atla: mosadi, monna, letlalo la mmala wa bontsho jo bo mo magareng, letlalo le lesweu',
    '👩🏾‍❤‍💋‍👨🏼' => 'atla: mosadi, monna, letlalo la mmala wa bontsho jo bo mo magareng, letlalo le le bosweu jo bo mo magareng',
    '👩🏾‍❤‍💋‍👨🏽' => 'atla: mosadi, monna, letlalo la mmala wa bontsho jo bo mo magareng, letlalo la mmala o o mo magareng',
    '👩🏾‍❤‍💋‍👨🏾' => 'atla: mosadi, monna, letlalo la mmala wa bontsho jo bo mo magareng',
    '👩🏾‍❤‍💋‍👨🏿' => 'atla: mosadi, monna, letlalo la mmala wa bontsho jo bo mo magareng, letlalo la mmala o montsho',
    '👩🏿‍❤‍💋‍👨🏻' => 'atla: mosadi, monna, letlalo la mmala o montsho, letlalo le lesweu',
    '👩🏿‍❤‍💋‍👨🏼' => 'atla: mosadi, monna, letlalo la mmala o montsho, letlalo le le bosweu jo bo mo magareng',
    '👩🏿‍❤‍💋‍👨🏽' => 'atla: mosadi, monna, letlalo la mmala o montsho, letlalo la mmala o o mo magareng',
    '👩🏿‍❤‍💋‍👨🏾' => 'atla: mosadi, monna, letlalo la mmala o montsho, letlalo la mmala wa bontsho jo bo mo magareng',
    '👩🏿‍❤‍💋‍👨🏿' => 'atla: mosadi, monna, letlalo la mmala o montsho',
    '👩🏻‍❤‍💋‍👩🏻' => 'atla: mosadi, mosadi, letlalo le lesweu',
    '👩🏻‍❤‍💋‍👩🏼' => 'atla: mosadi, mosadi, letlalo le lesweu, letlalo le le bosweu jo bo mo magareng',
    '👩🏻‍❤‍💋‍👩🏽' => 'atla: mosadi, mosadi, letlalo le lesweu, letlalo la mmala o o mo magareng',
    '👩🏻‍❤‍💋‍👩🏾' => 'atla: mosadi, mosadi, letlalo le lesweu, letlalo la mmala wa bontsho jo bo mo magareng',
    '👩🏻‍❤‍💋‍👩🏿' => 'atla: mosadi, mosadi, letlalo le lesweu, letlalo la mmala o montsho',
    '👩🏼‍❤‍💋‍👩🏻' => 'atla: mosadi, mosadi, letlalo le le bosweu jo bo mo magareng, letlalo le lesweu',
    '👩🏼‍❤‍💋‍👩🏼' => 'atla: mosadi, mosadi, letlalo le le bosweu jo bo mo magareng',
    '👩🏼‍❤‍💋‍👩🏽' => 'atla: mosadi, mosadi, letlalo le le bosweu jo bo mo magareng, letlalo la mmala o o mo magareng',
    '👩🏼‍❤‍💋‍👩🏾' => 'atla: mosadi, mosadi, letlalo le le bosweu jo bo mo magareng, letlalo la mmala wa bontsho jo bo mo magareng',
    '👩🏼‍❤‍💋‍👩🏿' => 'atla: mosadi, mosadi, letlalo le le bosweu jo bo mo magareng, letlalo la mmala o montsho',
    '👩🏽‍❤‍💋‍👩🏻' => 'atla: mosadi, mosadi, letlalo la mmala o o mo magareng, letlalo le lesweu',
    '👩🏽‍❤‍💋‍👩🏼' => 'atla: mosadi, mosadi, letlalo la mmala o o mo magareng, letlalo le le bosweu jo bo mo magareng',
    '👩🏽‍❤‍💋‍👩🏽' => 'atla: mosadi, mosadi, letlalo la mmala o o mo magareng',
    '👩🏽‍❤‍💋‍👩🏾' => 'atla: mosadi, mosadi, letlalo la mmala o o mo magareng, letlalo la mmala wa bontsho jo bo mo magareng',
    '👩🏽‍❤‍💋‍👩🏿' => 'atla: mosadi, mosadi, letlalo la mmala o o mo magareng, letlalo la mmala o montsho',
    '👩🏾‍❤‍💋‍👩🏻' => 'atla: mosadi, mosadi, letlalo la mmala wa bontsho jo bo mo magareng, letlalo le lesweu',
    '👩🏾‍❤‍💋‍👩🏼' => 'atla: mosadi, mosadi, letlalo la mmala wa bontsho jo bo mo magareng, letlalo le le bosweu jo bo mo magareng',
    '👩🏾‍❤‍💋‍👩🏽' => 'atla: mosadi, mosadi, letlalo la mmala wa bontsho jo bo mo magareng, letlalo la mmala o o mo magareng',
    '👩🏾‍❤‍💋‍👩🏾' => 'atla: mosadi, mosadi, letlalo la mmala wa bontsho jo bo mo magareng',
    '👩🏾‍❤‍💋‍👩🏿' => 'atla: mosadi, mosadi, letlalo la mmala wa bontsho jo bo mo magareng, letlalo la mmala o montsho',
    '👩🏿‍❤‍💋‍👩🏻' => 'atla: mosadi, mosadi, letlalo la mmala o montsho, letlalo le lesweu',
    '👩🏿‍❤‍💋‍👩🏼' => 'atla: mosadi, mosadi, letlalo la mmala o montsho, letlalo le le bosweu jo bo mo magareng',
    '👩🏿‍❤‍💋‍👩🏽' => 'atla: mosadi, mosadi, letlalo la mmala o montsho, letlalo la mmala o o mo magareng',
    '👩🏿‍❤‍💋‍👩🏾' => 'atla: mosadi, mosadi, letlalo la mmala o montsho, letlalo la mmala wa bontsho jo bo mo magareng',
    '👩🏿‍❤‍💋‍👩🏿' => 'atla: mosadi, mosadi, letlalo la mmala o montsho',
    '🧑🏻‍🫯‍🧑🏼' => 'batho ba ba lwang ka go mekamekana: letlalo le lesweu, letlalo le le bosweu jo bo mo magareng',
    '🧑🏻‍🫯‍🧑🏽' => 'batho ba ba lwang ka go mekamekana: letlalo le lesweu, letlalo la mmala o o mo magareng',
    '🧑🏻‍🫯‍🧑🏾' => 'batho ba ba lwang ka go mekamekana: letlalo le lesweu, letlalo la mmala wa bontsho jo bo mo magareng',
    '🧑🏻‍🫯‍🧑🏿' => 'batho ba ba lwang ka go mekamekana: letlalo le lesweu, letlalo la mmala o montsho',
    '🧑🏼‍🫯‍🧑🏻' => 'batho ba ba lwang ka go mekamekana: letlalo le le bosweu jo bo mo magareng, letlalo le lesweu',
    '🧑🏼‍🫯‍🧑🏽' => 'batho ba ba lwang ka go mekamekana: letlalo le le bosweu jo bo mo magareng, letlalo la mmala o o mo magareng',
    '🧑🏼‍🫯‍🧑🏾' => 'batho ba ba lwang ka go mekamekana: letlalo le le bosweu jo bo mo magareng, letlalo la mmala wa bontsho jo bo mo magareng',
    '🧑🏼‍🫯‍🧑🏿' => 'batho ba ba lwang ka go mekamekana: letlalo le le bosweu jo bo mo magareng, letlalo la mmala o montsho',
    '🧑🏽‍🫯‍🧑🏻' => 'batho ba ba lwang ka go mekamekana: letlalo la mmala o o mo magareng, letlalo le lesweu',
    '🧑🏽‍🫯‍🧑🏼' => 'batho ba ba lwang ka go mekamekana: letlalo la mmala o o mo magareng, letlalo le le bosweu jo bo mo magareng',
    '🧑🏽‍🫯‍🧑🏾' => 'batho ba ba lwang ka go mekamekana: letlalo la mmala o o mo magareng, letlalo la mmala wa bontsho jo bo mo magareng',
    '🧑🏽‍🫯‍🧑🏿' => 'batho ba ba lwang ka go mekamekana: letlalo la mmala o o mo magareng, letlalo la mmala o montsho',
    '🧑🏾‍🫯‍🧑🏻' => 'batho ba ba lwang ka go mekamekana: letlalo la mmala wa bontsho jo bo mo magareng, letlalo le lesweu',
    '🧑🏾‍🫯‍🧑🏼' => 'batho ba ba lwang ka go mekamekana: letlalo la mmala wa bontsho jo bo mo magareng, letlalo le le bosweu jo bo mo magareng',
    '🧑🏾‍🫯‍🧑🏽' => 'batho ba ba lwang ka go mekamekana: letlalo la mmala wa bontsho jo bo mo magareng, letlalo la mmala o o mo magareng',
    '🧑🏾‍🫯‍🧑🏿' => 'batho ba ba lwang ka go mekamekana: letlalo la mmala wa bontsho jo bo mo magareng, letlalo la mmala o montsho',
    '🧑🏿‍🫯‍🧑🏻' => 'batho ba ba lwang ka go mekamekana: letlalo la mmala o montsho, letlalo le lesweu',
    '🧑🏿‍🫯‍🧑🏼' => 'batho ba ba lwang ka go mekamekana: letlalo la mmala o montsho, letlalo le le bosweu jo bo mo magareng',
    '🧑🏿‍🫯‍🧑🏽' => 'batho ba ba lwang ka go mekamekana: letlalo la mmala o montsho, letlalo la mmala o o mo magareng',
    '🧑🏿‍🫯‍🧑🏾' => 'batho ba ba lwang ka go mekamekana: letlalo la mmala o montsho, letlalo la mmala wa bontsho jo bo mo magareng',
    '🧑🏻‍❤‍🧑🏼' => 'bobedi ka pelo: mogolo, mogolo, letlalo le lesweu, letlalo le le bosweu jo bo mo magareng',
    '🧑🏻‍❤‍🧑🏽' => 'bobedi ka pelo: mogolo, mogolo, letlalo le lesweu, letlalo la mmala o o mo magareng',
    '🧑🏻‍❤‍🧑🏾' => 'bobedi ka pelo: mogolo, mogolo, letlalo le lesweu, letlalo la mmala wa bontsho jo bo mo magareng',
    '🧑🏻‍❤‍🧑🏿' => 'bobedi ka pelo: mogolo, mogolo, letlalo le lesweu, letlalo la mmala o montsho',
    '🧑🏼‍❤‍🧑🏻' => 'bobedi ka pelo: mogolo, mogolo, letlalo le le bosweu jo bo mo magareng, letlalo le lesweu',
    '🧑🏼‍❤‍🧑🏽' => 'bobedi ka pelo: mogolo, mogolo, letlalo le le bosweu jo bo mo magareng, letlalo la mmala o o mo magareng',
    '🧑🏼‍❤‍🧑🏾' => 'bobedi ka pelo: mogolo, mogolo, letlalo le le bosweu jo bo mo magareng, letlalo la mmala wa bontsho jo bo mo magareng',
    '🧑🏼‍❤‍🧑🏿' => 'bobedi ka pelo: mogolo, mogolo, letlalo le le bosweu jo bo mo magareng, letlalo la mmala o montsho',
    '🧑🏽‍❤‍🧑🏻' => 'bobedi ka pelo: mogolo, mogolo, letlalo la mmala o o mo magareng, letlalo le lesweu',
    '🧑🏽‍❤‍🧑🏼' => 'bobedi ka pelo: mogolo, mogolo, letlalo la mmala o o mo magareng, letlalo le le bosweu jo bo mo magareng',
    '🧑🏽‍❤‍🧑🏾' => 'bobedi ka pelo: mogolo, mogolo, letlalo la mmala o o mo magareng, letlalo la mmala wa bontsho jo bo mo magareng',
    '🧑🏽‍❤‍🧑🏿' => 'bobedi ka pelo: mogolo, mogolo, letlalo la mmala o o mo magareng, letlalo la mmala o montsho',
    '🧑🏾‍❤‍🧑🏻' => 'bobedi ka pelo: mogolo, mogolo, letlalo la mmala wa bontsho jo bo mo magareng, letlalo le lesweu',
    '🧑🏾‍❤‍🧑🏼' => 'bobedi ka pelo: mogolo, mogolo, letlalo la mmala wa bontsho jo bo mo magareng, letlalo le le bosweu jo bo mo magareng',
    '🧑🏾‍❤‍🧑🏽' => 'bobedi ka pelo: mogolo, mogolo, letlalo la mmala wa bontsho jo bo mo magareng, letlalo la mmala o o mo magareng',
    '🧑🏾‍❤‍🧑🏿' => 'bobedi ka pelo: mogolo, mogolo, letlalo la mmala wa bontsho jo bo mo magareng, letlalo la mmala o montsho',
    '🧑🏿‍❤‍🧑🏻' => 'bobedi ka pelo: mogolo, mogolo, letlalo la mmala o montsho, letlalo le lesweu',
    '🧑🏿‍❤‍🧑🏼' => 'bobedi ka pelo: mogolo, mogolo, letlalo la mmala o montsho, letlalo le le bosweu jo bo mo magareng',
    '🧑🏿‍❤‍🧑🏽' => 'bobedi ka pelo: mogolo, mogolo, letlalo la mmala o montsho, letlalo la mmala o o mo magareng',
    '🧑🏿‍❤‍🧑🏾' => 'bobedi ka pelo: mogolo, mogolo, letlalo la mmala o montsho, letlalo la mmala wa bontsho jo bo mo magareng',
    '🧑🏻‍🐰‍🧑🏼' => 'batho ka ditsebe tsa mmutla mo moletlong: letlalo le lesweu, letlalo le le bosweu jo bo mo magareng',
    '🧑🏻‍🐰‍🧑🏽' => 'batho ka ditsebe tsa mmutla mo moletlong: letlalo le lesweu, letlalo la mmala o o mo magareng',
    '🧑🏻‍🐰‍🧑🏾' => 'batho ka ditsebe tsa mmutla mo moletlong: letlalo le lesweu, letlalo la mmala wa bontsho jo bo mo magareng',
    '🧑🏻‍🐰‍🧑🏿' => 'batho ka ditsebe tsa mmutla mo moletlong: letlalo le lesweu, letlalo la mmala o montsho',
    '🧑🏼‍🐰‍🧑🏻' => 'batho ka ditsebe tsa mmutla mo moletlong: letlalo le le bosweu jo bo mo magareng, letlalo le lesweu',
    '🧑🏼‍🐰‍🧑🏽' => 'batho ka ditsebe tsa mmutla mo moletlong: letlalo le le bosweu jo bo mo magareng, letlalo la mmala o o mo magareng',
    '🧑🏼‍🐰‍🧑🏾' => 'batho ka ditsebe tsa mmutla mo moletlong: letlalo le le bosweu jo bo mo magareng, letlalo la mmala wa bontsho jo bo mo magareng',
    '🧑🏼‍🐰‍🧑🏿' => 'batho ka ditsebe tsa mmutla mo moletlong: letlalo le le bosweu jo bo mo magareng, letlalo la mmala o montsho',
    '🧑🏽‍🐰‍🧑🏻' => 'batho ka ditsebe tsa mmutla mo moletlong: letlalo la mmala o o mo magareng, letlalo le lesweu',
    '🧑🏽‍🐰‍🧑🏼' => 'batho ka ditsebe tsa mmutla mo moletlong: letlalo la mmala o o mo magareng, letlalo le le bosweu jo bo mo magareng',
    '🧑🏽‍🐰‍🧑🏾' => 'batho ka ditsebe tsa mmutla mo moletlong: letlalo la mmala o o mo magareng, letlalo la mmala wa bontsho jo bo mo magareng',
    '🧑🏽‍🐰‍🧑🏿' => 'batho ka ditsebe tsa mmutla mo moletlong: letlalo la mmala o o mo magareng, letlalo la mmala o montsho',
    '🧑🏾‍🐰‍🧑🏻' => 'batho ka ditsebe tsa mmutla mo moletlong: letlalo la mmala wa bontsho jo bo mo magareng, letlalo le lesweu',
    '🧑🏾‍🐰‍🧑🏼' => 'batho ka ditsebe tsa mmutla mo moletlong: letlalo la mmala wa bontsho jo bo mo magareng, letlalo le le bosweu jo bo mo magareng',
    '🧑🏾‍🐰‍🧑🏽' => 'batho ka ditsebe tsa mmutla mo moletlong: letlalo la mmala wa bontsho jo bo mo magareng, letlalo la mmala o o mo magareng',
    '🧑🏾‍🐰‍🧑🏿' => 'batho ka ditsebe tsa mmutla mo moletlong: letlalo la mmala wa bontsho jo bo mo magareng, letlalo la mmala o montsho',
    '🧑🏿‍🐰‍🧑🏻' => 'batho ka ditsebe tsa mmutla mo moletlong: letlalo la mmala o montsho, letlalo le lesweu',
    '🧑🏿‍🐰‍🧑🏼' => 'batho ka ditsebe tsa mmutla mo moletlong: letlalo la mmala o montsho, letlalo le le bosweu jo bo mo magareng',
    '🧑🏿‍🐰‍🧑🏽' => 'batho ka ditsebe tsa mmutla mo moletlong: letlalo la mmala o montsho, letlalo la mmala o o mo magareng',
    '🧑🏿‍🐰‍🧑🏾' => 'batho ka ditsebe tsa mmutla mo moletlong: letlalo la mmala o montsho, letlalo la mmala wa bontsho jo bo mo magareng',
    '👨🏻‍🫯‍👨🏼' => 'banna ba ba lwang ka go mekamekana: letlalo le lesweu, letlalo le le bosweu jo bo mo magareng',
    '👨🏻‍🫯‍👨🏽' => 'banna ba ba lwang ka go mekamekana: letlalo le lesweu, letlalo la mmala o o mo magareng',
    '👨🏻‍🫯‍👨🏾' => 'banna ba ba lwang ka go mekamekana: letlalo le lesweu, letlalo la mmala wa bontsho jo bo mo magareng',
    '👨🏻‍🫯‍👨🏿' => 'banna ba ba lwang ka go mekamekana: letlalo le lesweu, letlalo la mmala o montsho',
    '👨🏼‍🫯‍👨🏻' => 'banna ba ba lwang ka go mekamekana: letlalo le le bosweu jo bo mo magareng, letlalo le lesweu',
    '👨🏼‍🫯‍👨🏽' => 'banna ba ba lwang ka go mekamekana: letlalo le le bosweu jo bo mo magareng, letlalo la mmala o o mo magareng',
    '👨🏼‍🫯‍👨🏾' => 'banna ba ba lwang ka go mekamekana: letlalo le le bosweu jo bo mo magareng, letlalo la mmala wa bontsho jo bo mo magareng',
    '👨🏼‍🫯‍👨🏿' => 'banna ba ba lwang ka go mekamekana: letlalo le le bosweu jo bo mo magareng, letlalo la mmala o montsho',
    '👨🏽‍🫯‍👨🏻' => 'banna ba ba lwang ka go mekamekana: letlalo la mmala o o mo magareng, letlalo le lesweu',
    '👨🏽‍🫯‍👨🏼' => 'banna ba ba lwang ka go mekamekana: letlalo la mmala o o mo magareng, letlalo le le bosweu jo bo mo magareng',
    '👨🏽‍🫯‍👨🏾' => 'banna ba ba lwang ka go mekamekana: letlalo la mmala o o mo magareng, letlalo la mmala wa bontsho jo bo mo magareng',
    '👨🏽‍🫯‍👨🏿' => 'banna ba ba lwang ka go mekamekana: letlalo la mmala o o mo magareng, letlalo la mmala o montsho',
    '👨🏾‍🫯‍👨🏻' => 'banna ba ba lwang ka go mekamekana: letlalo la mmala wa bontsho jo bo mo magareng, letlalo le lesweu',
    '👨🏾‍🫯‍👨🏼' => 'banna ba ba lwang ka go mekamekana: letlalo la mmala wa bontsho jo bo mo magareng, letlalo le le bosweu jo bo mo magareng',
    '👨🏾‍🫯‍👨🏽' => 'banna ba ba lwang ka go mekamekana: letlalo la mmala wa bontsho jo bo mo magareng, letlalo la mmala o o mo magareng',
    '👨🏾‍🫯‍👨🏿' => 'banna ba ba lwang ka go mekamekana: letlalo la mmala wa bontsho jo bo mo magareng, letlalo la mmala o montsho',
    '👨🏿‍🫯‍👨🏻' => 'banna ba ba lwang ka go mekamekana: letlalo la mmala o montsho, letlalo le lesweu',
    '👨🏿‍🫯‍👨🏼' => 'banna ba ba lwang ka go mekamekana: letlalo la mmala o montsho, letlalo le le bosweu jo bo mo magareng',
    '👨🏿‍🫯‍👨🏽' => 'banna ba ba lwang ka go mekamekana: letlalo la mmala o montsho, letlalo la mmala o o mo magareng',
    '👨🏿‍🫯‍👨🏾' => 'banna ba ba lwang ka go mekamekana: letlalo la mmala o montsho, letlalo la mmala wa bontsho jo bo mo magareng',
    '👨🏻‍❤‍👨🏻' => 'bobedi ka pelo: monna, monna, letlalo le lesweu',
    '👨🏻‍❤‍👨🏼' => 'bobedi ka pelo: monna, monna, letlalo le lesweu, letlalo le le bosweu jo bo mo magareng',
    '👨🏻‍❤‍👨🏽' => 'bobedi ka pelo: monna, monna, letlalo le lesweu, letlalo la mmala o o mo magareng',
    '👨🏻‍❤‍👨🏾' => 'bobedi ka pelo: monna, monna, letlalo le lesweu, letlalo la mmala wa bontsho jo bo mo magareng',
    '👨🏻‍❤‍👨🏿' => 'bobedi ka pelo: monna, monna, letlalo le lesweu, letlalo la mmala o montsho',
    '👨🏼‍❤‍👨🏻' => 'bobedi ka pelo: monna, monna, letlalo le le bosweu jo bo mo magareng, letlalo le lesweu',
    '👨🏼‍❤‍👨🏼' => 'bobedi ka pelo: monna, monna, letlalo le le bosweu jo bo mo magareng',
    '👨🏼‍❤‍👨🏽' => 'bobedi ka pelo: monna, monna, letlalo le le bosweu jo bo mo magareng, letlalo la mmala o o mo magareng',
    '👨🏼‍❤‍👨🏾' => 'bobedi ka pelo: monna, monna, letlalo le le bosweu jo bo mo magareng, letlalo la mmala wa bontsho jo bo mo magareng',
    '👨🏼‍❤‍👨🏿' => 'bobedi ka pelo: monna, monna, letlalo le le bosweu jo bo mo magareng, letlalo la mmala o montsho',
    '👨🏽‍❤‍👨🏻' => 'bobedi ka pelo: monna, monna, letlalo la mmala o o mo magareng, letlalo le lesweu',
    '👨🏽‍❤‍👨🏼' => 'bobedi ka pelo: monna, monna, letlalo la mmala o o mo magareng, letlalo le le bosweu jo bo mo magareng',
    '👨🏽‍❤‍👨🏽' => 'bobedi ka pelo: monna, monna, letlalo la mmala o o mo magareng',
    '👨🏽‍❤‍👨🏾' => 'bobedi ka pelo: monna, monna, letlalo la mmala o o mo magareng, letlalo la mmala wa bontsho jo bo mo magareng',
    '👨🏽‍❤‍👨🏿' => 'bobedi ka pelo: monna, monna, letlalo la mmala o o mo magareng, letlalo la mmala o montsho',
    '👨🏾‍❤‍👨🏻' => 'bobedi ka pelo: monna, monna, letlalo la mmala wa bontsho jo bo mo magareng, letlalo le lesweu',
    '👨🏾‍❤‍👨🏼' => 'bobedi ka pelo: monna, monna, letlalo la mmala wa bontsho jo bo mo magareng, letlalo le le bosweu jo bo mo magareng',
    '👨🏾‍❤‍👨🏽' => 'bobedi ka pelo: monna, monna, letlalo la mmala wa bontsho jo bo mo magareng, letlalo la mmala o o mo magareng',
    '👨🏾‍❤‍👨🏾' => 'bobedi ka pelo: monna, monna, letlalo la mmala wa bontsho jo bo mo magareng',
    '👨🏾‍❤‍👨🏿' => 'bobedi ka pelo: monna, monna, letlalo la mmala wa bontsho jo bo mo magareng, letlalo la mmala o montsho',
    '👨🏿‍❤‍👨🏻' => 'bobedi ka pelo: monna, monna, letlalo la mmala o montsho, letlalo le lesweu',
    '👨🏿‍❤‍👨🏼' => 'bobedi ka pelo: monna, monna, letlalo la mmala o montsho, letlalo le le bosweu jo bo mo magareng',
    '👨🏿‍❤‍👨🏽' => 'bobedi ka pelo: monna, monna, letlalo la mmala o montsho, letlalo la mmala o o mo magareng',
    '👨🏿‍❤‍👨🏾' => 'bobedi ka pelo: monna, monna, letlalo la mmala o montsho, letlalo la mmala wa bontsho jo bo mo magareng',
    '👨🏿‍❤‍👨🏿' => 'bobedi ka pelo: monna, monna, letlalo la mmala o montsho',
    '👨🏻‍🐰‍👨🏼' => 'banna ka ditsebe tsa mmutla mo moletlong: letlalo le lesweu, letlalo le le bosweu jo bo mo magareng',
    '👨🏻‍🐰‍👨🏽' => 'banna ka ditsebe tsa mmutla mo moletlong: letlalo le lesweu, letlalo la mmala o o mo magareng',
    '👨🏻‍🐰‍👨🏾' => 'banna ka ditsebe tsa mmutla mo moletlong: letlalo le lesweu, letlalo la mmala wa bontsho jo bo mo magareng',
    '👨🏻‍🐰‍👨🏿' => 'banna ka ditsebe tsa mmutla mo moletlong: letlalo le lesweu, letlalo la mmala o montsho',
    '👨🏼‍🐰‍👨🏻' => 'banna ka ditsebe tsa mmutla mo moletlong: letlalo le le bosweu jo bo mo magareng, letlalo le lesweu',
    '👨🏼‍🐰‍👨🏽' => 'banna ka ditsebe tsa mmutla mo moletlong: letlalo le le bosweu jo bo mo magareng, letlalo la mmala o o mo magareng',
    '👨🏼‍🐰‍👨🏾' => 'banna ka ditsebe tsa mmutla mo moletlong: letlalo le le bosweu jo bo mo magareng, letlalo la mmala wa bontsho jo bo mo magareng',
    '👨🏼‍🐰‍👨🏿' => 'banna ka ditsebe tsa mmutla mo moletlong: letlalo le le bosweu jo bo mo magareng, letlalo la mmala o montsho',
    '👨🏽‍🐰‍👨🏻' => 'banna ka ditsebe tsa mmutla mo moletlong: letlalo la mmala o o mo magareng, letlalo le lesweu',
    '👨🏽‍🐰‍👨🏼' => 'banna ka ditsebe tsa mmutla mo moletlong: letlalo la mmala o o mo magareng, letlalo le le bosweu jo bo mo magareng',
    '👨🏽‍🐰‍👨🏾' => 'banna ka ditsebe tsa mmutla mo moletlong: letlalo la mmala o o mo magareng, letlalo la mmala wa bontsho jo bo mo magareng',
    '👨🏽‍🐰‍👨🏿' => 'banna ka ditsebe tsa mmutla mo moletlong: letlalo la mmala o o mo magareng, letlalo la mmala o montsho',
    '👨🏾‍🐰‍👨🏻' => 'banna ka ditsebe tsa mmutla mo moletlong: letlalo la mmala wa bontsho jo bo mo magareng, letlalo le lesweu',
    '👨🏾‍🐰‍👨🏼' => 'banna ka ditsebe tsa mmutla mo moletlong: letlalo la mmala wa bontsho jo bo mo magareng, letlalo le le bosweu jo bo mo magareng',
    '👨🏾‍🐰‍👨🏽' => 'banna ka ditsebe tsa mmutla mo moletlong: letlalo la mmala wa bontsho jo bo mo magareng, letlalo la mmala o o mo magareng',
    '👨🏾‍🐰‍👨🏿' => 'banna ka ditsebe tsa mmutla mo moletlong: letlalo la mmala wa bontsho jo bo mo magareng, letlalo la mmala o montsho',
    '👨🏿‍🐰‍👨🏻' => 'banna ka ditsebe tsa mmutla mo moletlong: letlalo la mmala o montsho, letlalo le lesweu',
    '👨🏿‍🐰‍👨🏼' => 'banna ka ditsebe tsa mmutla mo moletlong: letlalo la mmala o montsho, letlalo le le bosweu jo bo mo magareng',
    '👨🏿‍🐰‍👨🏽' => 'banna ka ditsebe tsa mmutla mo moletlong: letlalo la mmala o montsho, letlalo la mmala o o mo magareng',
    '👨🏿‍🐰‍👨🏾' => 'banna ka ditsebe tsa mmutla mo moletlong: letlalo la mmala o montsho, letlalo la mmala wa bontsho jo bo mo magareng',
    '👩🏻‍🫯‍👩🏼' => 'basadi ba ba lwang ka go mekamekana: letlalo le lesweu, letlalo le le bosweu jo bo mo magareng',
    '👩🏻‍🫯‍👩🏽' => 'basadi ba ba lwang ka go mekamekana: letlalo le lesweu, letlalo la mmala o o mo magareng',
    '👩🏻‍🫯‍👩🏾' => 'basadi ba ba lwang ka go mekamekana: letlalo le lesweu, letlalo la mmala wa bontsho jo bo mo magareng',
    '👩🏻‍🫯‍👩🏿' => 'basadi ba ba lwang ka go mekamekana: letlalo le lesweu, letlalo la mmala o montsho',
    '👩🏼‍🫯‍👩🏻' => 'basadi ba ba lwang ka go mekamekana: letlalo le le bosweu jo bo mo magareng, letlalo le lesweu',
    '👩🏼‍🫯‍👩🏽' => 'basadi ba ba lwang ka go mekamekana: letlalo le le bosweu jo bo mo magareng, letlalo la mmala o o mo magareng',
    '👩🏼‍🫯‍👩🏾' => 'basadi ba ba lwang ka go mekamekana: letlalo le le bosweu jo bo mo magareng, letlalo la mmala wa bontsho jo bo mo magareng',
    '👩🏼‍🫯‍👩🏿' => 'basadi ba ba lwang ka go mekamekana: letlalo le le bosweu jo bo mo magareng, letlalo la mmala o montsho',
    '👩🏽‍🫯‍👩🏻' => 'basadi ba ba lwang ka go mekamekana: letlalo la mmala o o mo magareng, letlalo le lesweu',
    '👩🏽‍🫯‍👩🏼' => 'basadi ba ba lwang ka go mekamekana: letlalo la mmala o o mo magareng, letlalo le le bosweu jo bo mo magareng',
    '👩🏽‍🫯‍👩🏾' => 'basadi ba ba lwang ka go mekamekana: letlalo la mmala o o mo magareng, letlalo la mmala wa bontsho jo bo mo magareng',
    '👩🏽‍🫯‍👩🏿' => 'basadi ba ba lwang ka go mekamekana: letlalo la mmala o o mo magareng, letlalo la mmala o montsho',
    '👩🏾‍🫯‍👩🏻' => 'basadi ba ba lwang ka go mekamekana: letlalo la mmala wa bontsho jo bo mo magareng, letlalo le lesweu',
    '👩🏾‍🫯‍👩🏼' => 'basadi ba ba lwang ka go mekamekana: letlalo la mmala wa bontsho jo bo mo magareng, letlalo le le bosweu jo bo mo magareng',
    '👩🏾‍🫯‍👩🏽' => 'basadi ba ba lwang ka go mekamekana: letlalo la mmala wa bontsho jo bo mo magareng, letlalo la mmala o o mo magareng',
    '👩🏾‍🫯‍👩🏿' => 'basadi ba ba lwang ka go mekamekana: letlalo la mmala wa bontsho jo bo mo magareng, letlalo la mmala o montsho',
    '👩🏿‍🫯‍👩🏻' => 'basadi ba ba lwang ka go mekamekana: letlalo la mmala o montsho, letlalo le lesweu',
    '👩🏿‍🫯‍👩🏼' => 'basadi ba ba lwang ka go mekamekana: letlalo la mmala o montsho, letlalo le le bosweu jo bo mo magareng',
    '👩🏿‍🫯‍👩🏽' => 'basadi ba ba lwang ka go mekamekana: letlalo la mmala o montsho, letlalo la mmala o o mo magareng',
    '👩🏿‍🫯‍👩🏾' => 'basadi ba ba lwang ka go mekamekana: letlalo la mmala o montsho, letlalo la mmala wa bontsho jo bo mo magareng',
    '👩🏻‍❤‍👨🏻' => 'bobedi ka pelo: mosadi, monna, letlalo le lesweu',
    '👩🏻‍❤‍👨🏼' => 'bobedi ka pelo: mosadi, monna, letlalo le lesweu, letlalo le le bosweu jo bo mo magareng',
    '👩🏻‍❤‍👨🏽' => 'bobedi ka pelo: mosadi, monna, letlalo le lesweu, letlalo la mmala o o mo magareng',
    '👩🏻‍❤‍👨🏾' => 'bobedi ka pelo: mosadi, monna, letlalo le lesweu, letlalo la mmala wa bontsho jo bo mo magareng',
    '👩🏻‍❤‍👨🏿' => 'bobedi ka pelo: mosadi, monna, letlalo le lesweu, letlalo la mmala o montsho',
    '👩🏼‍❤‍👨🏻' => 'bobedi ka pelo: mosadi, monna, letlalo le le bosweu jo bo mo magareng, letlalo le lesweu',
    '👩🏼‍❤‍👨🏼' => 'bobedi ka pelo: mosadi, monna, letlalo le le bosweu jo bo mo magareng',
    '👩🏼‍❤‍👨🏽' => 'bobedi ka pelo: mosadi, monna, letlalo le le bosweu jo bo mo magareng, letlalo la mmala o o mo magareng',
    '👩🏼‍❤‍👨🏾' => 'bobedi ka pelo: mosadi, monna, letlalo le le bosweu jo bo mo magareng, letlalo la mmala wa bontsho jo bo mo magareng',
    '👩🏼‍❤‍👨🏿' => 'bobedi ka pelo: mosadi, monna, letlalo le le bosweu jo bo mo magareng, letlalo la mmala o montsho',
    '👩🏽‍❤‍👨🏻' => 'bobedi ka pelo: mosadi, monna, letlalo la mmala o o mo magareng, letlalo le lesweu',
    '👩🏽‍❤‍👨🏼' => 'bobedi ka pelo: mosadi, monna, letlalo la mmala o o mo magareng, letlalo le le bosweu jo bo mo magareng',
    '👩🏽‍❤‍👨🏽' => 'bobedi ka pelo: mosadi, monna, letlalo la mmala o o mo magareng',
    '👩🏽‍❤‍👨🏾' => 'bobedi ka pelo: mosadi, monna, letlalo la mmala o o mo magareng, letlalo la mmala wa bontsho jo bo mo magareng',
    '👩🏽‍❤‍👨🏿' => 'bobedi ka pelo: mosadi, monna, letlalo la mmala o o mo magareng, letlalo la mmala o montsho',
    '👩🏾‍❤‍👨🏻' => 'bobedi ka pelo: mosadi, monna, letlalo la mmala wa bontsho jo bo mo magareng, letlalo le lesweu',
    '👩🏾‍❤‍👨🏼' => 'bobedi ka pelo: mosadi, monna, letlalo la mmala wa bontsho jo bo mo magareng, letlalo le le bosweu jo bo mo magareng',
    '👩🏾‍❤‍👨🏽' => 'bobedi ka pelo: mosadi, monna, letlalo la mmala wa bontsho jo bo mo magareng, letlalo la mmala o o mo magareng',
    '👩🏾‍❤‍👨🏾' => 'bobedi ka pelo: mosadi, monna, letlalo la mmala wa bontsho jo bo mo magareng',
    '👩🏾‍❤‍👨🏿' => 'bobedi ka pelo: mosadi, monna, letlalo la mmala wa bontsho jo bo mo magareng, letlalo la mmala o montsho',
    '👩🏿‍❤‍👨🏻' => 'bobedi ka pelo: mosadi, monna, letlalo la mmala o montsho, letlalo le lesweu',
    '👩🏿‍❤‍👨🏼' => 'bobedi ka pelo: mosadi, monna, letlalo la mmala o montsho, letlalo le le bosweu jo bo mo magareng',
    '👩🏿‍❤‍👨🏽' => 'bobedi ka pelo: mosadi, monna, letlalo la mmala o montsho, letlalo la mmala o o mo magareng',
    '👩🏿‍❤‍👨🏾' => 'bobedi ka pelo: mosadi, monna, letlalo la mmala o montsho, letlalo la mmala wa bontsho jo bo mo magareng',
    '👩🏿‍❤‍👨🏿' => 'bobedi ka pelo: mosadi, monna, letlalo la mmala o montsho',
    '👩🏻‍❤‍👩🏻' => 'bobedi ka pelo: mosadi, mosadi, letlalo le lesweu',
    '👩🏻‍❤‍👩🏼' => 'bobedi ka pelo: mosadi, mosadi, letlalo le lesweu, letlalo le le bosweu jo bo mo magareng',
    '👩🏻‍❤‍👩🏽' => 'bobedi ka pelo: mosadi, mosadi, letlalo le lesweu, letlalo la mmala o o mo magareng',
    '👩🏻‍❤‍👩🏾' => 'bobedi ka pelo: mosadi, mosadi, letlalo le lesweu, letlalo la mmala wa bontsho jo bo mo magareng',
    '👩🏻‍❤‍👩🏿' => 'bobedi ka pelo: mosadi, mosadi, letlalo le lesweu, letlalo la mmala o montsho',
    '👩🏼‍❤‍👩🏻' => 'bobedi ka pelo: mosadi, mosadi, letlalo le le bosweu jo bo mo magareng, letlalo le lesweu',
    '👩🏼‍❤‍👩🏼' => 'bobedi ka pelo: mosadi, mosadi, letlalo le le bosweu jo bo mo magareng',
    '👩🏼‍❤‍👩🏽' => 'bobedi ka pelo: mosadi, mosadi, letlalo le le bosweu jo bo mo magareng, letlalo la mmala o o mo magareng',
    '👩🏼‍❤‍👩🏾' => 'bobedi ka pelo: mosadi, mosadi, letlalo le le bosweu jo bo mo magareng, letlalo la mmala wa bontsho jo bo mo magareng',
    '👩🏼‍❤‍👩🏿' => 'bobedi ka pelo: mosadi, mosadi, letlalo le le bosweu jo bo mo magareng, letlalo la mmala o montsho',
    '👩🏽‍❤‍👩🏻' => 'bobedi ka pelo: mosadi, mosadi, letlalo la mmala o o mo magareng, letlalo le lesweu',
    '👩🏽‍❤‍👩🏼' => 'bobedi ka pelo: mosadi, mosadi, letlalo la mmala o o mo magareng, letlalo le le bosweu jo bo mo magareng',
    '👩🏽‍❤‍👩🏽' => 'bobedi ka pelo: mosadi, mosadi, letlalo la mmala o o mo magareng',
    '👩🏽‍❤‍👩🏾' => 'bobedi ka pelo: mosadi, mosadi, letlalo la mmala o o mo magareng, letlalo la mmala wa bontsho jo bo mo magareng',
    '👩🏽‍❤‍👩🏿' => 'bobedi ka pelo: mosadi, mosadi, letlalo la mmala o o mo magareng, letlalo la mmala o montsho',
    '👩🏾‍❤‍👩🏻' => 'bobedi ka pelo: mosadi, mosadi, letlalo la mmala wa bontsho jo bo mo magareng, letlalo le lesweu',
    '👩🏾‍❤‍👩🏼' => 'bobedi ka pelo: mosadi, mosadi, letlalo la mmala wa bontsho jo bo mo magareng, letlalo le le bosweu jo bo mo magareng',
    '👩🏾‍❤‍👩🏽' => 'bobedi ka pelo: mosadi, mosadi, letlalo la mmala wa bontsho jo bo mo magareng, letlalo la mmala o o mo magareng',
    '👩🏾‍❤‍👩🏾' => 'bobedi ka pelo: mosadi, mosadi, letlalo la mmala wa bontsho jo bo mo magareng',
    '👩🏾‍❤‍👩🏿' => 'bobedi ka pelo: mosadi, mosadi, letlalo la mmala wa bontsho jo bo mo magareng, letlalo la mmala o montsho',
    '👩🏿‍❤‍👩🏻' => 'bobedi ka pelo: mosadi, mosadi, letlalo la mmala o montsho, letlalo le lesweu',
    '👩🏿‍❤‍👩🏼' => 'bobedi ka pelo: mosadi, mosadi, letlalo la mmala o montsho, letlalo le le bosweu jo bo mo magareng',
    '👩🏿‍❤‍👩🏽' => 'bobedi ka pelo: mosadi, mosadi, letlalo la mmala o montsho, letlalo la mmala o o mo magareng',
    '👩🏿‍❤‍👩🏾' => 'bobedi ka pelo: mosadi, mosadi, letlalo la mmala o montsho, letlalo la mmala wa bontsho jo bo mo magareng',
    '👩🏿‍❤‍👩🏿' => 'bobedi ka pelo: mosadi, mosadi, letlalo la mmala o montsho',
    '👩🏻‍🐰‍👩🏼' => 'basadi ka ditsebe tsa mmutla mo moletlong: letlalo le lesweu, letlalo le le bosweu jo bo mo magareng',
    '👩🏻‍🐰‍👩🏽' => 'basadi ka ditsebe tsa mmutla mo moletlong: letlalo le lesweu, letlalo la mmala o o mo magareng',
    '👩🏻‍🐰‍👩🏾' => 'basadi ka ditsebe tsa mmutla mo moletlong: letlalo le lesweu, letlalo la mmala wa bontsho jo bo mo magareng',
    '👩🏻‍🐰‍👩🏿' => 'basadi ka ditsebe tsa mmutla mo moletlong: letlalo le lesweu, letlalo la mmala o montsho',
    '👩🏼‍🐰‍👩🏻' => 'basadi ka ditsebe tsa mmutla mo moletlong: letlalo le le bosweu jo bo mo magareng, letlalo le lesweu',
    '👩🏼‍🐰‍👩🏽' => 'basadi ka ditsebe tsa mmutla mo moletlong: letlalo le le bosweu jo bo mo magareng, letlalo la mmala o o mo magareng',
    '👩🏼‍🐰‍👩🏾' => 'basadi ka ditsebe tsa mmutla mo moletlong: letlalo le le bosweu jo bo mo magareng, letlalo la mmala wa bontsho jo bo mo magareng',
    '👩🏼‍🐰‍👩🏿' => 'basadi ka ditsebe tsa mmutla mo moletlong: letlalo le le bosweu jo bo mo magareng, letlalo la mmala o montsho',
    '👩🏽‍🐰‍👩🏻' => 'basadi ka ditsebe tsa mmutla mo moletlong: letlalo la mmala o o mo magareng, letlalo le lesweu',
    '👩🏽‍🐰‍👩🏼' => 'basadi ka ditsebe tsa mmutla mo moletlong: letlalo la mmala o o mo magareng, letlalo le le bosweu jo bo mo magareng',
    '👩🏽‍🐰‍👩🏾' => 'basadi ka ditsebe tsa mmutla mo moletlong: letlalo la mmala o o mo magareng, letlalo la mmala wa bontsho jo bo mo magareng',
    '👩🏽‍🐰‍👩🏿' => 'basadi ka ditsebe tsa mmutla mo moletlong: letlalo la mmala o o mo magareng, letlalo la mmala o montsho',
    '👩🏾‍🐰‍👩🏻' => 'basadi ka ditsebe tsa mmutla mo moletlong: letlalo la mmala wa bontsho jo bo mo magareng, letlalo le lesweu',
    '👩🏾‍🐰‍👩🏼' => 'basadi ka ditsebe tsa mmutla mo moletlong: letlalo la mmala wa bontsho jo bo mo magareng, letlalo le le bosweu jo bo mo magareng',
    '👩🏾‍🐰‍👩🏽' => 'basadi ka ditsebe tsa mmutla mo moletlong: letlalo la mmala wa bontsho jo bo mo magareng, letlalo la mmala o o mo magareng',
    '👩🏾‍🐰‍👩🏿' => 'basadi ka ditsebe tsa mmutla mo moletlong: letlalo la mmala wa bontsho jo bo mo magareng, letlalo la mmala o montsho',
    '👩🏿‍🐰‍👩🏻' => 'basadi ka ditsebe tsa mmutla mo moletlong: letlalo la mmala o montsho, letlalo le lesweu',
    '👩🏿‍🐰‍👩🏼' => 'basadi ka ditsebe tsa mmutla mo moletlong: letlalo la mmala o montsho, letlalo le le bosweu jo bo mo magareng',
    '👩🏿‍🐰‍👩🏽' => 'basadi ka ditsebe tsa mmutla mo moletlong: letlalo la mmala o montsho, letlalo la mmala o o mo magareng',
    '👩🏿‍🐰‍👩🏾' => 'basadi ka ditsebe tsa mmutla mo moletlong: letlalo la mmala o montsho, letlalo la mmala wa bontsho jo bo mo magareng',
    '👩🏻‍🤝‍👩🏼' => 'basadi ba babedi ba tshwarane matsogo: letlalo le lesweu, letlalo le le bosweu jo bo mo magareng',
    '👩🏻‍🤝‍👩🏽' => 'basadi ba babedi ba tshwarane matsogo: letlalo le lesweu, letlalo la mmala o o mo magareng',
    '👩🏻‍🤝‍👩🏾' => 'basadi ba babedi ba tshwarane matsogo: letlalo le lesweu, letlalo la mmala wa bontsho jo bo mo magareng',
    '👩🏻‍🤝‍👩🏿' => 'basadi ba babedi ba tshwarane matsogo: letlalo le lesweu, letlalo la mmala o montsho',
    '👩🏼‍🤝‍👩🏻' => 'basadi ba babedi ba tshwarane matsogo: letlalo le le bosweu jo bo mo magareng, letlalo le lesweu',
    '👩🏼‍🤝‍👩🏽' => 'basadi ba babedi ba tshwarane matsogo: letlalo le le bosweu jo bo mo magareng, letlalo la mmala o o mo magareng',
    '👩🏼‍🤝‍👩🏾' => 'basadi ba babedi ba tshwarane matsogo: letlalo le le bosweu jo bo mo magareng, letlalo la mmala wa bontsho jo bo mo magareng',
    '👩🏼‍🤝‍👩🏿' => 'basadi ba babedi ba tshwarane matsogo: letlalo le le bosweu jo bo mo magareng, letlalo la mmala o montsho',
    '👩🏽‍🤝‍👩🏻' => 'basadi ba babedi ba tshwarane matsogo: letlalo la mmala o o mo magareng, letlalo le lesweu',
    '👩🏽‍🤝‍👩🏼' => 'basadi ba babedi ba tshwarane matsogo: letlalo la mmala o o mo magareng, letlalo le le bosweu jo bo mo magareng',
    '👩🏽‍🤝‍👩🏾' => 'basadi ba babedi ba tshwarane matsogo: letlalo la mmala o o mo magareng, letlalo la mmala wa bontsho jo bo mo magareng',
    '👩🏽‍🤝‍👩🏿' => 'basadi ba babedi ba tshwarane matsogo: letlalo la mmala o o mo magareng, letlalo la mmala o montsho',
    '👩🏾‍🤝‍👩🏻' => 'basadi ba babedi ba tshwarane matsogo: letlalo la mmala wa bontsho jo bo mo magareng, letlalo le lesweu',
    '👩🏾‍🤝‍👩🏼' => 'basadi ba babedi ba tshwarane matsogo: letlalo la mmala wa bontsho jo bo mo magareng, letlalo le le bosweu jo bo mo magareng',
    '👩🏾‍🤝‍👩🏽' => 'basadi ba babedi ba tshwarane matsogo: letlalo la mmala wa bontsho jo bo mo magareng, letlalo la mmala o o mo magareng',
    '👩🏾‍🤝‍👩🏿' => 'basadi ba babedi ba tshwarane matsogo: letlalo la mmala wa bontsho jo bo mo magareng, letlalo la mmala o montsho',
    '👩🏿‍🤝‍👩🏻' => 'basadi ba babedi ba tshwarane matsogo: letlalo la mmala o montsho, letlalo le lesweu',
    '👩🏿‍🤝‍👩🏼' => 'basadi ba babedi ba tshwarane matsogo: letlalo la mmala o montsho, letlalo le le bosweu jo bo mo magareng',
    '👩🏿‍🤝‍👩🏽' => 'basadi ba babedi ba tshwarane matsogo: letlalo la mmala o montsho, letlalo la mmala o o mo magareng',
    '👩🏿‍🤝‍👩🏾' => 'basadi ba babedi ba tshwarane matsogo: letlalo la mmala o montsho, letlalo la mmala wa bontsho jo bo mo magareng',
    '👩🏻‍🤝‍👨🏼' => 'monna le mosadi ba tshwarane matsogo: letlalo le lesweu, letlalo le le bosweu jo bo mo magareng',
    '👩🏻‍🤝‍👨🏽' => 'monna le mosadi ba tshwarane matsogo: letlalo le lesweu, letlalo la mmala o o mo magareng',
    '👩🏻‍🤝‍👨🏾' => 'monna le mosadi ba tshwarane matsogo: letlalo le lesweu, letlalo la mmala wa bontsho jo bo mo magareng',
    '👩🏻‍🤝‍👨🏿' => 'monna le mosadi ba tshwarane matsogo: letlalo le lesweu, letlalo la mmala o montsho',
    '👩🏼‍🤝‍👨🏻' => 'monna le mosadi ba tshwarane matsogo: letlalo le le bosweu jo bo mo magareng, letlalo le lesweu',
    '👩🏼‍🤝‍👨🏽' => 'monna le mosadi ba tshwarane matsogo: letlalo le le bosweu jo bo mo magareng, letlalo la mmala o o mo magareng',
    '👩🏼‍🤝‍👨🏾' => 'monna le mosadi ba tshwarane matsogo: letlalo le le bosweu jo bo mo magareng, letlalo la mmala wa bontsho jo bo mo magareng',
    '👩🏼‍🤝‍👨🏿' => 'monna le mosadi ba tshwarane matsogo: letlalo le le bosweu jo bo mo magareng, letlalo la mmala o montsho',
    '👩🏽‍🤝‍👨🏻' => 'monna le mosadi ba tshwarane matsogo: letlalo la mmala o o mo magareng, letlalo le lesweu',
    '👩🏽‍🤝‍👨🏼' => 'monna le mosadi ba tshwarane matsogo: letlalo la mmala o o mo magareng, letlalo le le bosweu jo bo mo magareng',
    '👩🏽‍🤝‍👨🏾' => 'monna le mosadi ba tshwarane matsogo: letlalo la mmala o o mo magareng, letlalo la mmala wa bontsho jo bo mo magareng',
    '👩🏽‍🤝‍👨🏿' => 'monna le mosadi ba tshwarane matsogo: letlalo la mmala o o mo magareng, letlalo la mmala o montsho',
    '👩🏾‍🤝‍👨🏻' => 'monna le mosadi ba tshwarane matsogo: letlalo la mmala wa bontsho jo bo mo magareng, letlalo le lesweu',
    '👩🏾‍🤝‍👨🏼' => 'monna le mosadi ba tshwarane matsogo: letlalo la mmala wa bontsho jo bo mo magareng, letlalo le le bosweu jo bo mo magareng',
    '👩🏾‍🤝‍👨🏽' => 'monna le mosadi ba tshwarane matsogo: letlalo la mmala wa bontsho jo bo mo magareng, letlalo la mmala o o mo magareng',
    '👩🏾‍🤝‍👨🏿' => 'monna le mosadi ba tshwarane matsogo: letlalo la mmala wa bontsho jo bo mo magareng, letlalo la mmala o montsho',
    '👩🏿‍🤝‍👨🏻' => 'monna le mosadi ba tshwarane matsogo: letlalo la mmala o montsho, letlalo le lesweu',
    '👩🏿‍🤝‍👨🏼' => 'monna le mosadi ba tshwarane matsogo: letlalo la mmala o montsho, letlalo le le bosweu jo bo mo magareng',
    '👩🏿‍🤝‍👨🏽' => 'monna le mosadi ba tshwarane matsogo: letlalo la mmala o montsho, letlalo la mmala o o mo magareng',
    '👩🏿‍🤝‍👨🏾' => 'monna le mosadi ba tshwarane matsogo: letlalo la mmala o montsho, letlalo la mmala wa bontsho jo bo mo magareng',
    '👨🏻‍🤝‍👨🏼' => 'banna ba babedi ba tshwarane matsogo: letlalo le lesweu, letlalo le le bosweu jo bo mo magareng',
    '👨🏻‍🤝‍👨🏽' => 'banna ba babedi ba tshwarane matsogo: letlalo le lesweu, letlalo la mmala o o mo magareng',
    '👨🏻‍🤝‍👨🏾' => 'banna ba babedi ba tshwarane matsogo: letlalo le lesweu, letlalo la mmala wa bontsho jo bo mo magareng',
    '👨🏻‍🤝‍👨🏿' => 'banna ba babedi ba tshwarane matsogo: letlalo le lesweu, letlalo la mmala o montsho',
    '👨🏼‍🤝‍👨🏻' => 'banna ba babedi ba tshwarane matsogo: letlalo le le bosweu jo bo mo magareng, letlalo le lesweu',
    '👨🏼‍🤝‍👨🏽' => 'banna ba babedi ba tshwarane matsogo: letlalo le le bosweu jo bo mo magareng, letlalo la mmala o o mo magareng',
    '👨🏼‍🤝‍👨🏾' => 'banna ba babedi ba tshwarane matsogo: letlalo le le bosweu jo bo mo magareng, letlalo la mmala wa bontsho jo bo mo magareng',
    '👨🏼‍🤝‍👨🏿' => 'banna ba babedi ba tshwarane matsogo: letlalo le le bosweu jo bo mo magareng, letlalo la mmala o montsho',
    '👨🏽‍🤝‍👨🏻' => 'banna ba babedi ba tshwarane matsogo: letlalo la mmala o o mo magareng, letlalo le lesweu',
    '👨🏽‍🤝‍👨🏼' => 'banna ba babedi ba tshwarane matsogo: letlalo la mmala o o mo magareng, letlalo le le bosweu jo bo mo magareng',
    '👨🏽‍🤝‍👨🏾' => 'banna ba babedi ba tshwarane matsogo: letlalo la mmala o o mo magareng, letlalo la mmala wa bontsho jo bo mo magareng',
    '👨🏽‍🤝‍👨🏿' => 'banna ba babedi ba tshwarane matsogo: letlalo la mmala o o mo magareng, letlalo la mmala o montsho',
    '👨🏾‍🤝‍👨🏻' => 'banna ba babedi ba tshwarane matsogo: letlalo la mmala wa bontsho jo bo mo magareng, letlalo le lesweu',
    '👨🏾‍🤝‍👨🏼' => 'banna ba babedi ba tshwarane matsogo: letlalo la mmala wa bontsho jo bo mo magareng, letlalo le le bosweu jo bo mo magareng',
    '👨🏾‍🤝‍👨🏽' => 'banna ba babedi ba tshwarane matsogo: letlalo la mmala wa bontsho jo bo mo magareng, letlalo la mmala o o mo magareng',
    '👨🏾‍🤝‍👨🏿' => 'banna ba babedi ba tshwarane matsogo: letlalo la mmala wa bontsho jo bo mo magareng, letlalo la mmala o montsho',
    '👨🏿‍🤝‍👨🏻' => 'banna ba babedi ba tshwarane matsogo: letlalo la mmala o montsho, letlalo le lesweu',
    '👨🏿‍🤝‍👨🏼' => 'banna ba babedi ba tshwarane matsogo: letlalo la mmala o montsho, letlalo le le bosweu jo bo mo magareng',
    '👨🏿‍🤝‍👨🏽' => 'banna ba babedi ba tshwarane matsogo: letlalo la mmala o montsho, letlalo la mmala o o mo magareng',
    '👨🏿‍🤝‍👨🏾' => 'banna ba babedi ba tshwarane matsogo: letlalo la mmala o montsho, letlalo la mmala wa bontsho jo bo mo magareng',
    '👩‍❤‍💋‍👨' => 'atla: mosadi, monna',
    '👨‍❤‍💋‍👨' => 'atla: monna, monna',
    '👩‍❤‍💋‍👩' => 'atla: mosadi, mosadi',
    '👨‍👩‍👧‍👦' => 'lelapa: monna, mosadi, mosetsana, mosimane',
    '👨‍👩‍👦‍👦' => 'lelapa: monna, mosadi, mosimane, mosimane',
    '👨‍👩‍👧‍👧' => 'lelapa: monna, mosadi, mosetsana, mosetsana',
    '👨‍👨‍👧‍👦' => 'lelapa: monna, monna, mosetsana, mosimane',
    '👨‍👨‍👦‍👦' => 'lelapa: monna, monna, mosimane, mosimane',
    '👨‍👨‍👧‍👧' => 'lelapa: monna, monna, mosetsana, mosetsana',
    '👩‍👩‍👧‍👦' => 'lelapa: mosadi, mosadi, mosetsana, mosimane',
    '👩‍👩‍👦‍👦' => 'lelapa: mosadi, mosadi, mosimane, mosimane',
    '👩‍👩‍👧‍👧' => 'lelapa: mosadi, mosadi, mosetsana, mosetsana',
    '🫱🏻‍🫲🏼' => 'tshwarano ka letsogo: letlalo le lesweu, letlalo le le bosweu jo bo mo magareng',
    '🫱🏻‍🫲🏽' => 'tshwarano ka letsogo: letlalo le lesweu, letlalo la mmala o o mo magareng',
    '🫱🏻‍🫲🏾' => 'tshwarano ka letsogo: letlalo le lesweu, letlalo la mmala wa bontsho jo bo mo magareng',
    '🫱🏻‍🫲🏿' => 'tshwarano ka letsogo: letlalo le lesweu, letlalo la mmala o montsho',
    '🫱🏼‍🫲🏻' => 'tshwarano ka letsogo: letlalo le le bosweu jo bo mo magareng, letlalo le lesweu',
    '🫱🏼‍🫲🏽' => 'tshwarano ka letsogo: letlalo le le bosweu jo bo mo magareng, letlalo la mmala o o mo magareng',
    '🫱🏼‍🫲🏾' => 'tshwarano ka letsogo: letlalo le le bosweu jo bo mo magareng, letlalo la mmala wa bontsho jo bo mo magareng',
    '🫱🏼‍🫲🏿' => 'tshwarano ka letsogo: letlalo le le bosweu jo bo mo magareng, letlalo la mmala o montsho',
    '🫱🏽‍🫲🏻' => 'tshwarano ka letsogo: letlalo la mmala o o mo magareng, letlalo le lesweu',
    '🫱🏽‍🫲🏼' => 'tshwarano ka letsogo: letlalo la mmala o o mo magareng, letlalo le le bosweu jo bo mo magareng',
    '🫱🏽‍🫲🏾' => 'tshwarano ka letsogo: letlalo la mmala o o mo magareng, letlalo la mmala wa bontsho jo bo mo magareng',
    '🫱🏽‍🫲🏿' => 'tshwarano ka letsogo: letlalo la mmala o o mo magareng, letlalo la mmala o montsho',
    '🫱🏾‍🫲🏻' => 'tshwarano ka letsogo: letlalo la mmala wa bontsho jo bo mo magareng, letlalo le lesweu',
    '🫱🏾‍🫲🏼' => 'tshwarano ka letsogo: letlalo la mmala wa bontsho jo bo mo magareng, letlalo le le bosweu jo bo mo magareng',
    '🫱🏾‍🫲🏽' => 'tshwarano ka letsogo: letlalo la mmala wa bontsho jo bo mo magareng, letlalo la mmala o o mo magareng',
    '🫱🏾‍🫲🏿' => 'tshwarano ka letsogo: letlalo la mmala wa bontsho jo bo mo magareng, letlalo la mmala o montsho',
    '🫱🏿‍🫲🏻' => 'tshwarano ka letsogo: letlalo la mmala o montsho, letlalo le lesweu',
    '🫱🏿‍🫲🏼' => 'tshwarano ka letsogo: letlalo la mmala o montsho, letlalo le le bosweu jo bo mo magareng',
    '🫱🏿‍🫲🏽' => 'tshwarano ka letsogo: letlalo la mmala o montsho, letlalo la mmala o o mo magareng',
    '🫱🏿‍🫲🏾' => 'tshwarano ka letsogo: letlalo la mmala o montsho, letlalo la mmala wa bontsho jo bo mo magareng',
    '👩‍❤‍👨' => 'bobedi ka pelo: mosadi, monna',
    '👨‍❤‍👨' => 'bobedi ka pelo: monna, monna',
    '👩‍❤‍👩' => 'bobedi ka pelo: mosadi, mosadi',
    '👨‍👩‍👦' => 'lelapa: monna, mosadi, mosimane',
    '👨‍👩‍👧' => 'lelapa: monna, mosadi, mosetsana',
    '👨‍👨‍👦' => 'lelapa: monna, monna, mosimane',
    '👨‍👨‍👧' => 'lelapa: monna, monna, mosetsana',
    '👩‍👩‍👦' => 'lelapa: mosadi, mosadi, mosimane',
    '👩‍👩‍👧' => 'lelapa: mosadi, mosadi, mosetsana',
    '👨‍👦‍👦' => 'lelapa: monna, mosimane, mosimane',
    '👨‍👧‍👦' => 'lelapa: monna, mosetsana, mosimane',
    '👨‍👧‍👧' => 'lelapa: monna, mosetsana, mosetsana',
    '👩‍👦‍👦' => 'lelapa: mosadi, mosimane, mosimane',
    '👩‍👧‍👦' => 'lelapa: mosadi, mosetsana, mosimane',
    '👩‍👧‍👧' => 'lelapa: mosadi, mosetsana, mosetsana',
    '👱🏻‍♂' => 'monna wa moriri o mosetlha: letlalo le lesweu',
    '👱🏼‍♂' => 'monna wa moriri o mosetlha: letlalo le le bosweu jo bo mo magareng',
    '👱🏽‍♂' => 'monna wa moriri o mosetlha: letlalo la mmala o o mo magareng',
    '👱🏾‍♂' => 'monna wa moriri o mosetlha: letlalo la mmala wa bontsho jo bo mo magareng',
    '👱🏿‍♂' => 'monna wa moriri o mosetlha: letlalo la mmala o montsho',
    '👱🏻‍♀' => 'mosadi wa moriri o mosetlha: letlalo le lesweu',
    '👱🏼‍♀' => 'mosadi wa moriri o mosetlha: letlalo le le bosweu jo bo mo magareng',
    '👱🏽‍♀' => 'mosadi wa moriri o mosetlha: letlalo la mmala o o mo magareng',
    '👱🏾‍♀' => 'mosadi wa moriri o mosetlha: letlalo la mmala wa bontsho jo bo mo magareng',
    '👱🏿‍♀' => 'mosadi wa moriri o mosetlha: letlalo la mmala o montsho',
    '🙍🏻‍♂' => 'monna yo o menneng phatla: letlalo le lesweu',
    '🙍🏼‍♂' => 'monna yo o menneng phatla: letlalo le le bosweu jo bo mo magareng',
    '🙍🏽‍♂' => 'monna yo o menneng phatla: letlalo la mmala o o mo magareng',
    '🙍🏾‍♂' => 'monna yo o menneng phatla: letlalo la mmala wa bontsho jo bo mo magareng',
    '🙍🏿‍♂' => 'monna yo o menneng phatla: letlalo la mmala o montsho',
    '🙍🏻‍♀' => 'mosadi yo o menneng phatla: letlalo le lesweu',
    '🙍🏼‍♀' => 'mosadi yo o menneng phatla: letlalo le le bosweu jo bo mo magareng',
    '🙍🏽‍♀' => 'mosadi yo o menneng phatla: letlalo la mmala o o mo magareng',
    '🙍🏾‍♀' => 'mosadi yo o menneng phatla: letlalo la mmala wa bontsho jo bo mo magareng',
    '🙍🏿‍♀' => 'mosadi yo o menneng phatla: letlalo la mmala o montsho',
    '🙎🏻‍♂' => 'monna yo o tsuputseng molomo: letlalo le lesweu',
    '🙎🏼‍♂' => 'monna yo o tsuputseng molomo: letlalo le le bosweu jo bo mo magareng',
    '🙎🏽‍♂' => 'monna yo o tsuputseng molomo: letlalo la mmala o o mo magareng',
    '🙎🏾‍♂' => 'monna yo o tsuputseng molomo: letlalo la mmala wa bontsho jo bo mo magareng',
    '🙎🏿‍♂' => 'monna yo o tsuputseng molomo: letlalo la mmala o montsho',
    '🙎🏻‍♀' => 'mosadi yo o tsuputseng molomo: letlalo le lesweu',
    '🙎🏼‍♀' => 'mosadi yo o tsuputseng molomo: letlalo le le bosweu jo bo mo magareng',
    '🙎🏽‍♀' => 'mosadi yo o tsuputseng molomo: letlalo la mmala o o mo magareng',
    '🙎🏾‍♀' => 'mosadi yo o tsuputseng molomo: letlalo la mmala wa bontsho jo bo mo magareng',
    '🙎🏿‍♀' => 'mosadi yo o tsuputseng molomo: letlalo la mmala o montsho',
    '🙅🏻‍♂' => 'monna yo o reng NNYAA ka puo ya matsogo: letlalo le lesweu',
    '🙅🏼‍♂' => 'monna yo o reng NNYAA ka puo ya matsogo: letlalo le le bosweu jo bo mo magareng',
    '🙅🏽‍♂' => 'monna yo o reng NNYAA ka puo ya matsogo: letlalo la mmala o o mo magareng',
    '🙅🏾‍♂' => 'monna yo o reng NNYAA ka puo ya matsogo: letlalo la mmala wa bontsho jo bo mo magareng',
    '🙅🏿‍♂' => 'monna yo o reng NNYAA ka puo ya matsogo: letlalo la mmala o montsho',
    '🙅🏻‍♀' => 'mosadi yo o reng NNYAA ka puo ya matsogo: letlalo le lesweu',
    '🙅🏼‍♀' => 'mosadi yo o reng NNYAA ka puo ya matsogo: letlalo le le bosweu jo bo mo magareng',
    '🙅🏽‍♀' => 'mosadi yo o reng NNYAA ka puo ya matsogo: letlalo la mmala o o mo magareng',
    '🙅🏾‍♀' => 'mosadi yo o reng NNYAA ka puo ya matsogo: letlalo la mmala wa bontsho jo bo mo magareng',
    '🙅🏿‍♀' => 'mosadi yo o reng NNYAA ka puo ya matsogo: letlalo la mmala o montsho',
    '🙆🏻‍♂' => 'monna yo o reng GO SIAME ka puo ya matsogo: letlalo le lesweu',
    '🙆🏼‍♂' => 'monna yo o reng GO SIAME ka puo ya matsogo: letlalo le le bosweu jo bo mo magareng',
    '🙆🏽‍♂' => 'monna yo o reng GO SIAME ka puo ya matsogo: letlalo la mmala o o mo magareng',
    '🙆🏾‍♂' => 'monna yo o reng GO SIAME ka puo ya matsogo: letlalo la mmala wa bontsho jo bo mo magareng',
    '🙆🏿‍♂' => 'monna yo o reng GO SIAME ka puo ya matsogo: letlalo la mmala o montsho',
    '🙆🏻‍♀' => 'mosadi yo o reng GO SIAME ka puo ya matsogo: letlalo le lesweu',
    '🙆🏼‍♀' => 'mosadi yo o reng GO SIAME ka puo ya matsogo: letlalo le le bosweu jo bo mo magareng',
    '🙆🏽‍♀' => 'mosadi yo o reng GO SIAME ka puo ya matsogo: letlalo la mmala o o mo magareng',
    '🙆🏾‍♀' => 'mosadi yo o reng GO SIAME ka puo ya matsogo: letlalo la mmala wa bontsho jo bo mo magareng',
    '🙆🏿‍♀' => 'mosadi yo o reng GO SIAME ka puo ya matsogo: letlalo la mmala o montsho',
    '💁🏻‍♂' => 'monna a sekamisa letsogo: letlalo le lesweu',
    '💁🏼‍♂' => 'monna a sekamisa letsogo: letlalo le le bosweu jo bo mo magareng',
    '💁🏽‍♂' => 'monna a sekamisa letsogo: letlalo la mmala o o mo magareng',
    '💁🏾‍♂' => 'monna a sekamisa letsogo: letlalo la mmala wa bontsho jo bo mo magareng',
    '💁🏿‍♂' => 'monna a sekamisa letsogo: letlalo la mmala o montsho',
    '💁🏻‍♀' => 'mosadi a sekamisa letsogo: letlalo le lesweu',
    '💁🏼‍♀' => 'mosadi a sekamisa letsogo: letlalo le le bosweu jo bo mo magareng',
    '💁🏽‍♀' => 'mosadi a sekamisa letsogo: letlalo la mmala o o mo magareng',
    '💁🏾‍♀' => 'mosadi a sekamisa letsogo: letlalo la mmala wa bontsho jo bo mo magareng',
    '💁🏿‍♀' => 'mosadi a sekamisa letsogo: letlalo la mmala o montsho',
    '🙋🏻‍♂' => 'monna a tsholetsa letsogo: letlalo le lesweu',
    '🙋🏼‍♂' => 'monna a tsholetsa letsogo: letlalo le le bosweu jo bo mo magareng',
    '🙋🏽‍♂' => 'monna a tsholetsa letsogo: letlalo la mmala o o mo magareng',
    '🙋🏾‍♂' => 'monna a tsholetsa letsogo: letlalo la mmala wa bontsho jo bo mo magareng',
    '🙋🏿‍♂' => 'monna a tsholetsa letsogo: letlalo la mmala o montsho',
    '🙋🏻‍♀' => 'mosadi a tsholetsa letsogo: letlalo le lesweu',
    '🙋🏼‍♀' => 'mosadi a tsholetsa letsogo: letlalo le le bosweu jo bo mo magareng',
    '🙋🏽‍♀' => 'mosadi a tsholetsa letsogo: letlalo la mmala o o mo magareng',
    '🙋🏾‍♀' => 'mosadi a tsholetsa letsogo: letlalo la mmala wa bontsho jo bo mo magareng',
    '🙋🏿‍♀' => 'mosadi a tsholetsa letsogo: letlalo la mmala o montsho',
    '🙇🏻‍♂' => 'monna a obega: letlalo le lesweu',
    '🙇🏼‍♂' => 'monna a obega: letlalo le le bosweu jo bo mo magareng',
    '🙇🏽‍♂' => 'monna a obega: letlalo la mmala o o mo magareng',
    '🙇🏾‍♂' => 'monna a obega: letlalo la mmala wa bontsho jo bo mo magareng',
    '🙇🏿‍♂' => 'monna a obega: letlalo la mmala o montsho',
    '🙇🏻‍♀' => 'mosadi a obega: letlalo le lesweu',
    '🙇🏼‍♀' => 'mosadi a obega: letlalo le le bosweu jo bo mo magareng',
    '🙇🏽‍♀' => 'mosadi a obega: letlalo la mmala o o mo magareng',
    '🙇🏾‍♀' => 'mosadi a obega: letlalo la mmala wa bontsho jo bo mo magareng',
    '🙇🏿‍♀' => 'mosadi a obega: letlalo la mmala o montsho',
    '🤦🏻‍♂' => 'monna ka legofi mo sefatlhegong: letlalo le lesweu',
    '🤦🏼‍♂' => 'monna ka legofi mo sefatlhegong: letlalo le le bosweu jo bo mo magareng',
    '🤦🏽‍♂' => 'monna ka legofi mo sefatlhegong: letlalo la mmala o o mo magareng',
    '🤦🏾‍♂' => 'monna ka legofi mo sefatlhegong: letlalo la mmala wa bontsho jo bo mo magareng',
    '🤦🏿‍♂' => 'monna ka legofi mo sefatlhegong: letlalo la mmala o montsho',
    '🤦🏻‍♀' => 'mosadi ka legofi mo sefatlhegong: letlalo le lesweu',
    '🤦🏼‍♀' => 'mosadi ka legofi mo sefatlhegong: letlalo le le bosweu jo bo mo magareng',
    '🤦🏽‍♀' => 'mosadi ka legofi mo sefatlhegong: letlalo la mmala o o mo magareng',
    '🤦🏾‍♀' => 'mosadi ka legofi mo sefatlhegong: letlalo la mmala wa bontsho jo bo mo magareng',
    '🤦🏿‍♀' => 'mosadi ka legofi mo sefatlhegong: letlalo la mmala o montsho',
    '🤷🏻‍♂' => 'monna yo o tsholetsang magetla: letlalo le lesweu',
    '🤷🏼‍♂' => 'monna yo o tsholetsang magetla: letlalo le le bosweu jo bo mo magareng',
    '🤷🏽‍♂' => 'monna yo o tsholetsang magetla: letlalo la mmala o o mo magareng',
    '🤷🏾‍♂' => 'monna yo o tsholetsang magetla: letlalo la mmala wa bontsho jo bo mo magareng',
    '🤷🏿‍♂' => 'monna yo o tsholetsang magetla: letlalo la mmala o montsho',
    '🤷🏻‍♀' => 'mosadi yo o tsholetsang magetla: letlalo le lesweu',
    '🤷🏼‍♀' => 'mosadi yo o tsholetsang magetla: letlalo le le bosweu jo bo mo magareng',
    '🤷🏽‍♀' => 'mosadi yo o tsholetsang magetla: letlalo la mmala o o mo magareng',
    '🤷🏾‍♀' => 'mosadi yo o tsholetsang magetla: letlalo la mmala wa bontsho jo bo mo magareng',
    '🤷🏿‍♀' => 'mosadi yo o tsholetsang magetla: letlalo la mmala o montsho',
    '👨🏻‍⚕' => 'modiri wa tsa botsogo wa monna: letlalo le lesweu',
    '👨🏼‍⚕' => 'modiri wa tsa botsogo wa monna: letlalo le le bosweu jo bo mo magareng',
    '👨🏽‍⚕' => 'modiri wa tsa botsogo wa monna: letlalo la mmala o o mo magareng',
    '👨🏾‍⚕' => 'modiri wa tsa botsogo wa monna: letlalo la mmala wa bontsho jo bo mo magareng',
    '👨🏿‍⚕' => 'modiri wa tsa botsogo wa monna: letlalo la mmala o montsho',
    '👩🏻‍⚕' => 'modiri wa tsa botsogo wa mosadi: letlalo le lesweu',
    '👩🏼‍⚕' => 'modiri wa tsa botsogo wa mosadi: letlalo le le bosweu jo bo mo magareng',
    '👩🏽‍⚕' => 'modiri wa tsa botsogo wa mosadi: letlalo la mmala o o mo magareng',
    '👩🏾‍⚕' => 'modiri wa tsa botsogo wa mosadi: letlalo la mmala wa bontsho jo bo mo magareng',
    '👩🏿‍⚕' => 'modiri wa tsa botsogo wa mosadi: letlalo la mmala o montsho',
    '👨🏻‍🎓' => 'seithuti sa monna: letlalo le lesweu',
    '👨🏼‍🎓' => 'seithuti sa monna: letlalo le le bosweu jo bo mo magareng',
    '👨🏽‍🎓' => 'seithuti sa monna: letlalo la mmala o o mo magareng',
    '👨🏾‍🎓' => 'seithuti sa monna: letlalo la mmala wa bontsho jo bo mo magareng',
    '👨🏿‍🎓' => 'seithuti sa monna: letlalo la mmala o montsho',
    '👩🏻‍🎓' => 'seithuti sa mosadi: letlalo le lesweu',
    '👩🏼‍🎓' => 'seithuti sa mosadi: letlalo le le bosweu jo bo mo magareng',
    '👩🏽‍🎓' => 'seithuti sa mosadi: letlalo la mmala o o mo magareng',
    '👩🏾‍🎓' => 'seithuti sa mosadi: letlalo la mmala wa bontsho jo bo mo magareng',
    '👩🏿‍🎓' => 'seithuti sa mosadi: letlalo la mmala o montsho',
    '👨🏻‍🏫' => 'morutisi wa monna: letlalo le lesweu',
    '👨🏼‍🏫' => 'morutisi wa monna: letlalo le le bosweu jo bo mo magareng',
    '👨🏽‍🏫' => 'morutisi wa monna: letlalo la mmala o o mo magareng',
    '👨🏾‍🏫' => 'morutisi wa monna: letlalo la mmala wa bontsho jo bo mo magareng',
    '👨🏿‍🏫' => 'morutisi wa monna: letlalo la mmala o montsho',
    '👩🏻‍🏫' => 'morutisi wa mosadi: letlalo le lesweu',
    '👩🏼‍🏫' => 'morutisi wa mosadi: letlalo le le bosweu jo bo mo magareng',
    '👩🏽‍🏫' => 'morutisi wa mosadi: letlalo la mmala o o mo magareng',
    '👩🏾‍🏫' => 'morutisi wa mosadi: letlalo la mmala wa bontsho jo bo mo magareng',
    '👩🏿‍🏫' => 'morutisi wa mosadi: letlalo la mmala o montsho',
    '👨🏻‍⚖' => 'moatlhodi wa monna: letlalo le lesweu',
    '👨🏼‍⚖' => 'moatlhodi wa monna: letlalo le le bosweu jo bo mo magareng',
    '👨🏽‍⚖' => 'moatlhodi wa monna: letlalo la mmala o o mo magareng',
    '👨🏾‍⚖' => 'moatlhodi wa monna: letlalo la mmala wa bontsho jo bo mo magareng',
    '👨🏿‍⚖' => 'moatlhodi wa monna: letlalo la mmala o montsho',
    '👩🏻‍⚖' => 'moatlhodi wa mosadi: letlalo le lesweu',
    '👩🏼‍⚖' => 'moatlhodi wa mosadi: letlalo le le bosweu jo bo mo magareng',
    '👩🏽‍⚖' => 'moatlhodi wa mosadi: letlalo la mmala o o mo magareng',
    '👩🏾‍⚖' => 'moatlhodi wa mosadi: letlalo la mmala wa bontsho jo bo mo magareng',
    '👩🏿‍⚖' => 'moatlhodi wa mosadi: letlalo la mmala o montsho',
    '👨🏻‍🌾' => 'molemirui wa monna: letlalo le lesweu',
    '👨🏼‍🌾' => 'molemirui wa monna: letlalo le le bosweu jo bo mo magareng',
    '👨🏽‍🌾' => 'molemirui wa monna: letlalo la mmala o o mo magareng',
    '👨🏾‍🌾' => 'molemirui wa monna: letlalo la mmala wa bontsho jo bo mo magareng',
    '👨🏿‍🌾' => 'molemirui wa monna: letlalo la mmala o montsho',
    '👩🏻‍🌾' => 'molemirui wa mosadi: letlalo le lesweu',
    '👩🏼‍🌾' => 'molemirui wa mosadi: letlalo le le bosweu jo bo mo magareng',
    '👩🏽‍🌾' => 'molemirui wa mosadi: letlalo la mmala o o mo magareng',
    '👩🏾‍🌾' => 'molemirui wa mosadi: letlalo la mmala wa bontsho jo bo mo magareng',
    '👩🏿‍🌾' => 'molemirui wa mosadi: letlalo la mmala o montsho',
    '👨🏻‍🍳' => 'moapei wa monna: letlalo le lesweu',
    '👨🏼‍🍳' => 'moapei wa monna: letlalo le le bosweu jo bo mo magareng',
    '👨🏽‍🍳' => 'moapei wa monna: letlalo la mmala o o mo magareng',
    '👨🏾‍🍳' => 'moapei wa monna: letlalo la mmala wa bontsho jo bo mo magareng',
    '👨🏿‍🍳' => 'moapei wa monna: letlalo la mmala o montsho',
    '👩🏻‍🍳' => 'moapei wa mosadi: letlalo le lesweu',
    '👩🏼‍🍳' => 'moapei wa mosadi: letlalo le le bosweu jo bo mo magareng',
    '👩🏽‍🍳' => 'moapei wa mosadi: letlalo la mmala o o mo magareng',
    '👩🏾‍🍳' => 'moapei wa mosadi: letlalo la mmala wa bontsho jo bo mo magareng',
    '👩🏿‍🍳' => 'moapei wa mosadi: letlalo la mmala o montsho',
    '👨🏻‍🔧' => 'mekheniki wa monna: letlalo le lesweu',
    '👨🏼‍🔧' => 'mekheniki wa monna: letlalo le le bosweu jo bo mo magareng',
    '👨🏽‍🔧' => 'mekheniki wa monna: letlalo la mmala o o mo magareng',
    '👨🏾‍🔧' => 'mekheniki wa monna: letlalo la mmala wa bontsho jo bo mo magareng',
    '👨🏿‍🔧' => 'mekheniki wa monna: letlalo la mmala o montsho',
    '👩🏻‍🔧' => 'mekheniki wa mosadi: letlalo le lesweu',
    '👩🏼‍🔧' => 'mekheniki wa mosadi: letlalo le le bosweu jo bo mo magareng',
    '👩🏽‍🔧' => 'mekheniki wa mosadi: letlalo la mmala o o mo magareng',
    '👩🏾‍🔧' => 'mekheniki wa mosadi: letlalo la mmala wa bontsho jo bo mo magareng',
    '👩🏿‍🔧' => 'mekheniki wa mosadi: letlalo la mmala o montsho',
    '👨🏻‍🏭' => 'modiri wa bodirelo wa monna: letlalo le lesweu',
    '👨🏼‍🏭' => 'modiri wa bodirelo wa monna: letlalo le le bosweu jo bo mo magareng',
    '👨🏽‍🏭' => 'modiri wa bodirelo wa monna: letlalo la mmala o o mo magareng',
    '👨🏾‍🏭' => 'modiri wa bodirelo wa monna: letlalo la mmala wa bontsho jo bo mo magareng',
    '👨🏿‍🏭' => 'modiri wa bodirelo wa monna: letlalo la mmala o montsho',
    '👩🏻‍🏭' => 'modiri wa bodirelo wa mosadi: letlalo le lesweu',
    '👩🏼‍🏭' => 'modiri wa bodirelo wa mosadi: letlalo le le bosweu jo bo mo magareng',
    '👩🏽‍🏭' => 'modiri wa bodirelo wa mosadi: letlalo la mmala o o mo magareng',
    '👩🏾‍🏭' => 'modiri wa bodirelo wa mosadi: letlalo la mmala wa bontsho jo bo mo magareng',
    '👩🏿‍🏭' => 'modiri wa bodirelo wa mosadi: letlalo la mmala o montsho',
    '👨🏻‍💼' => 'modiri wa mo ofising wa monna: letlalo le lesweu',
    '👨🏼‍💼' => 'modiri wa mo ofising wa monna: letlalo le le bosweu jo bo mo magareng',
    '👨🏽‍💼' => 'modiri wa mo ofising wa monna: letlalo la mmala o o mo magareng',
    '👨🏾‍💼' => 'modiri wa mo ofising wa monna: letlalo la mmala wa bontsho jo bo mo magareng',
    '👨🏿‍💼' => 'modiri wa mo ofising wa monna: letlalo la mmala o montsho',
    '👩🏻‍💼' => 'modiri wa mo ofising wa mosadi: letlalo le lesweu',
    '👩🏼‍💼' => 'modiri wa mo ofising wa mosadi: letlalo le le bosweu jo bo mo magareng',
    '👩🏽‍💼' => 'modiri wa mo ofising wa mosadi: letlalo la mmala o o mo magareng',
    '👩🏾‍💼' => 'modiri wa mo ofising wa mosadi: letlalo la mmala wa bontsho jo bo mo magareng',
    '👩🏿‍💼' => 'modiri wa mo ofising wa mosadi: letlalo la mmala o montsho',
    '👨🏻‍🔬' => 'moitsesaense wa monna: letlalo le lesweu',
    '👨🏼‍🔬' => 'moitsesaense wa monna: letlalo le le bosweu jo bo mo magareng',
    '👨🏽‍🔬' => 'moitsesaense wa monna: letlalo la mmala o o mo magareng',
    '👨🏾‍🔬' => 'moitsesaense wa monna: letlalo la mmala wa bontsho jo bo mo magareng',
    '👨🏿‍🔬' => 'moitsesaense wa monna: letlalo la mmala o montsho',
    '👩🏻‍🔬' => 'moitsesaense wa mosadi: letlalo le lesweu',
    '👩🏼‍🔬' => 'moitsesaense wa mosadi: letlalo le le bosweu jo bo mo magareng',
    '👩🏽‍🔬' => 'moitsesaense wa mosadi: letlalo la mmala o o mo magareng',
    '👩🏾‍🔬' => 'moitsesaense wa mosadi: letlalo la mmala wa bontsho jo bo mo magareng',
    '👩🏿‍🔬' => 'moitsesaense wa mosadi: letlalo la mmala o montsho',
    '👨🏻‍💻' => 'moitse thekenoloji wa monna: letlalo le lesweu',
    '👨🏼‍💻' => 'moitse thekenoloji wa monna: letlalo le le bosweu jo bo mo magareng',
    '👨🏽‍💻' => 'moitse thekenoloji wa monna: letlalo la mmala o o mo magareng',
    '👨🏾‍💻' => 'moitse thekenoloji wa monna: letlalo la mmala wa bontsho jo bo mo magareng',
    '👨🏿‍💻' => 'moitse thekenoloji wa monna: letlalo la mmala o montsho',
    '👩🏻‍💻' => 'moitse thekenoloji wa mosadi: letlalo le lesweu',
    '👩🏼‍💻' => 'moitse thekenoloji wa mosadi: letlalo le le bosweu jo bo mo magareng',
    '👩🏽‍💻' => 'moitse thekenoloji wa mosadi: letlalo la mmala o o mo magareng',
    '👩🏾‍💻' => 'moitse thekenoloji wa mosadi: letlalo la mmala wa bontsho jo bo mo magareng',
    '👩🏿‍💻' => 'moitse thekenoloji wa mosadi: letlalo la mmala o montsho',
    '👨🏻‍🎤' => 'seopedi sa monna: letlalo le lesweu',
    '👨🏼‍🎤' => 'seopedi sa monna: letlalo le le bosweu jo bo mo magareng',
    '👨🏽‍🎤' => 'seopedi sa monna: letlalo la mmala o o mo magareng',
    '👨🏾‍🎤' => 'seopedi sa monna: letlalo la mmala wa bontsho jo bo mo magareng',
    '👨🏿‍🎤' => 'seopedi sa monna: letlalo la mmala o montsho',
    '👩🏻‍🎤' => 'seopedi sa mosadi: letlalo le lesweu',
    '👩🏼‍🎤' => 'seopedi sa mosadi: letlalo le le bosweu jo bo mo magareng',
    '👩🏽‍🎤' => 'seopedi sa mosadi: letlalo la mmala o o mo magareng',
    '👩🏾‍🎤' => 'seopedi sa mosadi: letlalo la mmala wa bontsho jo bo mo magareng',
    '👩🏿‍🎤' => 'seopedi sa mosadi: letlalo la mmala o montsho',
    '👨🏻‍🎨' => 'modiragatsi wa monna: letlalo le lesweu',
    '👨🏼‍🎨' => 'modiragatsi wa monna: letlalo le le bosweu jo bo mo magareng',
    '👨🏽‍🎨' => 'modiragatsi wa monna: letlalo la mmala o o mo magareng',
    '👨🏾‍🎨' => 'modiragatsi wa monna: letlalo la mmala wa bontsho jo bo mo magareng',
    '👨🏿‍🎨' => 'modiragatsi wa monna: letlalo la mmala o montsho',
    '👩🏻‍🎨' => 'modiragatsi wa mosadi: letlalo le lesweu',
    '👩🏼‍🎨' => 'modiragatsi wa mosadi: letlalo le le bosweu jo bo mo magareng',
    '👩🏽‍🎨' => 'modiragatsi wa mosadi: letlalo la mmala o o mo magareng',
    '👩🏾‍🎨' => 'modiragatsi wa mosadi: letlalo la mmala wa bontsho jo bo mo magareng',
    '👩🏿‍🎨' => 'modiragatsi wa mosadi: letlalo la mmala o montsho',
    '👨🏻‍✈' => 'mokgweetsi wa sefofane wa monna: letlalo le lesweu',
    '👨🏼‍✈' => 'mokgweetsi wa sefofane wa monna: letlalo le le bosweu jo bo mo magareng',
    '👨🏽‍✈' => 'mokgweetsi wa sefofane wa monna: letlalo la mmala o o mo magareng',
    '👨🏾‍✈' => 'mokgweetsi wa sefofane wa monna: letlalo la mmala wa bontsho jo bo mo magareng',
    '👨🏿‍✈' => 'mokgweetsi wa sefofane wa monna: letlalo la mmala o montsho',
    '👩🏻‍✈' => 'mokgweetsi wa sefofane wa mosadi: letlalo le lesweu',
    '👩🏼‍✈' => 'mokgweetsi wa sefofane wa mosadi: letlalo le le bosweu jo bo mo magareng',
    '👩🏽‍✈' => 'mokgweetsi wa sefofane wa mosadi: letlalo la mmala o o mo magareng',
    '👩🏾‍✈' => 'mokgweetsi wa sefofane wa mosadi: letlalo la mmala wa bontsho jo bo mo magareng',
    '👩🏿‍✈' => 'mokgweetsi wa sefofane wa mosadi: letlalo la mmala o montsho',
    '👨🏻‍🚀' => 'moithutadinaledi wa monna: letlalo le lesweu',
    '👨🏼‍🚀' => 'moithutadinaledi wa monna: letlalo le le bosweu jo bo mo magareng',
    '👨🏽‍🚀' => 'moithutadinaledi wa monna: letlalo la mmala o o mo magareng',
    '👨🏾‍🚀' => 'moithutadinaledi wa monna: letlalo la mmala wa bontsho jo bo mo magareng',
    '👨🏿‍🚀' => 'moithutadinaledi wa monna: letlalo la mmala o montsho',
    '👩🏻‍🚀' => 'moithutadinaledi wa mosadi: letlalo le lesweu',
    '👩🏼‍🚀' => 'moithutadinaledi wa mosadi: letlalo le le bosweu jo bo mo magareng',
    '👩🏽‍🚀' => 'moithutadinaledi wa mosadi: letlalo la mmala o o mo magareng',
    '👩🏾‍🚀' => 'moithutadinaledi wa mosadi: letlalo la mmala wa bontsho jo bo mo magareng',
    '👩🏿‍🚀' => 'moithutadinaledi wa mosadi: letlalo la mmala o montsho',
    '👨🏻‍🚒' => 'motimamolelo wa monna: letlalo le lesweu',
    '👨🏼‍🚒' => 'motimamolelo wa monna: letlalo le le bosweu jo bo mo magareng',
    '👨🏽‍🚒' => 'motimamolelo wa monna: letlalo la mmala o o mo magareng',
    '👨🏾‍🚒' => 'motimamolelo wa monna: letlalo la mmala wa bontsho jo bo mo magareng',
    '👨🏿‍🚒' => 'motimamolelo wa monna: letlalo la mmala o montsho',
    '👩🏻‍🚒' => 'motimamolelo wa mosadi: letlalo le lesweu',
    '👩🏼‍🚒' => 'motimamolelo wa mosadi: letlalo le le bosweu jo bo mo magareng',
    '👩🏽‍🚒' => 'motimamolelo wa mosadi: letlalo la mmala o o mo magareng',
    '👩🏾‍🚒' => 'motimamolelo wa mosadi: letlalo la mmala wa bontsho jo bo mo magareng',
    '👩🏿‍🚒' => 'motimamolelo wa mosadi: letlalo la mmala o montsho',
    '👮🏻‍♂' => 'lepodise la monna: letlalo le lesweu',
    '👮🏼‍♂' => 'lepodise la monna: letlalo le le bosweu jo bo mo magareng',
    '👮🏽‍♂' => 'lepodise la monna: letlalo la mmala o o mo magareng',
    '👮🏾‍♂' => 'lepodise la monna: letlalo la mmala wa bontsho jo bo mo magareng',
    '👮🏿‍♂' => 'lepodise la monna: letlalo la mmala o montsho',
    '👮🏻‍♀' => 'lepodise la mosadi: letlalo le lesweu',
    '👮🏼‍♀' => 'lepodise la mosadi: letlalo le le bosweu jo bo mo magareng',
    '👮🏽‍♀' => 'lepodise la mosadi: letlalo la mmala o o mo magareng',
    '👮🏾‍♀' => 'lepodise la mosadi: letlalo la mmala wa bontsho jo bo mo magareng',
    '👮🏿‍♀' => 'lepodise la mosadi: letlalo la mmala o montsho',
    '🕵🏻‍♂' => 'leteketifi la monna: letlalo le lesweu',
    '🕵🏼‍♂' => 'leteketifi la monna: letlalo le le bosweu jo bo mo magareng',
    '🕵🏽‍♂' => 'leteketifi la monna: letlalo la mmala o o mo magareng',
    '🕵🏾‍♂' => 'leteketifi la monna: letlalo la mmala wa bontsho jo bo mo magareng',
    '🕵🏿‍♂' => 'leteketifi la monna: letlalo la mmala o montsho',
    '🕵🏻‍♀' => 'leteketifi la mosadi: letlalo le lesweu',
    '🕵🏼‍♀' => 'leteketifi la mosadi: letlalo le le bosweu jo bo mo magareng',
    '🕵🏽‍♀' => 'leteketifi la mosadi: letlalo la mmala o o mo magareng',
    '🕵🏾‍♀' => 'leteketifi la mosadi: letlalo la mmala wa bontsho jo bo mo magareng',
    '🕵🏿‍♀' => 'leteketifi la mosadi: letlalo la mmala o montsho',
    '💂🏻‍♂' => 'modisa wa monna: letlalo le lesweu',
    '💂🏼‍♂' => 'modisa wa monna: letlalo le le bosweu jo bo mo magareng',
    '💂🏽‍♂' => 'modisa wa monna: letlalo la mmala o o mo magareng',
    '💂🏾‍♂' => 'modisa wa monna: letlalo la mmala wa bontsho jo bo mo magareng',
    '💂🏿‍♂' => 'modisa wa monna: letlalo la mmala o montsho',
    '💂🏻‍♀' => 'modisa wa mosadi: letlalo le lesweu',
    '💂🏼‍♀' => 'modisa wa mosadi: letlalo le le bosweu jo bo mo magareng',
    '💂🏽‍♀' => 'modisa wa mosadi: letlalo la mmala o o mo magareng',
    '💂🏾‍♀' => 'modisa wa mosadi: letlalo la mmala wa bontsho jo bo mo magareng',
    '💂🏿‍♀' => 'modisa wa mosadi: letlalo la mmala o montsho',
    '👷🏻‍♂' => 'modiri wa monna mo kagong: letlalo le lesweu',
    '👷🏼‍♂' => 'modiri wa monna mo kagong: letlalo le le bosweu jo bo mo magareng',
    '👷🏽‍♂' => 'modiri wa monna mo kagong: letlalo la mmala o o mo magareng',
    '👷🏾‍♂' => 'modiri wa monna mo kagong: letlalo la mmala wa bontsho jo bo mo magareng',
    '👷🏿‍♂' => 'modiri wa monna mo kagong: letlalo la mmala o montsho',
    '👷🏻‍♀' => 'modiri wa mosadi mo kagong: letlalo le lesweu',
    '👷🏼‍♀' => 'modiri wa mosadi mo kagong: letlalo le le bosweu jo bo mo magareng',
    '👷🏽‍♀' => 'modiri wa mosadi mo kagong: letlalo la mmala o o mo magareng',
    '👷🏾‍♀' => 'modiri wa mosadi mo kagong: letlalo la mmala wa bontsho jo bo mo magareng',
    '👷🏿‍♀' => 'modiri wa mosadi mo kagong: letlalo la mmala o montsho',
    '👳🏻‍♂' => 'monna a rwele sehapatlhogo: letlalo le lesweu',
    '👳🏼‍♂' => 'monna a rwele sehapatlhogo: letlalo le le bosweu jo bo mo magareng',
    '👳🏽‍♂' => 'monna a rwele sehapatlhogo: letlalo la mmala o o mo magareng',
    '👳🏾‍♂' => 'monna a rwele sehapatlhogo: letlalo la mmala wa bontsho jo bo mo magareng',
    '👳🏿‍♂' => 'monna a rwele sehapatlhogo: letlalo la mmala o montsho',
    '👳🏻‍♀' => 'mosadi a rwele sehapatlhogo: letlalo le lesweu',
    '👳🏼‍♀' => 'mosadi a rwele sehapatlhogo: letlalo le le bosweu jo bo mo magareng',
    '👳🏽‍♀' => 'mosadi a rwele sehapatlhogo: letlalo la mmala o o mo magareng',
    '👳🏾‍♀' => 'mosadi a rwele sehapatlhogo: letlalo la mmala wa bontsho jo bo mo magareng',
    '👳🏿‍♀' => 'mosadi a rwele sehapatlhogo: letlalo la mmala o montsho',
    '🧙🏻‍♂' => 'matwetwe wa monna: letlalo le lesweu',
    '🧙🏼‍♂' => 'matwetwe wa monna: letlalo le le bosweu jo bo mo magareng',
    '🧙🏽‍♂' => 'matwetwe wa monna: letlalo la mmala o o mo magareng',
    '🧙🏾‍♂' => 'matwetwe wa monna: letlalo la mmala wa bontsho jo bo mo magareng',
    '🧙🏿‍♂' => 'matwetwe wa monna: letlalo la mmala o montsho',
    '🧙🏻‍♀' => 'matwetwe wa mosadi: letlalo le lesweu',
    '🧙🏼‍♀' => 'matwetwe wa mosadi: letlalo le le bosweu jo bo mo magareng',
    '🧙🏽‍♀' => 'matwetwe wa mosadi: letlalo la mmala o o mo magareng',
    '🧙🏾‍♀' => 'matwetwe wa mosadi: letlalo la mmala wa bontsho jo bo mo magareng',
    '🧙🏿‍♀' => 'matwetwe wa mosadi: letlalo la mmala o montsho',
    '🧚🏻‍♂' => 'motho wa ditlhamane wa monna: letlalo le lesweu',
    '🧚🏼‍♂' => 'motho wa ditlhamane wa monna: letlalo le le bosweu jo bo mo magareng',
    '🧚🏽‍♂' => 'motho wa ditlhamane wa monna: letlalo la mmala o o mo magareng',
    '🧚🏾‍♂' => 'motho wa ditlhamane wa monna: letlalo la mmala wa bontsho jo bo mo magareng',
    '🧚🏿‍♂' => 'motho wa ditlhamane wa monna: letlalo la mmala o montsho',
    '🧚🏻‍♀' => 'motho wa ditlhamane wa mosadi: letlalo le lesweu',
    '🧚🏼‍♀' => 'motho wa ditlhamane wa mosadi: letlalo le le bosweu jo bo mo magareng',
    '🧚🏽‍♀' => 'motho wa ditlhamane wa mosadi: letlalo la mmala o o mo magareng',
    '🧚🏾‍♀' => 'motho wa ditlhamane wa mosadi: letlalo la mmala wa bontsho jo bo mo magareng',
    '🧚🏿‍♀' => 'motho wa ditlhamane wa mosadi: letlalo la mmala o montsho',
    '🧛🏻‍♂' => 'mmamathwane wa vampire wa monna: letlalo le lesweu',
    '🧛🏼‍♂' => 'mmamathwane wa vampire wa monna: letlalo le le bosweu jo bo mo magareng',
    '🧛🏽‍♂' => 'mmamathwane wa vampire wa monna: letlalo la mmala o o mo magareng',
    '🧛🏾‍♂' => 'mmamathwane wa vampire wa monna: letlalo la mmala wa bontsho jo bo mo magareng',
    '🧛🏿‍♂' => 'mmamathwane wa vampire wa monna: letlalo la mmala o montsho',
    '🧛🏻‍♀' => 'mmamathwane wa vampire wa mosadi: letlalo le lesweu',
    '🧛🏼‍♀' => 'mmamathwane wa vampire wa mosadi: letlalo le le bosweu jo bo mo magareng',
    '🧛🏽‍♀' => 'mmamathwane wa vampire wa mosadi: letlalo la mmala o o mo magareng',
    '🧛🏾‍♀' => 'mmamathwane wa vampire wa mosadi: letlalo la mmala wa bontsho jo bo mo magareng',
    '🧛🏿‍♀' => 'mmamathwane wa vampire wa mosadi: letlalo la mmala o montsho',
    '🧜🏻‍♂' => 'monna wa tlhamane: letlalo le lesweu',
    '🧜🏼‍♂' => 'monna wa tlhamane: letlalo le le bosweu jo bo mo magareng',
    '🧜🏽‍♂' => 'monna wa tlhamane: letlalo la mmala o o mo magareng',
    '🧜🏾‍♂' => 'monna wa tlhamane: letlalo la mmala wa bontsho jo bo mo magareng',
    '🧜🏿‍♂' => 'monna wa tlhamane: letlalo la mmala o montsho',
    '🧜🏻‍♀' => 'modiri wa mosadi wa tlhamane: letlalo le lesweu',
    '🧜🏼‍♀' => 'modiri wa mosadi wa tlhamane: letlalo le le bosweu jo bo mo magareng',
    '🧜🏽‍♀' => 'modiri wa mosadi wa tlhamane: letlalo la mmala o o mo magareng',
    '🧜🏾‍♀' => 'modiri wa mosadi wa tlhamane: letlalo la mmala wa bontsho jo bo mo magareng',
    '🧜🏿‍♀' => 'modiri wa mosadi wa tlhamane: letlalo la mmala o montsho',
    '🧝🏻‍♂' => 'monna wa mankge mo ditlhamaneng: letlalo le lesweu',
    '🧝🏼‍♂' => 'monna wa mankge mo ditlhamaneng: letlalo le le bosweu jo bo mo magareng',
    '🧝🏽‍♂' => 'monna wa mankge mo ditlhamaneng: letlalo la mmala o o mo magareng',
    '🧝🏾‍♂' => 'monna wa mankge mo ditlhamaneng: letlalo la mmala wa bontsho jo bo mo magareng',
    '🧝🏿‍♂' => 'monna wa mankge mo ditlhamaneng: letlalo la mmala o montsho',
    '🧝🏻‍♀' => 'mosadi wa mankge mo ditlhamaneng: letlalo le lesweu',
    '🧝🏼‍♀' => 'mosadi wa mankge mo ditlhamaneng: letlalo le le bosweu jo bo mo magareng',
    '🧝🏽‍♀' => 'mosadi wa mankge mo ditlhamaneng: letlalo la mmala o o mo magareng',
    '🧝🏾‍♀' => 'mosadi wa mankge mo ditlhamaneng: letlalo la mmala wa bontsho jo bo mo magareng',
    '🧝🏿‍♀' => 'mosadi wa mankge mo ditlhamaneng: letlalo la mmala o montsho',
    '💆🏻‍♂' => 'monna yo o bonang tshidilo: letlalo le lesweu',
    '💆🏼‍♂' => 'monna yo o bonang tshidilo: letlalo le le bosweu jo bo mo magareng',
    '💆🏽‍♂' => 'monna yo o bonang tshidilo: letlalo la mmala o o mo magareng',
    '💆🏾‍♂' => 'monna yo o bonang tshidilo: letlalo la mmala wa bontsho jo bo mo magareng',
    '💆🏿‍♂' => 'monna yo o bonang tshidilo: letlalo la mmala o montsho',
    '💆🏻‍♀' => 'mosadi yo o bonang tshidilo: letlalo le lesweu',
    '💆🏼‍♀' => 'mosadi yo o bonang tshidilo: letlalo le le bosweu jo bo mo magareng',
    '💆🏽‍♀' => 'mosadi yo o bonang tshidilo: letlalo la mmala o o mo magareng',
    '💆🏾‍♀' => 'mosadi yo o bonang tshidilo: letlalo la mmala wa bontsho jo bo mo magareng',
    '💆🏿‍♀' => 'mosadi yo o bonang tshidilo: letlalo la mmala o montsho',
    '💇🏻‍♂' => 'monna yo o beolang moriri: letlalo le lesweu',
    '💇🏼‍♂' => 'monna yo o beolang moriri: letlalo le le bosweu jo bo mo magareng',
    '💇🏽‍♂' => 'monna yo o beolang moriri: letlalo la mmala o o mo magareng',
    '💇🏾‍♂' => 'monna yo o beolang moriri: letlalo la mmala wa bontsho jo bo mo magareng',
    '💇🏿‍♂' => 'monna yo o beolang moriri: letlalo la mmala o montsho',
    '💇🏻‍♀' => 'mosadi yo o beolang moriri: letlalo le lesweu',
    '💇🏼‍♀' => 'mosadi yo o beolang moriri: letlalo le le bosweu jo bo mo magareng',
    '💇🏽‍♀' => 'mosadi yo o beolang moriri: letlalo la mmala o o mo magareng',
    '💇🏾‍♀' => 'mosadi yo o beolang moriri: letlalo la mmala wa bontsho jo bo mo magareng',
    '💇🏿‍♀' => 'mosadi yo o beolang moriri: letlalo la mmala o montsho',
    '🚶🏻‍♂' => 'monna yo o tsamayang: letlalo le lesweu',
    '🚶🏼‍♂' => 'monna yo o tsamayang: letlalo le le bosweu jo bo mo magareng',
    '🚶🏽‍♂' => 'monna yo o tsamayang: letlalo la mmala o o mo magareng',
    '🚶🏾‍♂' => 'monna yo o tsamayang: letlalo la mmala wa bontsho jo bo mo magareng',
    '🚶🏿‍♂' => 'monna yo o tsamayang: letlalo la mmala o montsho',
    '🚶🏻‍♀' => 'mosadi yo o tsamayang: letlalo le lesweu',
    '🚶🏼‍♀' => 'mosadi yo o tsamayang: letlalo le le bosweu jo bo mo magareng',
    '🚶🏽‍♀' => 'mosadi yo o tsamayang: letlalo la mmala o o mo magareng',
    '🚶🏾‍♀' => 'mosadi yo o tsamayang: letlalo la mmala wa bontsho jo bo mo magareng',
    '🚶🏿‍♀' => 'mosadi yo o tsamayang: letlalo la mmala o montsho',
    '🏃🏻‍♂' => 'monna yo o tabogang: letlalo le lesweu',
    '🏃🏼‍♂' => 'monna yo o tabogang: letlalo le le bosweu jo bo mo magareng',
    '🏃🏽‍♂' => 'monna yo o tabogang: letlalo la mmala o o mo magareng',
    '🏃🏾‍♂' => 'monna yo o tabogang: letlalo la mmala wa bontsho jo bo mo magareng',
    '🏃🏿‍♂' => 'monna yo o tabogang: letlalo la mmala o montsho',
    '🏃🏻‍♀' => 'mosadi yo o tabogang: letlalo le lesweu',
    '🏃🏼‍♀' => 'mosadi yo o tabogang: letlalo le le bosweu jo bo mo magareng',
    '🏃🏽‍♀' => 'mosadi yo o tabogang: letlalo la mmala o o mo magareng',
    '🏃🏾‍♀' => 'mosadi yo o tabogang: letlalo la mmala wa bontsho jo bo mo magareng',
    '🏃🏿‍♀' => 'mosadi yo o tabogang: letlalo la mmala o montsho',
    '👯🏻‍♀' => 'basadi ka ditsebe tsa mmutla mo moletlong: letlalo le lesweu',
    '👯🏼‍♀' => 'basadi ka ditsebe tsa mmutla mo moletlong: letlalo le le bosweu jo bo mo magareng',
    '👯🏽‍♀' => 'basadi ka ditsebe tsa mmutla mo moletlong: letlalo la mmala o o mo magareng',
    '👯🏾‍♀' => 'basadi ka ditsebe tsa mmutla mo moletlong: letlalo la mmala wa bontsho jo bo mo magareng',
    '👯🏿‍♀' => 'basadi ka ditsebe tsa mmutla mo moletlong: letlalo la mmala o montsho',
    '👯🏻‍♂' => 'banna ka ditsebe tsa mmutla mo moletlong: letlalo le lesweu',
    '👯🏼‍♂' => 'banna ka ditsebe tsa mmutla mo moletlong: letlalo le le bosweu jo bo mo magareng',
    '👯🏽‍♂' => 'banna ka ditsebe tsa mmutla mo moletlong: letlalo la mmala o o mo magareng',
    '👯🏾‍♂' => 'banna ka ditsebe tsa mmutla mo moletlong: letlalo la mmala wa bontsho jo bo mo magareng',
    '👯🏿‍♂' => 'banna ka ditsebe tsa mmutla mo moletlong: letlalo la mmala o montsho',
    '🧖🏻‍♂' => 'monna mo kamoreng ya metsi a a belang: letlalo le lesweu',
    '🧖🏼‍♂' => 'monna mo kamoreng ya metsi a a belang: letlalo le le bosweu jo bo mo magareng',
    '🧖🏽‍♂' => 'monna mo kamoreng ya metsi a a belang: letlalo la mmala o o mo magareng',
    '🧖🏾‍♂' => 'monna mo kamoreng ya metsi a a belang: letlalo la mmala wa bontsho jo bo mo magareng',
    '🧖🏿‍♂' => 'monna mo kamoreng ya metsi a a belang: letlalo la mmala o montsho',
    '🧖🏻‍♀' => 'mosadi mo kamoreng ya metsi a a belang: letlalo le lesweu',
    '🧖🏼‍♀' => 'mosadi mo kamoreng ya metsi a a belang: letlalo le le bosweu jo bo mo magareng',
    '🧖🏽‍♀' => 'mosadi mo kamoreng ya metsi a a belang: letlalo la mmala o o mo magareng',
    '🧖🏾‍♀' => 'mosadi mo kamoreng ya metsi a a belang: letlalo la mmala wa bontsho jo bo mo magareng',
    '🧖🏿‍♀' => 'mosadi mo kamoreng ya metsi a a belang: letlalo la mmala o montsho',
    '🧗🏻‍♂' => 'monna yo o palamang: letlalo le lesweu',
    '🧗🏼‍♂' => 'monna yo o palamang: letlalo le le bosweu jo bo mo magareng',
    '🧗🏽‍♂' => 'monna yo o palamang: letlalo la mmala o o mo magareng',
    '🧗🏾‍♂' => 'monna yo o palamang: letlalo la mmala wa bontsho jo bo mo magareng',
    '🧗🏿‍♂' => 'monna yo o palamang: letlalo la mmala o montsho',
    '🧗🏻‍♀' => 'mosadi yo o palamang: letlalo le lesweu',
    '🧗🏼‍♀' => 'mosadi yo o palamang: letlalo le le bosweu jo bo mo magareng',
    '🧗🏽‍♀' => 'mosadi yo o palamang: letlalo la mmala o o mo magareng',
    '🧗🏾‍♀' => 'mosadi yo o palamang: letlalo la mmala wa bontsho jo bo mo magareng',
    '🧗🏿‍♀' => 'mosadi yo o palamang: letlalo la mmala o montsho',
    '🏌🏻‍♂' => 'monna yo o tshamekang kolofo: letlalo le lesweu',
    '🏌🏼‍♂' => 'monna yo o tshamekang kolofo: letlalo le le bosweu jo bo mo magareng',
    '🏌🏽‍♂' => 'monna yo o tshamekang kolofo: letlalo la mmala o o mo magareng',
    '🏌🏾‍♂' => 'monna yo o tshamekang kolofo: letlalo la mmala wa bontsho jo bo mo magareng',
    '🏌🏿‍♂' => 'monna yo o tshamekang kolofo: letlalo la mmala o montsho',
    '🏌🏻‍♀' => 'mosadi yo o tshamekang kolofo: letlalo le lesweu',
    '🏌🏼‍♀' => 'mosadi yo o tshamekang kolofo: letlalo le le bosweu jo bo mo magareng',
    '🏌🏽‍♀' => 'mosadi yo o tshamekang kolofo: letlalo la mmala o o mo magareng',
    '🏌🏾‍♀' => 'mosadi yo o tshamekang kolofo: letlalo la mmala wa bontsho jo bo mo magareng',
    '🏌🏿‍♀' => 'mosadi yo o tshamekang kolofo: letlalo la mmala o montsho',
    '🏄🏻‍♂' => 'monna yo o lelemelang: letlalo le lesweu',
    '🏄🏼‍♂' => 'monna yo o lelemelang: letlalo le le bosweu jo bo mo magareng',
    '🏄🏽‍♂' => 'monna yo o lelemelang: letlalo la mmala o o mo magareng',
    '🏄🏾‍♂' => 'monna yo o lelemelang: letlalo la mmala wa bontsho jo bo mo magareng',
    '🏄🏿‍♂' => 'monna yo o lelemelang: letlalo la mmala o montsho',
    '🏄🏻‍♀' => 'mosadi yo o lelemelang: letlalo le lesweu',
    '🏄🏼‍♀' => 'mosadi yo o lelemelang: letlalo le le bosweu jo bo mo magareng',
    '🏄🏽‍♀' => 'mosadi yo o lelemelang: letlalo la mmala o o mo magareng',
    '🏄🏾‍♀' => 'mosadi yo o lelemelang: letlalo la mmala wa bontsho jo bo mo magareng',
    '🏄🏿‍♀' => 'mosadi yo o lelemelang: letlalo la mmala o montsho',
    '🚣🏻‍♂' => 'monna yo o kgweetsang mokoro: letlalo le lesweu',
    '🚣🏼‍♂' => 'monna yo o kgweetsang mokoro: letlalo le le bosweu jo bo mo magareng',
    '🚣🏽‍♂' => 'monna yo o kgweetsang mokoro: letlalo la mmala o o mo magareng',
    '🚣🏾‍♂' => 'monna yo o kgweetsang mokoro: letlalo la mmala wa bontsho jo bo mo magareng',
    '🚣🏿‍♂' => 'monna yo o kgweetsang mokoro: letlalo la mmala o montsho',
    '🚣🏻‍♀' => 'mosadi yo o kgweetsang mokoro: letlalo le lesweu',
    '🚣🏼‍♀' => 'mosadi yo o kgweetsang mokoro: letlalo le le bosweu jo bo mo magareng',
    '🚣🏽‍♀' => 'mosadi yo o kgweetsang mokoro: letlalo la mmala o o mo magareng',
    '🚣🏾‍♀' => 'mosadi yo o kgweetsang mokoro: letlalo la mmala wa bontsho jo bo mo magareng',
    '🚣🏿‍♀' => 'mosadi yo o kgweetsang mokoro: letlalo la mmala o montsho',
    '🏊🏻‍♂' => 'monna yo o thumang: letlalo le lesweu',
    '🏊🏼‍♂' => 'monna yo o thumang: letlalo le le bosweu jo bo mo magareng',
    '🏊🏽‍♂' => 'monna yo o thumang: letlalo la mmala o o mo magareng',
    '🏊🏾‍♂' => 'monna yo o thumang: letlalo la mmala wa bontsho jo bo mo magareng',
    '🏊🏿‍♂' => 'monna yo o thumang: letlalo la mmala o montsho',
    '🏊🏻‍♀' => 'mosadi yo o thumang: letlalo le lesweu',
    '🏊🏼‍♀' => 'mosadi yo o thumang: letlalo le le bosweu jo bo mo magareng',
    '🏊🏽‍♀' => 'mosadi yo o thumang: letlalo la mmala o o mo magareng',
    '🏊🏾‍♀' => 'mosadi yo o thumang: letlalo la mmala wa bontsho jo bo mo magareng',
    '🏊🏿‍♀' => 'mosadi yo o thumang: letlalo la mmala o montsho',
    '⛹🏻‍♂' => 'monna yo o itaaganyang bolo fa fatshe: letlalo le lesweu',
    '⛹🏼‍♂' => 'monna yo o itaaganyang bolo fa fatshe: letlalo le le bosweu jo bo mo magareng',
    '⛹🏽‍♂' => 'monna yo o itaaganyang bolo fa fatshe: letlalo la mmala o o mo magareng',
    '⛹🏾‍♂' => 'monna yo o itaaganyang bolo fa fatshe: letlalo la mmala wa bontsho jo bo mo magareng',
    '⛹🏿‍♂' => 'monna yo o itaaganyang bolo fa fatshe: letlalo la mmala o montsho',
    '⛹🏻‍♀' => 'mosadi yo o itaaganyang bolo fa fatshe: letlalo le lesweu',
    '⛹🏼‍♀' => 'mosadi yo o itaaganyang bolo fa fatshe: letlalo le le bosweu jo bo mo magareng',
    '⛹🏽‍♀' => 'mosadi yo o itaaganyang bolo fa fatshe: letlalo la mmala o o mo magareng',
    '⛹🏾‍♀' => 'mosadi yo o itaaganyang bolo fa fatshe: letlalo la mmala wa bontsho jo bo mo magareng',
    '⛹🏿‍♀' => 'mosadi yo o itaaganyang bolo fa fatshe: letlalo la mmala o montsho',
    '🏋🏻‍♂' => 'monna yo o tsholetsang ditshipi: letlalo le lesweu',
    '🏋🏼‍♂' => 'monna yo o tsholetsang ditshipi: letlalo le le bosweu jo bo mo magareng',
    '🏋🏽‍♂' => 'monna yo o tsholetsang ditshipi: letlalo la mmala o o mo magareng',
    '🏋🏾‍♂' => 'monna yo o tsholetsang ditshipi: letlalo la mmala wa bontsho jo bo mo magareng',
    '🏋🏿‍♂' => 'monna yo o tsholetsang ditshipi: letlalo la mmala o montsho',
    '🏋🏻‍♀' => 'mosadi yo o tsholetsang ditshipi: letlalo le lesweu',
    '🏋🏼‍♀' => 'mosadi yo o tsholetsang ditshipi: letlalo le le bosweu jo bo mo magareng',
    '🏋🏽‍♀' => 'mosadi yo o tsholetsang ditshipi: letlalo la mmala o o mo magareng',
    '🏋🏾‍♀' => 'mosadi yo o tsholetsang ditshipi: letlalo la mmala wa bontsho jo bo mo magareng',
    '🏋🏿‍♀' => 'mosadi yo o tsholetsang ditshipi: letlalo la mmala o montsho',
    '🚴🏻‍♂' => 'monna yo o kgweetsang baesekele: letlalo le lesweu',
    '🚴🏼‍♂' => 'monna yo o kgweetsang baesekele: letlalo le le bosweu jo bo mo magareng',
    '🚴🏽‍♂' => 'monna yo o kgweetsang baesekele: letlalo la mmala o o mo magareng',
    '🚴🏾‍♂' => 'monna yo o kgweetsang baesekele: letlalo la mmala wa bontsho jo bo mo magareng',
    '🚴🏿‍♂' => 'monna yo o kgweetsang baesekele: letlalo la mmala o montsho',
    '🚴🏻‍♀' => 'mosadi yo o kgweetsang baesekele: letlalo le lesweu',
    '🚴🏼‍♀' => 'mosadi yo o kgweetsang baesekele: letlalo le le bosweu jo bo mo magareng',
    '🚴🏽‍♀' => 'mosadi yo o kgweetsang baesekele: letlalo la mmala o o mo magareng',
    '🚴🏾‍♀' => 'mosadi yo o kgweetsang baesekele: letlalo la mmala wa bontsho jo bo mo magareng',
    '🚴🏿‍♀' => 'mosadi yo o kgweetsang baesekele: letlalo la mmala o montsho',
    '🚵🏻‍♂' => 'monna yo o kgweetsang sekuta mo thabeng: letlalo le lesweu',
    '🚵🏼‍♂' => 'monna yo o kgweetsang sekuta mo thabeng: letlalo le le bosweu jo bo mo magareng',
    '🚵🏽‍♂' => 'monna yo o kgweetsang sekuta mo thabeng: letlalo la mmala o o mo magareng',
    '🚵🏾‍♂' => 'monna yo o kgweetsang sekuta mo thabeng: letlalo la mmala wa bontsho jo bo mo magareng',
    '🚵🏿‍♂' => 'monna yo o kgweetsang sekuta mo thabeng: letlalo la mmala o montsho',
    '🚵🏻‍♀' => 'mosadi yo o kgweetsang sekuta mo thabeng: letlalo le lesweu',
    '🚵🏼‍♀' => 'mosadi yo o kgweetsang sekuta mo thabeng: letlalo le le bosweu jo bo mo magareng',
    '🚵🏽‍♀' => 'mosadi yo o kgweetsang sekuta mo thabeng: letlalo la mmala o o mo magareng',
    '🚵🏾‍♀' => 'mosadi yo o kgweetsang sekuta mo thabeng: letlalo la mmala wa bontsho jo bo mo magareng',
    '🚵🏿‍♀' => 'mosadi yo o kgweetsang sekuta mo thabeng: letlalo la mmala o montsho',
    '🤸🏻‍♂' => 'monna yo o tsamaisang kolotsana: letlalo le lesweu',
    '🤸🏼‍♂' => 'monna yo o tsamaisang kolotsana: letlalo le le bosweu jo bo mo magareng',
    '🤸🏽‍♂' => 'monna yo o tsamaisang kolotsana: letlalo la mmala o o mo magareng',
    '🤸🏾‍♂' => 'monna yo o tsamaisang kolotsana: letlalo la mmala wa bontsho jo bo mo magareng',
    '🤸🏿‍♂' => 'monna yo o tsamaisang kolotsana: letlalo la mmala o montsho',
    '🤸🏻‍♀' => 'mosadi yo o tsamaisang kolotsana: letlalo le lesweu',
    '🤸🏼‍♀' => 'mosadi yo o tsamaisang kolotsana: letlalo le le bosweu jo bo mo magareng',
    '🤸🏽‍♀' => 'mosadi yo o tsamaisang kolotsana: letlalo la mmala o o mo magareng',
    '🤸🏾‍♀' => 'mosadi yo o tsamaisang kolotsana: letlalo la mmala wa bontsho jo bo mo magareng',
    '🤸🏿‍♀' => 'mosadi yo o tsamaisang kolotsana: letlalo la mmala o montsho',
    '🤼🏻‍♀' => 'basadi ba ba lwang ka go mekamekana: letlalo le lesweu',
    '🤼🏼‍♀' => 'basadi ba ba lwang ka go mekamekana: letlalo le le bosweu jo bo mo magareng',
    '🤼🏽‍♀' => 'basadi ba ba lwang ka go mekamekana: letlalo la mmala o o mo magareng',
    '🤼🏾‍♀' => 'basadi ba ba lwang ka go mekamekana: letlalo la mmala wa bontsho jo bo mo magareng',
    '🤼🏿‍♀' => 'basadi ba ba lwang ka go mekamekana: letlalo la mmala o montsho',
    '🤼🏻‍♂' => 'banna ba ba lwang ka go mekamekana: letlalo le lesweu',
    '🤼🏼‍♂' => 'banna ba ba lwang ka go mekamekana: letlalo le le bosweu jo bo mo magareng',
    '🤼🏽‍♂' => 'banna ba ba lwang ka go mekamekana: letlalo la mmala o o mo magareng',
    '🤼🏾‍♂' => 'banna ba ba lwang ka go mekamekana: letlalo la mmala wa bontsho jo bo mo magareng',
    '🤼🏿‍♂' => 'banna ba ba lwang ka go mekamekana: letlalo la mmala o montsho',
    '🤽🏻‍♂' => 'monna yo o tshamekang polo ya metsi: letlalo le lesweu',
    '🤽🏼‍♂' => 'monna yo o tshamekang polo ya metsi: letlalo le le bosweu jo bo mo magareng',
    '🤽🏽‍♂' => 'monna yo o tshamekang polo ya metsi: letlalo la mmala o o mo magareng',
    '🤽🏾‍♂' => 'monna yo o tshamekang polo ya metsi: letlalo la mmala wa bontsho jo bo mo magareng',
    '🤽🏿‍♂' => 'monna yo o tshamekang polo ya metsi: letlalo la mmala o montsho',
    '🤽🏻‍♀' => 'mosadi yo o tshamekang polo ya metsi: letlalo le lesweu',
    '🤽🏼‍♀' => 'mosadi yo o tshamekang polo ya metsi: letlalo le le bosweu jo bo mo magareng',
    '🤽🏽‍♀' => 'mosadi yo o tshamekang polo ya metsi: letlalo la mmala o o mo magareng',
    '🤽🏾‍♀' => 'mosadi yo o tshamekang polo ya metsi: letlalo la mmala wa bontsho jo bo mo magareng',
    '🤽🏿‍♀' => 'mosadi yo o tshamekang polo ya metsi: letlalo la mmala o montsho',
    '🤾🏻‍♂' => 'monna yo o tshamekang bolo ya letsogo: letlalo le lesweu',
    '🤾🏼‍♂' => 'monna yo o tshamekang bolo ya letsogo: letlalo le le bosweu jo bo mo magareng',
    '🤾🏽‍♂' => 'monna yo o tshamekang bolo ya letsogo: letlalo la mmala o o mo magareng',
    '🤾🏾‍♂' => 'monna yo o tshamekang bolo ya letsogo: letlalo la mmala wa bontsho jo bo mo magareng',
    '🤾🏿‍♂' => 'monna yo o tshamekang bolo ya letsogo: letlalo la mmala o montsho',
    '🤾🏻‍♀' => 'mosadi yo o tshamekang bolo ya letsogo: letlalo le lesweu',
    '🤾🏼‍♀' => 'mosadi yo o tshamekang bolo ya letsogo: letlalo le le bosweu jo bo mo magareng',
    '🤾🏽‍♀' => 'mosadi yo o tshamekang bolo ya letsogo: letlalo la mmala o o mo magareng',
    '🤾🏾‍♀' => 'mosadi yo o tshamekang bolo ya letsogo: letlalo la mmala wa bontsho jo bo mo magareng',
    '🤾🏿‍♀' => 'mosadi yo o tshamekang bolo ya letsogo: letlalo la mmala o montsho',
    '🤹🏻‍♂' => 'monna yo o mekamekanang le dilo dintsi: letlalo le lesweu',
    '🤹🏼‍♂' => 'monna yo o mekamekanang le dilo dintsi: letlalo le le bosweu jo bo mo magareng',
    '🤹🏽‍♂' => 'monna yo o mekamekanang le dilo dintsi: letlalo la mmala o o mo magareng',
    '🤹🏾‍♂' => 'monna yo o mekamekanang le dilo dintsi: letlalo la mmala wa bontsho jo bo mo magareng',
    '🤹🏿‍♂' => 'monna yo o mekamekanang le dilo dintsi: letlalo la mmala o montsho',
    '🤹🏻‍♀' => 'mosadi yo o mekamekanang le dilo dintsi: letlalo le lesweu',
    '🤹🏼‍♀' => 'mosadi yo o mekamekanang le dilo dintsi: letlalo le le bosweu jo bo mo magareng',
    '🤹🏽‍♀' => 'mosadi yo o mekamekanang le dilo dintsi: letlalo la mmala o o mo magareng',
    '🤹🏾‍♀' => 'mosadi yo o mekamekanang le dilo dintsi: letlalo la mmala wa bontsho jo bo mo magareng',
    '🤹🏿‍♀' => 'mosadi yo o mekamekanang le dilo dintsi: letlalo la mmala o montsho',
    '🧘🏻‍♂' => 'monna mo boemong jwa lotus: letlalo le lesweu',
    '🧘🏼‍♂' => 'monna mo boemong jwa lotus: letlalo le le bosweu jo bo mo magareng',
    '🧘🏽‍♂' => 'monna mo boemong jwa lotus: letlalo la mmala o o mo magareng',
    '🧘🏾‍♂' => 'monna mo boemong jwa lotus: letlalo la mmala wa bontsho jo bo mo magareng',
    '🧘🏿‍♂' => 'monna mo boemong jwa lotus: letlalo la mmala o montsho',
    '🧘🏻‍♀' => 'mosadi mo boemong jwa lotus: letlalo le lesweu',
    '🧘🏼‍♀' => 'mosadi mo boemong jwa lotus: letlalo le le bosweu jo bo mo magareng',
    '🧘🏽‍♀' => 'mosadi mo boemong jwa lotus: letlalo la mmala o o mo magareng',
    '🧘🏾‍♀' => 'mosadi mo boemong jwa lotus: letlalo la mmala wa bontsho jo bo mo magareng',
    '🧘🏿‍♀' => 'mosadi mo boemong jwa lotus: letlalo la mmala o montsho',
    '👨‍👦' => 'lelapa: monna, mosimane',
    '👨‍👧' => 'lelapa: monna, mosetsana',
    '👩‍👦' => 'lelapa: mosadi, mosimane',
    '👩‍👧' => 'lelapa: mosadi, mosetsana',
    '👁‍🗨' => 'leitlho mo puduleng ya puo',
    '👱‍♂' => 'monna wa moriri o mosetlha',
    '👱‍♀' => 'mosadi wa moriri o mosetlha',
    '🙍‍♂' => 'monna yo o menneng phatla',
    '🙍‍♀' => 'mosadi yo o menneng phatla',
    '🙎‍♂' => 'monna yo o tsuputseng molomo',
    '🙎‍♀' => 'mosadi yo o tsuputseng molomo',
    '🙅‍♂' => 'monna yo o reng NNYAA ka puo ya matsogo',
    '🙅‍♀' => 'mosadi yo o reng NNYAA ka puo ya matsogo',
    '🙆‍♂' => 'monna yo o reng GO SIAME ka puo ya matsogo',
    '🙆‍♀' => 'mosadi yo o reng GO SIAME ka puo ya matsogo',
    '💁‍♂' => 'monna a sekamisa letsogo',
    '💁‍♀' => 'mosadi a sekamisa letsogo',
    '🙋‍♂' => 'monna a tsholetsa letsogo',
    '🙋‍♀' => 'mosadi a tsholetsa letsogo',
    '🙇‍♂' => 'monna a obega',
    '🙇‍♀' => 'mosadi a obega',
    '🤦‍♂' => 'monna ka legofi mo sefatlhegong',
    '🤦‍♀' => 'mosadi ka legofi mo sefatlhegong',
    '🤷‍♂' => 'monna yo o tsholetsang magetla',
    '🤷‍♀' => 'mosadi yo o tsholetsang magetla',
    '👨‍⚕' => 'modiri wa tsa botsogo wa monna',
    '👩‍⚕' => 'modiri wa tsa botsogo wa mosadi',
    '👨‍🎓' => 'seithuti sa monna',
    '👩‍🎓' => 'seithuti sa mosadi',
    '👨‍🏫' => 'morutisi wa monna',
    '👩‍🏫' => 'morutisi wa mosadi',
    '👨‍⚖' => 'moatlhodi wa monna',
    '👩‍⚖' => 'moatlhodi wa mosadi',
    '👨‍🌾' => 'molemirui wa monna',
    '👩‍🌾' => 'molemirui wa mosadi',
    '👨‍🍳' => 'moapei wa monna',
    '👩‍🍳' => 'moapei wa mosadi',
    '👨‍🔧' => 'mekheniki wa monna',
    '👩‍🔧' => 'mekheniki wa mosadi',
    '👨‍🏭' => 'modiri wa bodirelo wa monna',
    '👩‍🏭' => 'modiri wa bodirelo wa mosadi',
    '👨‍💼' => 'modiri wa mo ofising wa monna',
    '👩‍💼' => 'modiri wa mo ofising wa mosadi',
    '👨‍🔬' => 'moitsesaense wa monna',
    '👩‍🔬' => 'moitsesaense wa mosadi',
    '👨‍💻' => 'moitse thekenoloji wa monna',
    '👩‍💻' => 'moitse thekenoloji wa mosadi',
    '👨‍🎤' => 'seopedi sa monna',
    '👩‍🎤' => 'seopedi sa mosadi',
    '👨‍🎨' => 'modiragatsi wa monna',
    '👩‍🎨' => 'modiragatsi wa mosadi',
    '👨‍✈' => 'mokgweetsi wa sefofane wa monna',
    '👩‍✈' => 'mokgweetsi wa sefofane wa mosadi',
    '👨‍🚀' => 'moithutadinaledi wa monna',
    '👩‍🚀' => 'moithutadinaledi wa mosadi',
    '👨‍🚒' => 'motimamolelo wa monna',
    '👩‍🚒' => 'motimamolelo wa mosadi',
    '👮‍♂' => 'lepodise la monna',
    '👮‍♀' => 'lepodise la mosadi',
    '🕵‍♂' => 'leteketifi la monna',
    '🕵‍♀' => 'leteketifi la mosadi',
    '💂‍♂' => 'modisa wa monna',
    '💂‍♀' => 'modisa wa mosadi',
    '👷‍♂' => 'modiri wa monna mo kagong',
    '👷‍♀' => 'modiri wa mosadi mo kagong',
    '👳‍♂' => 'monna a rwele sehapatlhogo',
    '👳‍♀' => 'mosadi a rwele sehapatlhogo',
    '🧙‍♂' => 'matwetwe wa monna',
    '🧙‍♀' => 'matwetwe wa mosadi',
    '🧚‍♂' => 'motho wa ditlhamane wa monna',
    '🧚‍♀' => 'motho wa ditlhamane wa mosadi',
    '🧛‍♂' => 'mmamathwane wa vampire wa monna',
    '🧛‍♀' => 'mmamathwane wa vampire wa mosadi',
    '🧜‍♂' => 'monna wa tlhamane',
    '🧜‍♀' => 'modiri wa mosadi wa tlhamane',
    '🧝‍♂' => 'monna wa mankge mo ditlhamaneng',
    '🧝‍♀' => 'mosadi wa mankge mo ditlhamaneng',
    '🧞‍♂' => 'monna wa moengele wa tlhamane',
    '🧞‍♀' => 'mosadi wa moengele wa tlhamane',
    '🧟‍♂' => 'sombi wa monna',
    '🧟‍♀' => 'sombi wa mosadi',
    '💆‍♂' => 'monna yo o bonang tshidilo',
    '💆‍♀' => 'mosadi yo o bonang tshidilo',
    '💇‍♂' => 'monna yo o beolang moriri',
    '💇‍♀' => 'mosadi yo o beolang moriri',
    '🚶‍♂' => 'monna yo o tsamayang',
    '🚶‍♀' => 'mosadi yo o tsamayang',
    '🏃‍♂' => 'monna yo o tabogang',
    '🏃‍♀' => 'mosadi yo o tabogang',
    '👯‍♂' => 'banna ka ditsebe tsa mmutla mo moletlong',
    '👯‍♀' => 'basadi ka ditsebe tsa mmutla mo moletlong',
    '🧖‍♂' => 'monna mo kamoreng ya metsi a a belang',
    '🧖‍♀' => 'mosadi mo kamoreng ya metsi a a belang',
    '🧗‍♂' => 'monna yo o palamang',
    '🧗‍♀' => 'mosadi yo o palamang',
    '🏌‍♂' => 'monna yo o tshamekang kolofo',
    '🏌‍♀' => 'mosadi yo o tshamekang kolofo',
    '🏄‍♂' => 'monna yo o lelemelang',
    '🏄‍♀' => 'mosadi yo o lelemelang',
    '🚣‍♂' => 'monna yo o kgweetsang mokoro',
    '🚣‍♀' => 'mosadi yo o kgweetsang mokoro',
    '🏊‍♂' => 'monna yo o thumang',
    '🏊‍♀' => 'mosadi yo o thumang',
    '⛹‍♂' => 'monna yo o itaaganyang bolo fa fatshe',
    '⛹‍♀' => 'mosadi yo o itaaganyang bolo fa fatshe',
    '🏋‍♂' => 'monna yo o tsholetsang ditshipi',
    '🏋‍♀' => 'mosadi yo o tsholetsang ditshipi',
    '🚴‍♂' => 'monna yo o kgweetsang baesekele',
    '🚴‍♀' => 'mosadi yo o kgweetsang baesekele',
    '🚵‍♂' => 'monna yo o kgweetsang sekuta mo thabeng',
    '🚵‍♀' => 'mosadi yo o kgweetsang sekuta mo thabeng',
    '🤸‍♂' => 'monna yo o tsamaisang kolotsana',
    '🤸‍♀' => 'mosadi yo o tsamaisang kolotsana',
    '🤼‍♂' => 'banna ba ba lwang ka go mekamekana',
    '🤼‍♀' => 'basadi ba ba lwang ka go mekamekana',
    '🤽‍♂' => 'monna yo o tshamekang polo ya metsi',
    '🤽‍♀' => 'mosadi yo o tshamekang polo ya metsi',
    '🤾‍♂' => 'monna yo o tshamekang bolo ya letsogo',
    '🤾‍♀' => 'mosadi yo o tshamekang bolo ya letsogo',
    '🤹‍♂' => 'monna yo o mekamekanang le dilo dintsi',
    '🤹‍♀' => 'mosadi yo o mekamekanang le dilo dintsi',
    '🧘‍♂' => 'monna mo boemong jwa lotus',
    '🧘‍♀' => 'mosadi mo boemong jwa lotus',
    '🏳‍🌈' => 'folaga ya motshewagodimo',
    '👋🏻' => 'letsogo le le tsholeditsweng: letlalo le lesweu',
    '👋🏼' => 'letsogo le le tsholeditsweng: letlalo le le bosweu jo bo mo magareng',
    '👋🏽' => 'letsogo le le tsholeditsweng: letlalo la mmala o o mo magareng',
    '👋🏾' => 'letsogo le le tsholeditsweng: letlalo la mmala wa bontsho jo bo mo magareng',
    '👋🏿' => 'letsogo le le tsholeditsweng: letlalo la mmala o montsho',
    '🤚🏻' => 'lemorago le le kwa godimo la letsogo: letlalo le lesweu',
    '🤚🏼' => 'lemorago le le kwa godimo la letsogo: letlalo le le bosweu jo bo mo magareng',
    '🤚🏽' => 'lemorago le le kwa godimo la letsogo: letlalo la mmala o o mo magareng',
    '🤚🏾' => 'lemorago le le kwa godimo la letsogo: letlalo la mmala wa bontsho jo bo mo magareng',
    '🤚🏿' => 'lemorago le le kwa godimo la letsogo: letlalo la mmala o montsho',
    '🖐🏻' => 'letshogo le le kwa godimo ka menwana e gatogantswe: letlalo le lesweu',
    '🖐🏼' => 'letshogo le le kwa godimo ka menwana e gatogantswe: letlalo le le bosweu jo bo mo magareng',
    '🖐🏽' => 'letshogo le le kwa godimo ka menwana e gatogantswe: letlalo la mmala o o mo magareng',
    '🖐🏾' => 'letshogo le le kwa godimo ka menwana e gatogantswe: letlalo la mmala wa bontsho jo bo mo magareng',
    '🖐🏿' => 'letshogo le le kwa godimo ka menwana e gatogantswe: letlalo la mmala o montsho',
    '✋🏻' => 'letsogo le le kwa godimo: letlalo le lesweu',
    '✋🏼' => 'letsogo le le kwa godimo: letlalo le le bosweu jo bo mo magareng',
    '✋🏽' => 'letsogo le le kwa godimo: letlalo la mmala o o mo magareng',
    '✋🏾' => 'letsogo le le kwa godimo: letlalo la mmala wa bontsho jo bo mo magareng',
    '✋🏿' => 'letsogo le le kwa godimo: letlalo la mmala o montsho',
    '🖖🏻' => 'tumediso ya vulcan: letlalo le lesweu',
    '🖖🏼' => 'tumediso ya vulcan: letlalo le le bosweu jo bo mo magareng',
    '🖖🏽' => 'tumediso ya vulcan: letlalo la mmala o o mo magareng',
    '🖖🏾' => 'tumediso ya vulcan: letlalo la mmala wa bontsho jo bo mo magareng',
    '🖖🏿' => 'tumediso ya vulcan: letlalo la mmala o montsho',
    '👌🏻' => 'letsogo la GO SIAME: letlalo le lesweu',
    '👌🏼' => 'letsogo la GO SIAME: letlalo le le bosweu jo bo mo magareng',
    '👌🏽' => 'letsogo la GO SIAME: letlalo la mmala o o mo magareng',
    '👌🏾' => 'letsogo la GO SIAME: letlalo la mmala wa bontsho jo bo mo magareng',
    '👌🏿' => 'letsogo la GO SIAME: letlalo la mmala o montsho',
    '✌🏻' => 'letsogo la phenyo: letlalo le lesweu',
    '✌🏼' => 'letsogo la phenyo: letlalo le le bosweu jo bo mo magareng',
    '✌🏽' => 'letsogo la phenyo: letlalo la mmala o o mo magareng',
    '✌🏾' => 'letsogo la phenyo: letlalo la mmala wa bontsho jo bo mo magareng',
    '✌🏿' => 'letsogo la phenyo: letlalo la mmala o montsho',
    '🤞🏻' => 'fapaanya menwana: letlalo le lesweu',
    '🤞🏼' => 'fapaanya menwana: letlalo le le bosweu jo bo mo magareng',
    '🤞🏽' => 'fapaanya menwana: letlalo la mmala o o mo magareng',
    '🤞🏾' => 'fapaanya menwana: letlalo la mmala wa bontsho jo bo mo magareng',
    '🤞🏿' => 'fapaanya menwana: letlalo la mmala o montsho',
    '🤟🏻' => 'sesupo sa ke a go rata: letlalo le lesweu',
    '🤟🏼' => 'sesupo sa ke a go rata: letlalo le le bosweu jo bo mo magareng',
    '🤟🏽' => 'sesupo sa ke a go rata: letlalo la mmala o o mo magareng',
    '🤟🏾' => 'sesupo sa ke a go rata: letlalo la mmala wa bontsho jo bo mo magareng',
    '🤟🏿' => 'sesupo sa ke a go rata: letlalo la mmala o montsho',
    '🤘🏻' => 'letshwao la dinaka: letlalo le lesweu',
    '🤘🏼' => 'letshwao la dinaka: letlalo le le bosweu jo bo mo magareng',
    '🤘🏽' => 'letshwao la dinaka: letlalo la mmala o o mo magareng',
    '🤘🏾' => 'letshwao la dinaka: letlalo la mmala wa bontsho jo bo mo magareng',
    '🤘🏿' => 'letshwao la dinaka: letlalo la mmala o montsho',
    '🤙🏻' => 'letsogo la mpitsa: letlalo le lesweu',
    '🤙🏼' => 'letsogo la mpitsa: letlalo le le bosweu jo bo mo magareng',
    '🤙🏽' => 'letsogo la mpitsa: letlalo la mmala o o mo magareng',
    '🤙🏾' => 'letsogo la mpitsa: letlalo la mmala wa bontsho jo bo mo magareng',
    '🤙🏿' => 'letsogo la mpitsa: letlalo la mmala o montsho',
    '👈🏻' => 'lemorago la monwana o o supang o supile molemeng: letlalo le lesweu',
    '👈🏼' => 'lemorago la monwana o o supang o supile molemeng: letlalo le le bosweu jo bo mo magareng',
    '👈🏽' => 'lemorago la monwana o o supang o supile molemeng: letlalo la mmala o o mo magareng',
    '👈🏾' => 'lemorago la monwana o o supang o supile molemeng: letlalo la mmala wa bontsho jo bo mo magareng',
    '👈🏿' => 'lemorago la monwana o o supang o supile molemeng: letlalo la mmala o montsho',
    '👉🏻' => 'lemorago la monwana o o supang o supile mojeng: letlalo le lesweu',
    '👉🏼' => 'lemorago la monwana o o supang o supile mojeng: letlalo le le bosweu jo bo mo magareng',
    '👉🏽' => 'lemorago la monwana o o supang o supile mojeng: letlalo la mmala o o mo magareng',
    '👉🏾' => 'lemorago la monwana o o supang o supile mojeng: letlalo la mmala wa bontsho jo bo mo magareng',
    '👉🏿' => 'lemorago la monwana o o supang o supile mojeng: letlalo la mmala o montsho',
    '👆🏻' => 'lemorago la monwana o o supang o supile godimo: letlalo le lesweu',
    '👆🏼' => 'lemorago la monwana o o supang o supile godimo: letlalo le le bosweu jo bo mo magareng',
    '👆🏽' => 'lemorago la monwana o o supang o supile godimo: letlalo la mmala o o mo magareng',
    '👆🏾' => 'lemorago la monwana o o supang o supile godimo: letlalo la mmala wa bontsho jo bo mo magareng',
    '👆🏿' => 'lemorago la monwana o o supang o supile godimo: letlalo la mmala o montsho',
    '🖕🏻' => 'monwana o o mo gare: letlalo le lesweu',
    '🖕🏼' => 'monwana o o mo gare: letlalo le le bosweu jo bo mo magareng',
    '🖕🏽' => 'monwana o o mo gare: letlalo la mmala o o mo magareng',
    '🖕🏾' => 'monwana o o mo gare: letlalo la mmala wa bontsho jo bo mo magareng',
    '🖕🏿' => 'monwana o o mo gare: letlalo la mmala o montsho',
    '👇🏻' => 'lemorago la monwana o o supang o supile tlase: letlalo le lesweu',
    '👇🏼' => 'lemorago la monwana o o supang o supile tlase: letlalo le le bosweu jo bo mo magareng',
    '👇🏽' => 'lemorago la monwana o o supang o supile tlase: letlalo la mmala o o mo magareng',
    '👇🏾' => 'lemorago la monwana o o supang o supile tlase: letlalo la mmala wa bontsho jo bo mo magareng',
    '👇🏿' => 'lemorago la monwana o o supang o supile tlase: letlalo la mmala o montsho',
    '☝🏻' => 'monwana o o supang o supile sodimo: letlalo le lesweu',
    '☝🏼' => 'monwana o o supang o supile sodimo: letlalo le le bosweu jo bo mo magareng',
    '☝🏽' => 'monwana o o supang o supile sodimo: letlalo la mmala o o mo magareng',
    '☝🏾' => 'monwana o o supang o supile sodimo: letlalo la mmala wa bontsho jo bo mo magareng',
    '☝🏿' => 'monwana o o supang o supile sodimo: letlalo la mmala o montsho',
    '👍🏻' => 'bokgonojwe godimo: letlalo le lesweu',
    '👍🏼' => 'bokgonojwe godimo: letlalo le le bosweu jo bo mo magareng',
    '👍🏽' => 'bokgonojwe godimo: letlalo la mmala o o mo magareng',
    '👍🏾' => 'bokgonojwe godimo: letlalo la mmala wa bontsho jo bo mo magareng',
    '👍🏿' => 'bokgonojwe godimo: letlalo la mmala o montsho',
    '👎🏻' => 'bokgonojwe tlase: letlalo le lesweu',
    '👎🏼' => 'bokgonojwe tlase: letlalo le le bosweu jo bo mo magareng',
    '👎🏽' => 'bokgonojwe tlase: letlalo la mmala o o mo magareng',
    '👎🏾' => 'bokgonojwe tlase: letlalo la mmala wa bontsho jo bo mo magareng',
    '👎🏿' => 'bokgonojwe tlase: letlalo la mmala o montsho',
    '✊🏻' => 'lebole le le kwa godimo: letlalo le lesweu',
    '✊🏼' => 'lebole le le kwa godimo: letlalo le le bosweu jo bo mo magareng',
    '✊🏽' => 'lebole le le kwa godimo: letlalo la mmala o o mo magareng',
    '✊🏾' => 'lebole le le kwa godimo: letlalo la mmala wa bontsho jo bo mo magareng',
    '✊🏿' => 'lebole le le kwa godimo: letlalo la mmala o montsho',
    '👊🏻' => 'lebole le le tlang go wena: letlalo le lesweu',
    '👊🏼' => 'lebole le le tlang go wena: letlalo le le bosweu jo bo mo magareng',
    '👊🏽' => 'lebole le le tlang go wena: letlalo la mmala o o mo magareng',
    '👊🏾' => 'lebole le le tlang go wena: letlalo la mmala wa bontsho jo bo mo magareng',
    '👊🏿' => 'lebole le le tlang go wena: letlalo la mmala o montsho',
    '🤛🏻' => 'lebole le le lebileng molemeng: letlalo le lesweu',
    '🤛🏼' => 'lebole le le lebileng molemeng: letlalo le le bosweu jo bo mo magareng',
    '🤛🏽' => 'lebole le le lebileng molemeng: letlalo la mmala o o mo magareng',
    '🤛🏾' => 'lebole le le lebileng molemeng: letlalo la mmala wa bontsho jo bo mo magareng',
    '🤛🏿' => 'lebole le le lebileng molemeng: letlalo la mmala o montsho',
    '🤜🏻' => 'lebole le le lebileng mojeng: letlalo le lesweu',
    '🤜🏼' => 'lebole le le lebileng mojeng: letlalo le le bosweu jo bo mo magareng',
    '🤜🏽' => 'lebole le le lebileng mojeng: letlalo la mmala o o mo magareng',
    '🤜🏾' => 'lebole le le lebileng mojeng: letlalo la mmala wa bontsho jo bo mo magareng',
    '🤜🏿' => 'lebole le le lebileng mojeng: letlalo la mmala o montsho',
    '👏🏻' => 'matsogo a a opiwang: letlalo le lesweu',
    '👏🏼' => 'matsogo a a opiwang: letlalo le le bosweu jo bo mo magareng',
    '👏🏽' => 'matsogo a a opiwang: letlalo la mmala o o mo magareng',
    '👏🏾' => 'matsogo a a opiwang: letlalo la mmala wa bontsho jo bo mo magareng',
    '👏🏿' => 'matsogo a a opiwang: letlalo la mmala o montsho',
    '🙌🏻' => 'matsogo a a tsholeditsweng: letlalo le lesweu',
    '🙌🏼' => 'matsogo a a tsholeditsweng: letlalo le le bosweu jo bo mo magareng',
    '🙌🏽' => 'matsogo a a tsholeditsweng: letlalo la mmala o o mo magareng',
    '🙌🏾' => 'matsogo a a tsholeditsweng: letlalo la mmala wa bontsho jo bo mo magareng',
    '🙌🏿' => 'matsogo a a tsholeditsweng: letlalo la mmala o montsho',
    '👐🏻' => 'matsogo a a bulegileng: letlalo le lesweu',
    '👐🏼' => 'matsogo a a bulegileng: letlalo le le bosweu jo bo mo magareng',
    '👐🏽' => 'matsogo a a bulegileng: letlalo la mmala o o mo magareng',
    '👐🏾' => 'matsogo a a bulegileng: letlalo la mmala wa bontsho jo bo mo magareng',
    '👐🏿' => 'matsogo a a bulegileng: letlalo la mmala o montsho',
    '🤲🏻' => 'magofi mmogo kwa godimo: letlalo le lesweu',
    '🤲🏼' => 'magofi mmogo kwa godimo: letlalo le le bosweu jo bo mo magareng',
    '🤲🏽' => 'magofi mmogo kwa godimo: letlalo la mmala o o mo magareng',
    '🤲🏾' => 'magofi mmogo kwa godimo: letlalo la mmala wa bontsho jo bo mo magareng',
    '🤲🏿' => 'magofi mmogo kwa godimo: letlalo la mmala o montsho',
    '🤝🏻' => 'tshwarano ka letsogo: letlalo le lesweu',
    '🤝🏼' => 'tshwarano ka letsogo: letlalo le le bosweu jo bo mo magareng',
    '🤝🏽' => 'tshwarano ka letsogo: letlalo la mmala o o mo magareng',
    '🤝🏾' => 'tshwarano ka letsogo: letlalo la mmala wa bontsho jo bo mo magareng',
    '🤝🏿' => 'tshwarano ka letsogo: letlalo la mmala o montsho',
    '🙏🏻' => 'matsogo a a mennweng: letlalo le lesweu',
    '🙏🏼' => 'matsogo a a mennweng: letlalo le le bosweu jo bo mo magareng',
    '🙏🏽' => 'matsogo a a mennweng: letlalo la mmala o o mo magareng',
    '🙏🏾' => 'matsogo a a mennweng: letlalo la mmala wa bontsho jo bo mo magareng',
    '🙏🏿' => 'matsogo a a mennweng: letlalo la mmala o montsho',
    '✍🏻' => 'letsogo le le kwalang: letlalo le lesweu',
    '✍🏼' => 'letsogo le le kwalang: letlalo le le bosweu jo bo mo magareng',
    '✍🏽' => 'letsogo le le kwalang: letlalo la mmala o o mo magareng',
    '✍🏾' => 'letsogo le le kwalang: letlalo la mmala wa bontsho jo bo mo magareng',
    '✍🏿' => 'letsogo le le kwalang: letlalo la mmala o montsho',
    '💅🏻' => 'politšhe ya dinala: letlalo le lesweu',
    '💅🏼' => 'politšhe ya dinala: letlalo le le bosweu jo bo mo magareng',
    '💅🏽' => 'politšhe ya dinala: letlalo la mmala o o mo magareng',
    '💅🏾' => 'politšhe ya dinala: letlalo la mmala wa bontsho jo bo mo magareng',
    '💅🏿' => 'politšhe ya dinala: letlalo la mmala o montsho',
    '🤳🏻' => 'itsaya senepe: letlalo le lesweu',
    '🤳🏼' => 'itsaya senepe: letlalo le le bosweu jo bo mo magareng',
    '🤳🏽' => 'itsaya senepe: letlalo la mmala o o mo magareng',
    '🤳🏾' => 'itsaya senepe: letlalo la mmala wa bontsho jo bo mo magareng',
    '🤳🏿' => 'itsaya senepe: letlalo la mmala o montsho',
    '💪🏻' => 'dipotongwane tse di obegileng: letlalo le lesweu',
    '💪🏼' => 'dipotongwane tse di obegileng: letlalo le le bosweu jo bo mo magareng',
    '💪🏽' => 'dipotongwane tse di obegileng: letlalo la mmala o o mo magareng',
    '💪🏾' => 'dipotongwane tse di obegileng: letlalo la mmala wa bontsho jo bo mo magareng',
    '💪🏿' => 'dipotongwane tse di obegileng: letlalo la mmala o montsho',
    '👂🏻' => 'tsebe: letlalo le lesweu',
    '👂🏼' => 'tsebe: letlalo le le bosweu jo bo mo magareng',
    '👂🏽' => 'tsebe: letlalo la mmala o o mo magareng',
    '👂🏾' => 'tsebe: letlalo la mmala wa bontsho jo bo mo magareng',
    '👂🏿' => 'tsebe: letlalo la mmala o montsho',
    '👃🏻' => 'nko: letlalo le lesweu',
    '👃🏼' => 'nko: letlalo le le bosweu jo bo mo magareng',
    '👃🏽' => 'nko: letlalo la mmala o o mo magareng',
    '👃🏾' => 'nko: letlalo la mmala wa bontsho jo bo mo magareng',
    '👃🏿' => 'nko: letlalo la mmala o montsho',
    '👶🏻' => 'lesea: letlalo le lesweu',
    '👶🏼' => 'lesea: letlalo le le bosweu jo bo mo magareng',
    '👶🏽' => 'lesea: letlalo la mmala o o mo magareng',
    '👶🏾' => 'lesea: letlalo la mmala wa bontsho jo bo mo magareng',
    '👶🏿' => 'lesea: letlalo la mmala o montsho',
    '🧒🏻' => 'ngwana: letlalo le lesweu',
    '🧒🏼' => 'ngwana: letlalo le le bosweu jo bo mo magareng',
    '🧒🏽' => 'ngwana: letlalo la mmala o o mo magareng',
    '🧒🏾' => 'ngwana: letlalo la mmala wa bontsho jo bo mo magareng',
    '🧒🏿' => 'ngwana: letlalo la mmala o montsho',
    '👦🏻' => 'mosimane: letlalo le lesweu',
    '👦🏼' => 'mosimane: letlalo le le bosweu jo bo mo magareng',
    '👦🏽' => 'mosimane: letlalo la mmala o o mo magareng',
    '👦🏾' => 'mosimane: letlalo la mmala wa bontsho jo bo mo magareng',
    '👦🏿' => 'mosimane: letlalo la mmala o montsho',
    '👧🏻' => 'mosetsana: letlalo le lesweu',
    '👧🏼' => 'mosetsana: letlalo le le bosweu jo bo mo magareng',
    '👧🏽' => 'mosetsana: letlalo la mmala o o mo magareng',
    '👧🏾' => 'mosetsana: letlalo la mmala wa bontsho jo bo mo magareng',
    '👧🏿' => 'mosetsana: letlalo la mmala o montsho',
    '🧑🏻' => 'mogolo: letlalo le lesweu',
    '🧑🏼' => 'mogolo: letlalo le le bosweu jo bo mo magareng',
    '🧑🏽' => 'mogolo: letlalo la mmala o o mo magareng',
    '🧑🏾' => 'mogolo: letlalo la mmala wa bontsho jo bo mo magareng',
    '🧑🏿' => 'mogolo: letlalo la mmala o montsho',
    '👱🏻' => 'motho wa moriri o mosetlha: letlalo le lesweu',
    '👱🏼' => 'motho wa moriri o mosetlha: letlalo le le bosweu jo bo mo magareng',
    '👱🏽' => 'motho wa moriri o mosetlha: letlalo la mmala o o mo magareng',
    '👱🏾' => 'motho wa moriri o mosetlha: letlalo la mmala wa bontsho jo bo mo magareng',
    '👱🏿' => 'motho wa moriri o mosetlha: letlalo la mmala o montsho',
    '👨🏻' => 'monna: letlalo le lesweu',
    '👨🏼' => 'monna: letlalo le le bosweu jo bo mo magareng',
    '👨🏽' => 'monna: letlalo la mmala o o mo magareng',
    '👨🏾' => 'monna: letlalo la mmala wa bontsho jo bo mo magareng',
    '👨🏿' => 'monna: letlalo la mmala o montsho',
    '🧔🏻' => 'motho yo o ditedu: letlalo le lesweu',
    '🧔🏼' => 'motho yo o ditedu: letlalo le le bosweu jo bo mo magareng',
    '🧔🏽' => 'motho yo o ditedu: letlalo la mmala o o mo magareng',
    '🧔🏾' => 'motho yo o ditedu: letlalo la mmala wa bontsho jo bo mo magareng',
    '🧔🏿' => 'motho yo o ditedu: letlalo la mmala o montsho',
    '👩🏻' => 'mosadi: letlalo le lesweu',
    '👩🏼' => 'mosadi: letlalo le le bosweu jo bo mo magareng',
    '👩🏽' => 'mosadi: letlalo la mmala o o mo magareng',
    '👩🏾' => 'mosadi: letlalo la mmala wa bontsho jo bo mo magareng',
    '👩🏿' => 'mosadi: letlalo la mmala o montsho',
    '🧓🏻' => 'mogolo yo o tsofetseng: letlalo le lesweu',
    '🧓🏼' => 'mogolo yo o tsofetseng: letlalo le le bosweu jo bo mo magareng',
    '🧓🏽' => 'mogolo yo o tsofetseng: letlalo la mmala o o mo magareng',
    '🧓🏾' => 'mogolo yo o tsofetseng: letlalo la mmala wa bontsho jo bo mo magareng',
    '🧓🏿' => 'mogolo yo o tsofetseng: letlalo la mmala o montsho',
    '👴🏻' => 'monnamogolo: letlalo le lesweu',
    '👴🏼' => 'monnamogolo: letlalo le le bosweu jo bo mo magareng',
    '👴🏽' => 'monnamogolo: letlalo la mmala o o mo magareng',
    '👴🏾' => 'monnamogolo: letlalo la mmala wa bontsho jo bo mo magareng',
    '👴🏿' => 'monnamogolo: letlalo la mmala o montsho',
    '👵🏻' => 'mosadimogolo: letlalo le lesweu',
    '👵🏼' => 'mosadimogolo: letlalo le le bosweu jo bo mo magareng',
    '👵🏽' => 'mosadimogolo: letlalo la mmala o o mo magareng',
    '👵🏾' => 'mosadimogolo: letlalo la mmala wa bontsho jo bo mo magareng',
    '👵🏿' => 'mosadimogolo: letlalo la mmala o montsho',
    '🙍🏻' => 'motho yo o menneng phatla: letlalo le lesweu',
    '🙍🏼' => 'motho yo o menneng phatla: letlalo le le bosweu jo bo mo magareng',
    '🙍🏽' => 'motho yo o menneng phatla: letlalo la mmala o o mo magareng',
    '🙍🏾' => 'motho yo o menneng phatla: letlalo la mmala wa bontsho jo bo mo magareng',
    '🙍🏿' => 'motho yo o menneng phatla: letlalo la mmala o montsho',
    '🙎🏻' => 'motho yo o tsuputseng molomo: letlalo le lesweu',
    '🙎🏼' => 'motho yo o tsuputseng molomo: letlalo le le bosweu jo bo mo magareng',
    '🙎🏽' => 'motho yo o tsuputseng molomo: letlalo la mmala o o mo magareng',
    '🙎🏾' => 'motho yo o tsuputseng molomo: letlalo la mmala wa bontsho jo bo mo magareng',
    '🙎🏿' => 'motho yo o tsuputseng molomo: letlalo la mmala o montsho',
    '🙅🏻' => 'motho yo o reng NNYAA ka puo ya matsogo: letlalo le lesweu',
    '🙅🏼' => 'motho yo o reng NNYAA ka puo ya matsogo: letlalo le le bosweu jo bo mo magareng',
    '🙅🏽' => 'motho yo o reng NNYAA ka puo ya matsogo: letlalo la mmala o o mo magareng',
    '🙅🏾' => 'motho yo o reng NNYAA ka puo ya matsogo: letlalo la mmala wa bontsho jo bo mo magareng',
    '🙅🏿' => 'motho yo o reng NNYAA ka puo ya matsogo: letlalo la mmala o montsho',
    '🙆🏻' => 'motho yo o reng GO SIAME ka puo ya matsogo: letlalo le lesweu',
    '🙆🏼' => 'motho yo o reng GO SIAME ka puo ya matsogo: letlalo le le bosweu jo bo mo magareng',
    '🙆🏽' => 'motho yo o reng GO SIAME ka puo ya matsogo: letlalo la mmala o o mo magareng',
    '🙆🏾' => 'motho yo o reng GO SIAME ka puo ya matsogo: letlalo la mmala wa bontsho jo bo mo magareng',
    '🙆🏿' => 'motho yo o reng GO SIAME ka puo ya matsogo: letlalo la mmala o montsho',
    '💁🏻' => 'motho a sekamisa letsogo: letlalo le lesweu',
    '💁🏼' => 'motho a sekamisa letsogo: letlalo le le bosweu jo bo mo magareng',
    '💁🏽' => 'motho a sekamisa letsogo: letlalo la mmala o o mo magareng',
    '💁🏾' => 'motho a sekamisa letsogo: letlalo la mmala wa bontsho jo bo mo magareng',
    '💁🏿' => 'motho a sekamisa letsogo: letlalo la mmala o montsho',
    '🙋🏻' => 'motho a tsholetsa letsogo: letlalo le lesweu',
    '🙋🏼' => 'motho a tsholetsa letsogo: letlalo le le bosweu jo bo mo magareng',
    '🙋🏽' => 'motho a tsholetsa letsogo: letlalo la mmala o o mo magareng',
    '🙋🏾' => 'motho a tsholetsa letsogo: letlalo la mmala wa bontsho jo bo mo magareng',
    '🙋🏿' => 'motho a tsholetsa letsogo: letlalo la mmala o montsho',
    '🙇🏻' => 'motho a obega: letlalo le lesweu',
    '🙇🏼' => 'motho a obega: letlalo le le bosweu jo bo mo magareng',
    '🙇🏽' => 'motho a obega: letlalo la mmala o o mo magareng',
    '🙇🏾' => 'motho a obega: letlalo la mmala wa bontsho jo bo mo magareng',
    '🙇🏿' => 'motho a obega: letlalo la mmala o montsho',
    '🤦🏻' => 'motho ka legofi mo sefatlhegong: letlalo le lesweu',
    '🤦🏼' => 'motho ka legofi mo sefatlhegong: letlalo le le bosweu jo bo mo magareng',
    '🤦🏽' => 'motho ka legofi mo sefatlhegong: letlalo la mmala o o mo magareng',
    '🤦🏾' => 'motho ka legofi mo sefatlhegong: letlalo la mmala wa bontsho jo bo mo magareng',
    '🤦🏿' => 'motho ka legofi mo sefatlhegong: letlalo la mmala o montsho',
    '🤷🏻' => 'motho yo o tsholetsang magetla: letlalo le lesweu',
    '🤷🏼' => 'motho yo o tsholetsang magetla: letlalo le le bosweu jo bo mo magareng',
    '🤷🏽' => 'motho yo o tsholetsang magetla: letlalo la mmala o o mo magareng',
    '🤷🏾' => 'motho yo o tsholetsang magetla: letlalo la mmala wa bontsho jo bo mo magareng',
    '🤷🏿' => 'motho yo o tsholetsang magetla: letlalo la mmala o montsho',
    '👮🏻' => 'lepodise: letlalo le lesweu',
    '👮🏼' => 'lepodise: letlalo le le bosweu jo bo mo magareng',
    '👮🏽' => 'lepodise: letlalo la mmala o o mo magareng',
    '👮🏾' => 'lepodise: letlalo la mmala wa bontsho jo bo mo magareng',
    '👮🏿' => 'lepodise: letlalo la mmala o montsho',
    '🕵🏻' => 'boteketifi: letlalo le lesweu',
    '🕵🏼' => 'boteketifi: letlalo le le bosweu jo bo mo magareng',
    '🕵🏽' => 'boteketifi: letlalo la mmala o o mo magareng',
    '🕵🏾' => 'boteketifi: letlalo la mmala wa bontsho jo bo mo magareng',
    '🕵🏿' => 'boteketifi: letlalo la mmala o montsho',
    '💂🏻' => 'modisa: letlalo le lesweu',
    '💂🏼' => 'modisa: letlalo le le bosweu jo bo mo magareng',
    '💂🏽' => 'modisa: letlalo la mmala o o mo magareng',
    '💂🏾' => 'modisa: letlalo la mmala wa bontsho jo bo mo magareng',
    '💂🏿' => 'modisa: letlalo la mmala o montsho',
    '👷🏻' => 'modiri mo kagong: letlalo le lesweu',
    '👷🏼' => 'modiri mo kagong: letlalo le le bosweu jo bo mo magareng',
    '👷🏽' => 'modiri mo kagong: letlalo la mmala o o mo magareng',
    '👷🏾' => 'modiri mo kagong: letlalo la mmala wa bontsho jo bo mo magareng',
    '👷🏿' => 'modiri mo kagong: letlalo la mmala o montsho',
    '🤴🏻' => 'kgosana: letlalo le lesweu',
    '🤴🏼' => 'kgosana: letlalo le le bosweu jo bo mo magareng',
    '🤴🏽' => 'kgosana: letlalo la mmala o o mo magareng',
    '🤴🏾' => 'kgosana: letlalo la mmala wa bontsho jo bo mo magareng',
    '🤴🏿' => 'kgosana: letlalo la mmala o montsho',
    '👸🏻' => 'kgosanagadi: letlalo le lesweu',
    '👸🏼' => 'kgosanagadi: letlalo le le bosweu jo bo mo magareng',
    '👸🏽' => 'kgosanagadi: letlalo la mmala o o mo magareng',
    '👸🏾' => 'kgosanagadi: letlalo la mmala wa bontsho jo bo mo magareng',
    '👸🏿' => 'kgosanagadi: letlalo la mmala o montsho',
    '👳🏻' => 'motho a rwele sehapatlhogo: letlalo le lesweu',
    '👳🏼' => 'motho a rwele sehapatlhogo: letlalo le le bosweu jo bo mo magareng',
    '👳🏽' => 'motho a rwele sehapatlhogo: letlalo la mmala o o mo magareng',
    '👳🏾' => 'motho a rwele sehapatlhogo: letlalo la mmala wa bontsho jo bo mo magareng',
    '👳🏿' => 'motho a rwele sehapatlhogo: letlalo la mmala o montsho',
    '👲🏻' => 'monna ka kepisi ya matšhaena: letlalo le lesweu',
    '👲🏼' => 'monna ka kepisi ya matšhaena: letlalo le le bosweu jo bo mo magareng',
    '👲🏽' => 'monna ka kepisi ya matšhaena: letlalo la mmala o o mo magareng',
    '👲🏾' => 'monna ka kepisi ya matšhaena: letlalo la mmala wa bontsho jo bo mo magareng',
    '👲🏿' => 'monna ka kepisi ya matšhaena: letlalo la mmala o montsho',
    '🧕🏻' => 'mosadi ka sehapatlhogo: letlalo le lesweu',
    '🧕🏼' => 'mosadi ka sehapatlhogo: letlalo le le bosweu jo bo mo magareng',
    '🧕🏽' => 'mosadi ka sehapatlhogo: letlalo la mmala o o mo magareng',
    '🧕🏾' => 'mosadi ka sehapatlhogo: letlalo la mmala wa bontsho jo bo mo magareng',
    '🧕🏿' => 'mosadi ka sehapatlhogo: letlalo la mmala o montsho',
    '🤵🏻' => 'monna mo tuxedo: letlalo le lesweu',
    '🤵🏼' => 'monna mo tuxedo: letlalo le le bosweu jo bo mo magareng',
    '🤵🏽' => 'monna mo tuxedo: letlalo la mmala o o mo magareng',
    '🤵🏾' => 'monna mo tuxedo: letlalo la mmala wa bontsho jo bo mo magareng',
    '🤵🏿' => 'monna mo tuxedo: letlalo la mmala o montsho',
    '👰🏻' => 'monyadwi ka lesire: letlalo le lesweu',
    '👰🏼' => 'monyadwi ka lesire: letlalo le le bosweu jo bo mo magareng',
    '👰🏽' => 'monyadwi ka lesire: letlalo la mmala o o mo magareng',
    '👰🏾' => 'monyadwi ka lesire: letlalo la mmala wa bontsho jo bo mo magareng',
    '👰🏿' => 'monyadwi ka lesire: letlalo la mmala o montsho',
    '🤰🏻' => 'mosadi wa moimana: letlalo le lesweu',
    '🤰🏼' => 'mosadi wa moimana: letlalo le le bosweu jo bo mo magareng',
    '🤰🏽' => 'mosadi wa moimana: letlalo la mmala o o mo magareng',
    '🤰🏾' => 'mosadi wa moimana: letlalo la mmala wa bontsho jo bo mo magareng',
    '🤰🏿' => 'mosadi wa moimana: letlalo la mmala o montsho',
    '🤱🏻' => 'anyisa: letlalo le lesweu',
    '🤱🏼' => 'anyisa: letlalo le le bosweu jo bo mo magareng',
    '🤱🏽' => 'anyisa: letlalo la mmala o o mo magareng',
    '🤱🏾' => 'anyisa: letlalo la mmala wa bontsho jo bo mo magareng',
    '🤱🏿' => 'anyisa: letlalo la mmala o montsho',
    '👼🏻' => 'moengele wa lesea: letlalo le lesweu',
    '👼🏼' => 'moengele wa lesea: letlalo le le bosweu jo bo mo magareng',
    '👼🏽' => 'moengele wa lesea: letlalo la mmala o o mo magareng',
    '👼🏾' => 'moengele wa lesea: letlalo la mmala wa bontsho jo bo mo magareng',
    '👼🏿' => 'moengele wa lesea: letlalo la mmala o montsho',
    '🎅🏻' => 'Santa Tlelose: letlalo le lesweu',
    '🎅🏼' => 'Santa Tlelose: letlalo le le bosweu jo bo mo magareng',
    '🎅🏽' => 'Santa Tlelose: letlalo la mmala o o mo magareng',
    '🎅🏾' => 'Santa Tlelose: letlalo la mmala wa bontsho jo bo mo magareng',
    '🎅🏿' => 'Santa Tlelose: letlalo la mmala o montsho',
    '🤶🏻' => 'Mme Tlelose: letlalo le lesweu',
    '🤶🏼' => 'Mme Tlelose: letlalo le le bosweu jo bo mo magareng',
    '🤶🏽' => 'Mme Tlelose: letlalo la mmala o o mo magareng',
    '🤶🏾' => 'Mme Tlelose: letlalo la mmala wa bontsho jo bo mo magareng',
    '🤶🏿' => 'Mme Tlelose: letlalo la mmala o montsho',
    '🧙🏻' => 'matwetwe: letlalo le lesweu',
    '🧙🏼' => 'matwetwe: letlalo le le bosweu jo bo mo magareng',
    '🧙🏽' => 'matwetwe: letlalo la mmala o o mo magareng',
    '🧙🏾' => 'matwetwe: letlalo la mmala wa bontsho jo bo mo magareng',
    '🧙🏿' => 'matwetwe: letlalo la mmala o montsho',
    '🧚🏻' => 'ya ditlhamane: letlalo le lesweu',
    '🧚🏼' => 'ya ditlhamane: letlalo le le bosweu jo bo mo magareng',
    '🧚🏽' => 'ya ditlhamane: letlalo la mmala o o mo magareng',
    '🧚🏾' => 'ya ditlhamane: letlalo la mmala wa bontsho jo bo mo magareng',
    '🧚🏿' => 'ya ditlhamane: letlalo la mmala o montsho',
    '🧛🏻' => 'mmamathwane wa vampire: letlalo le lesweu',
    '🧛🏼' => 'mmamathwane wa vampire: letlalo le le bosweu jo bo mo magareng',
    '🧛🏽' => 'mmamathwane wa vampire: letlalo la mmala o o mo magareng',
    '🧛🏾' => 'mmamathwane wa vampire: letlalo la mmala wa bontsho jo bo mo magareng',
    '🧛🏿' => 'mmamathwane wa vampire: letlalo la mmala o montsho',
    '🧜🏻' => 'motho wa tlhamane: letlalo le lesweu',
    '🧜🏼' => 'motho wa tlhamane: letlalo le le bosweu jo bo mo magareng',
    '🧜🏽' => 'motho wa tlhamane: letlalo la mmala o o mo magareng',
    '🧜🏾' => 'motho wa tlhamane: letlalo la mmala wa bontsho jo bo mo magareng',
    '🧜🏿' => 'motho wa tlhamane: letlalo la mmala o montsho',
    '🧝🏻' => 'mankge mo ditlhamaneng: letlalo le lesweu',
    '🧝🏼' => 'mankge mo ditlhamaneng: letlalo le le bosweu jo bo mo magareng',
    '🧝🏽' => 'mankge mo ditlhamaneng: letlalo la mmala o o mo magareng',
    '🧝🏾' => 'mankge mo ditlhamaneng: letlalo la mmala wa bontsho jo bo mo magareng',
    '🧝🏿' => 'mankge mo ditlhamaneng: letlalo la mmala o montsho',
    '💆🏻' => 'motho yo o bonang tshidilo: letlalo le lesweu',
    '💆🏼' => 'motho yo o bonang tshidilo: letlalo le le bosweu jo bo mo magareng',
    '💆🏽' => 'motho yo o bonang tshidilo: letlalo la mmala o o mo magareng',
    '💆🏾' => 'motho yo o bonang tshidilo: letlalo la mmala wa bontsho jo bo mo magareng',
    '💆🏿' => 'motho yo o bonang tshidilo: letlalo la mmala o montsho',
    '💇🏻' => 'motho yo o beolang moriri: letlalo le lesweu',
    '💇🏼' => 'motho yo o beolang moriri: letlalo le le bosweu jo bo mo magareng',
    '💇🏽' => 'motho yo o beolang moriri: letlalo la mmala o o mo magareng',
    '💇🏾' => 'motho yo o beolang moriri: letlalo la mmala wa bontsho jo bo mo magareng',
    '💇🏿' => 'motho yo o beolang moriri: letlalo la mmala o montsho',
    '🚶🏻' => 'motho yo o tsamayang: letlalo le lesweu',
    '🚶🏼' => 'motho yo o tsamayang: letlalo le le bosweu jo bo mo magareng',
    '🚶🏽' => 'motho yo o tsamayang: letlalo la mmala o o mo magareng',
    '🚶🏾' => 'motho yo o tsamayang: letlalo la mmala wa bontsho jo bo mo magareng',
    '🚶🏿' => 'motho yo o tsamayang: letlalo la mmala o montsho',
    '🏃🏻' => 'motho yo o tabogang: letlalo le lesweu',
    '🏃🏼' => 'motho yo o tabogang: letlalo le le bosweu jo bo mo magareng',
    '🏃🏽' => 'motho yo o tabogang: letlalo la mmala o o mo magareng',
    '🏃🏾' => 'motho yo o tabogang: letlalo la mmala wa bontsho jo bo mo magareng',
    '🏃🏿' => 'motho yo o tabogang: letlalo la mmala o montsho',
    '💃🏻' => 'mosadi yo o binang: letlalo le lesweu',
    '💃🏼' => 'mosadi yo o binang: letlalo le le bosweu jo bo mo magareng',
    '💃🏽' => 'mosadi yo o binang: letlalo la mmala o o mo magareng',
    '💃🏾' => 'mosadi yo o binang: letlalo la mmala wa bontsho jo bo mo magareng',
    '💃🏿' => 'mosadi yo o binang: letlalo la mmala o montsho',
    '🕺🏻' => 'monna yo o binang: letlalo le lesweu',
    '🕺🏼' => 'monna yo o binang: letlalo le le bosweu jo bo mo magareng',
    '🕺🏽' => 'monna yo o binang: letlalo la mmala o o mo magareng',
    '🕺🏾' => 'monna yo o binang: letlalo la mmala wa bontsho jo bo mo magareng',
    '🕺🏿' => 'monna yo o binang: letlalo la mmala o montsho',
    '🕴🏻' => 'monna mo sutung ya kgwebo a ya godimo: letlalo le lesweu',
    '🕴🏼' => 'monna mo sutung ya kgwebo a ya godimo: letlalo le le bosweu jo bo mo magareng',
    '🕴🏽' => 'monna mo sutung ya kgwebo a ya godimo: letlalo la mmala o o mo magareng',
    '🕴🏾' => 'monna mo sutung ya kgwebo a ya godimo: letlalo la mmala wa bontsho jo bo mo magareng',
    '🕴🏿' => 'monna mo sutung ya kgwebo a ya godimo: letlalo la mmala o montsho',
    '👯🏻' => 'batho ka ditsebe tsa mmutla mo moletlong: letlalo le lesweu',
    '👯🏼' => 'batho ka ditsebe tsa mmutla mo moletlong: letlalo le le bosweu jo bo mo magareng',
    '👯🏽' => 'batho ka ditsebe tsa mmutla mo moletlong: letlalo la mmala o o mo magareng',
    '👯🏾' => 'batho ka ditsebe tsa mmutla mo moletlong: letlalo la mmala wa bontsho jo bo mo magareng',
    '👯🏿' => 'batho ka ditsebe tsa mmutla mo moletlong: letlalo la mmala o montsho',
    '🧖🏻' => 'motho mo kamoreng ya metsi a a belang: letlalo le lesweu',
    '🧖🏼' => 'motho mo kamoreng ya metsi a a belang: letlalo le le bosweu jo bo mo magareng',
    '🧖🏽' => 'motho mo kamoreng ya metsi a a belang: letlalo la mmala o o mo magareng',
    '🧖🏾' => 'motho mo kamoreng ya metsi a a belang: letlalo la mmala wa bontsho jo bo mo magareng',
    '🧖🏿' => 'motho mo kamoreng ya metsi a a belang: letlalo la mmala o montsho',
    '🧗🏻' => 'motho yo o palamang: letlalo le lesweu',
    '🧗🏼' => 'motho yo o palamang: letlalo le le bosweu jo bo mo magareng',
    '🧗🏽' => 'motho yo o palamang: letlalo la mmala o o mo magareng',
    '🧗🏾' => 'motho yo o palamang: letlalo la mmala wa bontsho jo bo mo magareng',
    '🧗🏿' => 'motho yo o palamang: letlalo la mmala o montsho',
    '🏇🏻' => 'lobelo lwa dipitse: letlalo le lesweu',
    '🏇🏼' => 'lobelo lwa dipitse: letlalo le le bosweu jo bo mo magareng',
    '🏇🏽' => 'lobelo lwa dipitse: letlalo la mmala o o mo magareng',
    '🏇🏾' => 'lobelo lwa dipitse: letlalo la mmala wa bontsho jo bo mo magareng',
    '🏇🏿' => 'lobelo lwa dipitse: letlalo la mmala o montsho',
    '🏂🏻' => 'mopagami wa boto ya semathana: letlalo le lesweu',
    '🏂🏼' => 'mopagami wa boto ya semathana: letlalo le le bosweu jo bo mo magareng',
    '🏂🏽' => 'mopagami wa boto ya semathana: letlalo la mmala o o mo magareng',
    '🏂🏾' => 'mopagami wa boto ya semathana: letlalo la mmala wa bontsho jo bo mo magareng',
    '🏂🏿' => 'mopagami wa boto ya semathana: letlalo la mmala o montsho',
    '🏌🏻' => 'motho yo o tshamekang kolofo: letlalo le lesweu',
    '🏌🏼' => 'motho yo o tshamekang kolofo: letlalo le le bosweu jo bo mo magareng',
    '🏌🏽' => 'motho yo o tshamekang kolofo: letlalo la mmala o o mo magareng',
    '🏌🏾' => 'motho yo o tshamekang kolofo: letlalo la mmala wa bontsho jo bo mo magareng',
    '🏌🏿' => 'motho yo o tshamekang kolofo: letlalo la mmala o montsho',
    '🏄🏻' => 'motho yo o lelemelang mo metsing: letlalo le lesweu',
    '🏄🏼' => 'motho yo o lelemelang mo metsing: letlalo le le bosweu jo bo mo magareng',
    '🏄🏽' => 'motho yo o lelemelang mo metsing: letlalo la mmala o o mo magareng',
    '🏄🏾' => 'motho yo o lelemelang mo metsing: letlalo la mmala wa bontsho jo bo mo magareng',
    '🏄🏿' => 'motho yo o lelemelang mo metsing: letlalo la mmala o montsho',
    '🚣🏻' => 'motho yo o kgweetsang mokoro: letlalo le lesweu',
    '🚣🏼' => 'motho yo o kgweetsang mokoro: letlalo le le bosweu jo bo mo magareng',
    '🚣🏽' => 'motho yo o kgweetsang mokoro: letlalo la mmala o o mo magareng',
    '🚣🏾' => 'motho yo o kgweetsang mokoro: letlalo la mmala wa bontsho jo bo mo magareng',
    '🚣🏿' => 'motho yo o kgweetsang mokoro: letlalo la mmala o montsho',
    '🏊🏻' => 'motho yo o thumang: letlalo le lesweu',
    '🏊🏼' => 'motho yo o thumang: letlalo le le bosweu jo bo mo magareng',
    '🏊🏽' => 'motho yo o thumang: letlalo la mmala o o mo magareng',
    '🏊🏾' => 'motho yo o thumang: letlalo la mmala wa bontsho jo bo mo magareng',
    '🏊🏿' => 'motho yo o thumang: letlalo la mmala o montsho',
    '⛹🏻' => 'motho yo o itaaganyang bolo fa fatshe: letlalo le lesweu',
    '⛹🏼' => 'motho yo o itaaganyang bolo fa fatshe: letlalo le le bosweu jo bo mo magareng',
    '⛹🏽' => 'motho yo o itaaganyang bolo fa fatshe: letlalo la mmala o o mo magareng',
    '⛹🏾' => 'motho yo o itaaganyang bolo fa fatshe: letlalo la mmala wa bontsho jo bo mo magareng',
    '⛹🏿' => 'motho yo o itaaganyang bolo fa fatshe: letlalo la mmala o montsho',
    '🏋🏻' => 'motho yo o tsholetsang ditshipi: letlalo le lesweu',
    '🏋🏼' => 'motho yo o tsholetsang ditshipi: letlalo le le bosweu jo bo mo magareng',
    '🏋🏽' => 'motho yo o tsholetsang ditshipi: letlalo la mmala o o mo magareng',
    '🏋🏾' => 'motho yo o tsholetsang ditshipi: letlalo la mmala wa bontsho jo bo mo magareng',
    '🏋🏿' => 'motho yo o tsholetsang ditshipi: letlalo la mmala o montsho',
    '🚴🏻' => 'motho yo o kgweetsang sekuta: letlalo le lesweu',
    '🚴🏼' => 'motho yo o kgweetsang sekuta: letlalo le le bosweu jo bo mo magareng',
    '🚴🏽' => 'motho yo o kgweetsang sekuta: letlalo la mmala o o mo magareng',
    '🚴🏾' => 'motho yo o kgweetsang sekuta: letlalo la mmala wa bontsho jo bo mo magareng',
    '🚴🏿' => 'motho yo o kgweetsang sekuta: letlalo la mmala o montsho',
    '🚵🏻' => 'motho yo o kgweetsang sekuta mo thabeng: letlalo le lesweu',
    '🚵🏼' => 'motho yo o kgweetsang sekuta mo thabeng: letlalo le le bosweu jo bo mo magareng',
    '🚵🏽' => 'motho yo o kgweetsang sekuta mo thabeng: letlalo la mmala o o mo magareng',
    '🚵🏾' => 'motho yo o kgweetsang sekuta mo thabeng: letlalo la mmala wa bontsho jo bo mo magareng',
    '🚵🏿' => 'motho yo o kgweetsang sekuta mo thabeng: letlalo la mmala o montsho',
    '🤸🏻' => 'motho yo o tsamaisang kolotsana: letlalo le lesweu',
    '🤸🏼' => 'motho yo o tsamaisang kolotsana: letlalo le le bosweu jo bo mo magareng',
    '🤸🏽' => 'motho yo o tsamaisang kolotsana: letlalo la mmala o o mo magareng',
    '🤸🏾' => 'motho yo o tsamaisang kolotsana: letlalo la mmala wa bontsho jo bo mo magareng',
    '🤸🏿' => 'motho yo o tsamaisang kolotsana: letlalo la mmala o montsho',
    '🤼🏻' => 'batho ba ba lwang ka go mekamekana: letlalo le lesweu',
    '🤼🏼' => 'batho ba ba lwang ka go mekamekana: letlalo le le bosweu jo bo mo magareng',
    '🤼🏽' => 'batho ba ba lwang ka go mekamekana: letlalo la mmala o o mo magareng',
    '🤼🏾' => 'batho ba ba lwang ka go mekamekana: letlalo la mmala wa bontsho jo bo mo magareng',
    '🤼🏿' => 'batho ba ba lwang ka go mekamekana: letlalo la mmala o montsho',
    '🤽🏻' => 'motho yo o tshamekang polo ya metsi: letlalo le lesweu',
    '🤽🏼' => 'motho yo o tshamekang polo ya metsi: letlalo le le bosweu jo bo mo magareng',
    '🤽🏽' => 'motho yo o tshamekang polo ya metsi: letlalo la mmala o o mo magareng',
    '🤽🏾' => 'motho yo o tshamekang polo ya metsi: letlalo la mmala wa bontsho jo bo mo magareng',
    '🤽🏿' => 'motho yo o tshamekang polo ya metsi: letlalo la mmala o montsho',
    '🤾🏻' => 'motho yo o tshamekang bolo ya letsogo: letlalo le lesweu',
    '🤾🏼' => 'motho yo o tshamekang bolo ya letsogo: letlalo le le bosweu jo bo mo magareng',
    '🤾🏽' => 'motho yo o tshamekang bolo ya letsogo: letlalo la mmala o o mo magareng',
    '🤾🏾' => 'motho yo o tshamekang bolo ya letsogo: letlalo la mmala wa bontsho jo bo mo magareng',
    '🤾🏿' => 'motho yo o tshamekang bolo ya letsogo: letlalo la mmala o montsho',
    '🤹🏻' => 'motho yo o mekamekanang le dilo dintsi: letlalo le lesweu',
    '🤹🏼' => 'motho yo o mekamekanang le dilo dintsi: letlalo le le bosweu jo bo mo magareng',
    '🤹🏽' => 'motho yo o mekamekanang le dilo dintsi: letlalo la mmala o o mo magareng',
    '🤹🏾' => 'motho yo o mekamekanang le dilo dintsi: letlalo la mmala wa bontsho jo bo mo magareng',
    '🤹🏿' => 'motho yo o mekamekanang le dilo dintsi: letlalo la mmala o montsho',
    '🧘🏻' => 'motho mo boemong jwa lotus: letlalo le lesweu',
    '🧘🏼' => 'motho mo boemong jwa lotus: letlalo le le bosweu jo bo mo magareng',
    '🧘🏽' => 'motho mo boemong jwa lotus: letlalo la mmala o o mo magareng',
    '🧘🏾' => 'motho mo boemong jwa lotus: letlalo la mmala wa bontsho jo bo mo magareng',
    '🧘🏿' => 'motho mo boemong jwa lotus: letlalo la mmala o montsho',
    '🛀🏻' => 'motho yo o tlhapang: letlalo le lesweu',
    '🛀🏼' => 'motho yo o tlhapang: letlalo le le bosweu jo bo mo magareng',
    '🛀🏽' => 'motho yo o tlhapang: letlalo la mmala o o mo magareng',
    '🛀🏾' => 'motho yo o tlhapang: letlalo la mmala wa bontsho jo bo mo magareng',
    '🛀🏿' => 'motho yo o tlhapang: letlalo la mmala o montsho',
    '🛌🏻' => 'motho mo bolaong: letlalo le lesweu',
    '🛌🏼' => 'motho mo bolaong: letlalo le le bosweu jo bo mo magareng',
    '🛌🏽' => 'motho mo bolaong: letlalo la mmala o o mo magareng',
    '🛌🏾' => 'motho mo bolaong: letlalo la mmala wa bontsho jo bo mo magareng',
    '🛌🏿' => 'motho mo bolaong: letlalo la mmala o montsho',
    '👭🏻' => 'basadi ba babedi ba tshwarane matsogo: letlalo le lesweu',
    '👭🏼' => 'basadi ba babedi ba tshwarane matsogo: letlalo le le bosweu jo bo mo magareng',
    '👭🏽' => 'basadi ba babedi ba tshwarane matsogo: letlalo la mmala o o mo magareng',
    '👭🏾' => 'basadi ba babedi ba tshwarane matsogo: letlalo la mmala wa bontsho jo bo mo magareng',
    '👭🏿' => 'basadi ba babedi ba tshwarane matsogo: letlalo la mmala o montsho',
    '👫🏻' => 'monna le mosadi ba tshwarane matsogo: letlalo le lesweu',
    '👫🏼' => 'monna le mosadi ba tshwarane matsogo: letlalo le le bosweu jo bo mo magareng',
    '👫🏽' => 'monna le mosadi ba tshwarane matsogo: letlalo la mmala o o mo magareng',
    '👫🏾' => 'monna le mosadi ba tshwarane matsogo: letlalo la mmala wa bontsho jo bo mo magareng',
    '👫🏿' => 'monna le mosadi ba tshwarane matsogo: letlalo la mmala o montsho',
    '👬🏻' => 'banna ba babedi ba tshwarane matsogo: letlalo le lesweu',
    '👬🏼' => 'banna ba babedi ba tshwarane matsogo: letlalo le le bosweu jo bo mo magareng',
    '👬🏽' => 'banna ba babedi ba tshwarane matsogo: letlalo la mmala o o mo magareng',
    '👬🏾' => 'banna ba babedi ba tshwarane matsogo: letlalo la mmala wa bontsho jo bo mo magareng',
    '👬🏿' => 'banna ba babedi ba tshwarane matsogo: letlalo la mmala o montsho',
    '💏🏻' => 'atla: letlalo le lesweu',
    '💏🏼' => 'atla: letlalo le le bosweu jo bo mo magareng',
    '💏🏽' => 'atla: letlalo la mmala o o mo magareng',
    '💏🏾' => 'atla: letlalo la mmala wa bontsho jo bo mo magareng',
    '💏🏿' => 'atla: letlalo la mmala o montsho',
    '💑🏻' => 'bobedi ka pelo: letlalo le lesweu',
    '💑🏼' => 'bobedi ka pelo: letlalo le le bosweu jo bo mo magareng',
    '💑🏽' => 'bobedi ka pelo: letlalo la mmala o o mo magareng',
    '💑🏾' => 'bobedi ka pelo: letlalo la mmala wa bontsho jo bo mo magareng',
    '💑🏿' => 'bobedi ka pelo: letlalo la mmala o montsho',
    '🏻' => 'letlalo le lesweu',
    '🏼' => 'letlalo le le bosweu jo bo mo magareng',
    '🏽' => 'letlalo la mmala o o mo magareng',
    '🏾' => 'letlalo la mmala wa bontsho jo bo mo magareng',
    '🏿' => 'letlalo la mmala o montsho',
    '😀' => 'sefatlhego se se ntshitseng meno',
    '😃' => 'sefatlhego se se nyenyang ka molomo o o bulegileng',
    '😄' => 'sefatlhego se se nyenyang ka molomo o o bulegileng le matlho a a nyenyang',
    '😁' => 'sefatlhego se se ntshitseng meno le matlho a a nyenyang',
    '😆' => 'sefatlhego se se nyenyang ka molomo o o bulegileng le matlho a a tswalegileng',
    '😅' => 'sefatlhego se se nyenyang ka molomo o o bulegileng le mofufutso o o tsididi',
    '🤣' => 'bidikama fa fatshe ka ditshego',
    '😂' => 'sefatlhego ka dikeledi tsa boitumelo',
    '🙂' => 'sefatlhego se se nyenyang go sekae',
    '🙃' => 'sefatlhego se se lebileng kwa tlase',
    '😉' => 'sefatlhego se se tsipang leitlho',
    '😊' => 'sefatlhego se se nyenyang ka matlho a a nyenyang',
    '😇' => 'sefatlhego se se nyenyang ka halo',
    '😍' => 'sefatlhego se se nyenyang ka matlho a pelo',
    '🤩' => 'itewa ke naledi',
    '😘' => 'sefatlhego se se butswelang moatlo',
    '😗' => 'sefatlhego sa go atla',
    '☺' => 'sefatlhego sa go nyenya',
    '😚' => 'sefatlhego sa go atla ka matlho a tswalegile',
    '😙' => 'sefatlhego sa go atla ka matlho a a nyenyang',
    '😋' => 'sefatlhego sa motho a utlwa dijo tse di rokotsang mathe',
    '😛' => 'sefatlhego ka leleme le tswetse ntle',
    '😜' => 'sefatlhego ka leleme le tswetse ntle le leitlho le tsipilwe',
    '🤪' => 'sefatlhego sa botsenwa',
    '😝' => 'sefatlhego ka leleme le tswetse ntle le matlho a tswetswe',
    '🤑' => 'sefatlhego sa madi mo ganong',
    '🤗' => 'sefatlhego se se tlamparelang',
    '🤭' => 'sefatlhego ka letsogo mo molomong',
    '🤫' => 'sefatlhego se se didimatsang',
    '🤔' => 'sefatlhego se se akanyang',
    '🤐' => 'sefatlhego sa go tswala molomo ka zip',
    '🤨' => 'sefatlhego ka dintshi tse di isitsweng godimo',
    '😐' => 'sefatlhego se se magareng',
    '😑' => 'sefatlhego se se sa bontsheng maikutlo',
    '😶' => 'sefatlhego go se na molomo',
    '😏' => 'sefatlhego sa lonyatso',
    '😒' => 'sefatlhego se se sa tshegeng',
    '🙄' => 'sefatlhego ka matlho a a dikologang',
    '😬' => 'sefatlhego se se sontseng',
    '🤥' => 'sefatlhego sa go bua maaka',
    '😌' => 'sefatlhego se se wetseng makgwafo',
    '😔' => 'sefatlhego sa motho a akanya',
    '😪' => 'sefatlhego se se boroko',
    '🤤' => 'sefatlhego sa go dutla mathe ganong',
    '😴' => 'sefatlhego sa go robala',
    '😷' => 'sefatlhego sa seipipo sa bongaka',
    '🤒' => 'sefatlhego sa selekanya mogote',
    '🤕' => 'sefatlhego ka sehaphatlhogo',
    '🤢' => 'sefatlhego sa go feroga dibete',
    '🤮' => 'sefatlhego sa motho a tlhatsa',
    '🤧' => 'sefatlhego sa go ethimola',
    '😵' => 'sefatlhego sa sedidi',
    '🤯' => 'tlhogo e e thunyang',
    '🤠' => 'sefatlhego sa hutshe ya modisa',
    '😎' => 'sefatlhego se se nyenyang ka diborele tsa letsatsi',
    '🤓' => 'sefatlhego sa tapisego',
    '🧐' => 'sefatlhego ka diborele',
    '😕' => 'sefatlhego sa kakabalo',
    '😟' => 'sefatlhego sa go tshwenyega',
    '🙁' => 'sefatlhego se se menneng phatlha go sekae',
    '☹' => 'sefatlhego se se menneng phatlha',
    '😮' => 'sefatlhego ka molomo o o bulegileng',
    '😯' => 'sefatlhego se se didimaditsweng',
    '😲' => 'sefatlhego se se gakgametseng',
    '😳' => 'sefatlhego sa ditlhong',
    '😦' => 'sefatlhego se se menneng phatlha ka molomo o o bulegileng',
    '😧' => 'sefatlhego sa kutlobotlhoko',
    '😨' => 'sefatlhego sa poifo',
    '😰' => 'sefatlhego ka molomo o o bulegileng le mofufutso o o tsididi',
    '😥' => 'sefatlhego sa go swaba mme gone wetse makgwafo',
    '😢' => 'sefatlhego se se lelang',
    '😭' => 'sefatlhego se se lelelang godimo',
    '😱' => 'sefatlhego sa motho a goa ka poifo',
    '😖' => 'sefatlhego se se akanyetsang teng',
    '😣' => 'sefatlhego sa boitshoko',
    '😞' => 'sefatlhego sa tshwabo',
    '😓' => 'sefatlhego ka mofufutso o o tsididi',
    '😩' => 'sefatlhego sa go lapa',
    '😫' => 'sefatlhego se se lapileng',
    '😤' => 'sefatlhego ka mofufutso mo nkong',
    '😡' => 'sefatlhego sa go tsupula molomo',
    '😠' => 'sefatlhego sa kgalefo',
    '🤬' => 'sefatlhego ka matshwao mo molomong',
    '😈' => 'sefatlhego se se nyenyang ka dinaka',
    '👿' => 'sefatlhego sa kgalefo ka dinaka',
    '💀' => 'logata',
    '☠' => 'logata le marapo a a fapaantsweng',
    '💩' => 'mokowa wa mantle',
    '🤡' => 'sefatlhego sa modirametlae',
    '👹' => 'dimo',
    '👺' => 'gogo',
    '👻' => 'sepoko',
    '👽' => 'motswakwa',
    '👾' => 'dimo ya motswakwa',
    '🤖' => 'sefatlhego sa roboto',
    '😺' => 'sefatlhego sa katse se se nyenyang ka molomo o o bulegileng',
    '😸' => 'sefatlhego sa katse se se šenneng meno ka matlho a a nyenyang',
    '😹' => 'sefatlhego sa katse ka dikeledi tsa boitumelo',
    '😻' => 'sefatlhego sa katse se se nyenyang ka matlho a pelo',
    '😼' => 'sefatlhego sa katse ka monyenyo wa lesotlo',
    '😽' => 'sefatlhego sa katse se se atlang ka matlho a a tswetsweng',
    '🙀' => 'sefatlhego sa katse sa go lapa',
    '😿' => 'sefatlhego sa katse se se lelang',
    '😾' => 'sefatlhego sa katse se se tsuputseng molomo',
    '🙈' => 'kgabo ya se-bone-boikepo',
    '🙉' => 'kgabo ya se-utlwe-boikepo',
    '🙊' => 'kgabo ya se-bue-boikepo',
    '💌' => 'lekwalo la marato',
    '💘' => 'pelo ka motsu',
    '💝' => 'pelo e e nang le ribone',
    '💖' => 'pelo e e tsabakelang',
    '💗' => 'pelo e e golang',
    '💓' => 'pelo e e ubang',
    '💞' => 'dipelo tse di dikologang',
    '💕' => 'pelo tse pedi',
    '💟' => 'mokgabiso wa pelo',
    '❣' => 'kgakgamalo ya pelo e e imelwang',
    '💔' => 'pelo e e botlhoko',
    '❤' => 'pelo e khibidu',
    '🧡' => 'pelo ya mmala wa lamune',
    '💛' => 'pelo e e serolwana',
    '💚' => 'pelo e tala',
    '💙' => 'pelo e e pududu',
    '💜' => 'pelo e e phephole',
    '🖤' => 'pelo e ntsho',
    '💋' => 'letshwao la moatlo',
    '💯' => 'dintlha di le lekgolo',
    '💢' => 'letshwao la kgalefo',
    '💥' => 'thulano',
    '💫' => 'sedidi',
    '💦' => 'marothodi a mofufutso',
    '💨' => 'ragoga',
    '🕳' => 'lehuti',
    '💬' => 'balune ya puo',
    '🗨' => 'pudula ya puo e e kafa molemeng',
    '🗯' => 'pudula ya kgalefo e e kafa mojeng',
    '💭' => 'balune ya kakanyo',
    '💤' => 'zzz',
    '👋' => 'letsogo le le tsholeditsweng',
    '🤚' => 'lemorago le le kwa godimo la letsogo',
    '🖐' => 'letshogo le le kwa godimo ka menwana e gatogantswe',
    '✋' => 'letsogo le le kwa godimo',
    '🖖' => 'tumediso ya vulcan',
    '👌' => 'letsogo la GO SIAME',
    '✌' => 'letsogo la phenyo',
    '🤞' => 'fapaanya menwana',
    '🤟' => 'sesupo sa ke a go rata',
    '🤘' => 'letshwao la dinaka',
    '🤙' => 'letsogo la mpitsa',
    '👈' => 'lemorago la monwana o o supang o supile molemeng',
    '👉' => 'lemorago la monwana o o supang o supile mojeng',
    '👆' => 'lemorago la monwana o o supang o supile godimo',
    '🖕' => 'monwana o o mo gare',
    '👇' => 'lemorago la monwana o o supang o supile tlase',
    '☝' => 'monwana o o supang o supile sodimo',
    '👍' => 'bokgonojwe godimo',
    '👎' => 'bokgonojwe tlase',
    '✊' => 'lebole le le kwa godimo',
    '👊' => 'lebole le le tlang go wena',
    '🤛' => 'lebole le le lebileng molemeng',
    '🤜' => 'lebole le le lebileng mojeng',
    '👏' => 'matsogo a a opiwang',
    '🙌' => 'matsogo a a tsholeditsweng',
    '👐' => 'matsogo a a bulegileng',
    '🤲' => 'magofi mmogo kwa godimo',
    '🤝' => 'tshwarano ka letsogo',
    '🙏' => 'matsogo a a mennweng',
    '✍' => 'letsogo le le kwalang',
    '💅' => 'politšhe ya dinala',
    '🤳' => 'itsaya senepe',
    '💪' => 'dipotongwane tse di obegileng',
    '👂' => 'tsebe',
    '👃' => 'nko',
    '🧠' => 'boboko',
    '👀' => 'matlho',
    '👁' => 'leitlho',
    '👅' => 'leleme',
    '👄' => 'molomo',
    '👶' => 'lesea',
    '🧒' => 'ngwana',
    '👦' => 'mosimane',
    '👧' => 'mosetsana',
    '🧑' => 'mogolo',
    '👱' => 'motho wa moriri o mosetlha',
    '👨' => 'monna',
    '🧔' => 'motho yo o ditedu',
    '👩' => 'mosadi',
    '🧓' => 'mogolo yo o tsofetseng',
    '👴' => 'monnamogolo',
    '👵' => 'mosadimogolo',
    '🙍' => 'motho yo o menneng phatla',
    '🙎' => 'motho yo o tsuputseng molomo',
    '🙅' => 'motho yo o reng NNYAA ka puo ya matsogo',
    '🙆' => 'motho yo o reng GO SIAME ka puo ya matsogo',
    '💁' => 'motho a sekamisa letsogo',
    '🙋' => 'motho a tsholetsa letsogo',
    '🙇' => 'motho a obega',
    '🤦' => 'motho ka legofi mo sefatlhegong',
    '🤷' => 'motho yo o tsholetsang magetla',
    '👮' => 'lepodise',
    '🕵' => 'boteketifi',
    '💂' => 'modisa',
    '👷' => 'modiri mo kagong',
    '🤴' => 'kgosana',
    '👸' => 'kgosanagadi',
    '👳' => 'motho a rwele sehapatlhogo',
    '👲' => 'monna ka kepisi ya matšhaena',
    '🧕' => 'mosadi ka sehapatlhogo',
    '🤵' => 'monna mo tuxedo',
    '👰' => 'monyadwi ka lesire',
    '🤰' => 'mosadi wa moimana',
    '🤱' => 'anyisa',
    '👼' => 'moengele wa lesea',
    '🎅' => 'Santa Tlelose',
    '🤶' => 'Mme Tlelose',
    '🧙' => 'matwetwe',
    '🧚' => 'ya ditlhamane',
    '🧛' => 'mmamathwane wa vampire',
    '🧜' => 'motho wa tlhamane',
    '🧝' => 'mankge mo ditlhamaneng',
    '🧞' => 'moengele wa tlhamane',
    '🧟' => 'sombi',
    '💆' => 'motho yo o bonang tshidilo',
    '💇' => 'motho yo o beolang moriri',
    '🚶' => 'motho yo o tsamayang',
    '🏃' => 'motho yo o tabogang',
    '💃' => 'mosadi yo o binang',
    '🕺' => 'monna yo o binang',
    '🕴' => 'monna mo sutung ya kgwebo a ya godimo',
    '👯' => 'batho ka ditsebe tsa mmutla mo moletlong',
    '🧖' => 'motho mo kamoreng ya metsi a a belang',
    '🧗' => 'motho yo o palamang',
    '🤺' => 'motho yo o dirang legora',
    '🏇' => 'lobelo lwa dipitse',
    '⛷' => 'motho yo o relelang mo semathaneng',
    '🏂' => 'mopagami wa boto ya semathana',
    '🏌' => 'motho yo o tshamekang kolofo',
    '🏄' => 'motho yo o lelemelang mo metsing',
    '🚣' => 'motho yo o kgweetsang mokoro',
    '🏊' => 'motho yo o thumang',
    '⛹' => 'motho yo o itaaganyang bolo fa fatshe',
    '🏋' => 'motho yo o tsholetsang ditshipi',
    '🚴' => 'motho yo o kgweetsang sekuta',
    '🚵' => 'motho yo o kgweetsang sekuta mo thabeng',
    '🤸' => 'motho yo o tsamaisang kolotsana',
    '🤼' => 'batho ba ba lwang ka go mekamekana',
    '🤽' => 'motho yo o tshamekang polo ya metsi',
    '🤾' => 'motho yo o tshamekang bolo ya letsogo',
    '🤹' => 'motho yo o mekamekanang le dilo dintsi',
    '🧘' => 'motho mo boemong jwa lotus',
    '🛀' => 'motho yo o tlhapang',
    '🛌' => 'motho mo bolaong',
    '👭' => 'basadi ba babedi ba tshwarane matsogo',
    '👫' => 'monna le mosadi ba tshwarane matsogo',
    '👬' => 'banna ba babedi ba tshwarane matsogo',
    '💏' => 'atla',
    '💑' => 'bobedi ka pelo',
    '🗣' => 'tlhogo e e buang',
    '👤' => 'sehuba mo moriting',
    '👥' => 'dihuba mo moriting',
    '👪' => 'lelapa',
    '👣' => 'metlhala ya maoto',
    '🐵' => 'sefatlhego sa kgabo',
    '🐒' => 'kgabo',
    '🦍' => 'korila',
    '🐶' => 'sefatlhego sa ntšwa',
    '🐕' => 'ntšwa',
    '🐩' => 'ntšwa ya poodle',
    '🐺' => 'sefatlhego sa phiri',
    '🦊' => 'sefatlhego sa phokoje',
    '🐱' => 'sefatlhego sa katse',
    '🐈' => 'katse',
    '🦁' => 'sefatlhego sa tau',
    '🐯' => 'sefatlhego sa nkwe',
    '🐅' => 'nkwe',
    '🐆' => 'lengau',
    '🐴' => 'sefatlhego sa pitse',
    '🐎' => 'pitse',
    '🦄' => 'sefatlhego sa unicorn',
    '🦓' => 'pitse ya naga',
    '🦌' => 'phuduhudu',
    '🐮' => 'sefatlhego sa kgomo',
    '🐂' => 'kgomo ya pelesa',
    '🐃' => 'nare ya metsi',
    '🐄' => 'kgomo',
    '🐷' => 'sefatlhego sa kolobe',
    '🐖' => 'kolobe',
    '🐗' => 'kolobe ya naga',
    '🐽' => 'nko ya kolobe',
    '🐏' => 'phelehu',
    '🐑' => 'nku',
    '🐐' => 'podi',
    '🐪' => 'kamela',
    '🐫' => 'kamela e e diroto di pedi',
    '🦒' => 'thutlwa',
    '🐘' => 'tlou',
    '🦏' => 'tshukudu',
    '🐭' => 'sefatlhego sa peba',
    '🐁' => 'peba',
    '🐀' => 'legotlo',
    '🐹' => 'sefatlhego sa serathi',
    '🐰' => 'sefatlhego sa mmutla',
    '🐇' => 'mmutla',
    '🐿' => 'samane',
    '🦔' => 'hejehoko',
    '🦇' => 'mmamathwane',
    '🐻' => 'sefatlhego sa bera',
    '🐨' => 'koala',
    '🐼' => 'sefatlhego sa panda',
    '🐾' => 'metlhala ya maroo',
    '🦃' => 'thekhi',
    '🐔' => 'koko',
    '🐓' => 'mokoko',
    '🐣' => 'kokwana e e thuthusang lee',
    '🐤' => 'kokwanyana',
    '🐥' => 'kokwana e e lebileng kwa pele',
    '🐦' => 'nonyane',
    '🐧' => 'phengwene',
    '🕊' => 'lephoi',
    '🦅' => 'ntsu',
    '🦆' => 'pidipidi',
    '🦉' => 'morubisi',
    '🐸' => 'sefatlhego sa segwagwa',
    '🐊' => 'kwena',
    '🐢' => 'khudu',
    '🦎' => 'mokgatitswane',
    '🐍' => 'noga',
    '🐲' => 'sefatlhego sa kgwanyape',
    '🐉' => 'kgwanyape',
    '🦕' => 'sauropod',
    '🦖' => 'T-Rex',
    '🐳' => 'leruarua le le runyang',
    '🐋' => 'leruarua',
    '🐬' => 'dolefini',
    '🐟' => 'tlhapi',
    '🐠' => 'tlhapi ya boboatsatsi',
    '🐡' => 'tlhapi ya blowfish',
    '🦈' => 'shaka',
    '🐙' => 'okothopase',
    '🐚' => 'kgapetla e e itshopang',
    '🦀' => 'lekakaie',
    '🦐' => 'shrimp',
    '🦑' => 'squid',
    '🐌' => 'kgopa',
    '🦋' => 'serurubele',
    '🐛' => 'setshedinyana',
    '🐜' => 'tshoswane',
    '🐝' => 'notshi',
    '🐞' => 'khukhwana',
    '🦗' => 'kirikete',
    '🕷' => 'sekgokgo',
    '🕸' => 'bobi jwa sekgokgo',
    '🦂' => 'phepeng',
    '💐' => 'ngatana ya dithunya',
    '🌸' => 'go thunya tšheri',
    '💮' => 'sethunya se sesweu',
    '🏵' => 'mokgabiso',
    '🌹' => 'sethunya',
    '🥀' => 'sethunya se se tshwapileng',
    '🌺' => 'hibiscus',
    '🌻' => 'sonobolomo',
    '🌼' => 'thunya',
    '🌷' => 'tšhulipi',
    '🌱' => 'sata',
    '🌲' => 'setlhare se se nnetseng setala ruri',
    '🌳' => 'setlhare se se tlhotlhoregang matlhare',
    '🌴' => 'setlhare sa mokolane',
    '🌵' => 'mokgwapa',
    '🌾' => 'ngata ya raese',
    '🌿' => 'setswammung',
    '☘' => 'sejalo sa shamrock',
    '🍀' => 'clover e e matlhare mane',
    '🍁' => 'letlhare la maple',
    '🍂' => 'letlhare le le oleng',
    '🍃' => 'letlhare le le phaphaselang mo phefong',
    '🍄' => 'mašerumo',
    '🍇' => 'merara',
    '🍈' => 'melone',
    '🍉' => 'legapu',
    '🍊' => 'tangerine',
    '🍋' => 'lamune',
    '🍌' => 'panana',
    '🍍' => 'peinapole',
    '🍎' => 'apole e khibidu',
    '🍏' => 'apole e tala',
    '🍐' => 'pere',
    '🍑' => 'perekisi',
    '🍒' => 'ditšheri',
    '🍓' => 'seteroberi',
    '🥝' => 'leungo la kiwi',
    '🍅' => 'tamati',
    '🥥' => 'khokhonate',
    '🥑' => 'abokato',
    '🍆' => 'eggplant',
    '🥔' => 'tapole',
    '🥕' => 'segwete',
    '🌽' => 'setlhotlha sa mmidi',
    '🌶' => 'pepere e e fisang',
    '🥒' => 'komkomore',
    '🥦' => 'borokholi',
    '🥜' => 'matonkomane',
    '🌰' => 'chestnut',
    '🍞' => 'senkgwe',
    '🥐' => 'croissant',
    '🥖' => 'borotho jwa baguette',
    '🥨' => 'pretzel',
    '🥞' => 'diphenekheiki',
    '🧀' => 'setena sa tšhisi',
    '🍖' => 'nama mo lerapong',
    '🍗' => 'leoto la koko',
    '🥩' => 'lenathwana la nama',
    '🥓' => 'beikhone',
    '🍔' => 'hamburger',
    '🍟' => 'ditšhipisi',
    '🍕' => 'pizza',
    '🌭' => 'hot dog',
    '🥪' => 'sementšhisi',
    '🌮' => 'taco',
    '🌯' => 'burrito',
    '🥙' => 'borotho jo bo suketsweng dilo',
    '🥚' => 'lee',
    '🍳' => 'kapei',
    '🥘' => 'pane e tshesane ya dijo',
    '🍲' => 'pitsa ya dijo',
    '🥣' => 'mogopo le leswana',
    '🥗' => 'salate e tala',
    '🍿' => 'phopokhone',
    '🥫' => 'dijo tse di mo motemeng',
    '🍱' => 'lebokoso la bento',
    '🍘' => 'cracker ya raese',
    '🍙' => 'bolo ya raese',
    '🍚' => 'raese e e apeilweng',
    '🍛' => 'raese ya kheri',
    '🍜' => 'mogopo wa metsi a a belang',
    '🍝' => 'sepakethi',
    '🍠' => 'potata e e gadikilweng',
    '🍢' => 'oden',
    '🍣' => 'sushi',
    '🍤' => 'shrimp e e gadikilweng',
    '🍥' => 'tlhapi e e dirilweng kuku ka swirl',
    '🍡' => 'dango',
    '🥟' => 'ledombolo',
    '🥠' => 'khukhi ya lesego',
    '🥡' => 'lebokoso la dijo tse di jelwang kwa gae',
    '🍦' => 'aese kirimi e e seng thata',
    '🍧' => 'shaved ice',
    '🍨' => 'aese kirimi',
    '🍩' => 'donate',
    '🍪' => 'khukhi',
    '🎂' => 'kuku ya letsatsi la matsalo',
    '🍰' => 'shortcake',
    '🥧' => 'phae',
    '🍫' => 'setena sa tšhokolete',
    '🍬' => 'semonamone',
    '🍭' => 'lolipopo',
    '🍮' => 'khasetete',
    '🍯' => 'honey pot',
    '🍼' => 'lebotlolo la lesea',
    '🥛' => 'galase ya maši',
    '☕' => 'mogodungwana',
    '🍵' => 'kopi ya tee e e se nang matshwaro',
    '🍶' => 'sake',
    '🍾' => 'lebotlolo ka sekhurumelo se se thunyang',
    '🍷' => 'galase ya beine',
    '🍸' => 'galase ya cocktail',
    '🍹' => 'seno sa boboatsatsi',
    '🍺' => 'bikiri ya biri',
    '🍻' => 'bikiri ya biri e e tudumang',
    '🥂' => 'digalase tse di tudumang',
    '🥃' => 'galase ya tumbler',
    '🥤' => 'kopi ka setoroo',
    '🥢' => 'di-chopstick',
    '🍽' => 'thipa le forotlho le poleite',
    '🍴' => 'thipa le forotlho',
    '🥄' => 'leswana',
    '🔪' => 'thipa ya go apaya',
    '🏺' => 'amphora',
    '🌍' => 'kgolokwe e e bontshang Yuropa le Aforika',
    '🌎' => 'kgolokwe e e bontshang dinaga tsa Amerika',
    '🌏' => 'kgolokwe e e bontshang Asia le Australia',
    '🌐' => 'kgolokwe e e bontshang mela ya meridian',
    '🗺' => 'mmapa wa lefatshe',
    '🗾' => 'mmapa wa Japane',
    '🏔' => 'thaba e e apesitsweng ke semathane',
    '⛰' => 'thaba',
    '🌋' => 'lekgwamolelo',
    '🗻' => 'thaba ya fuji',
    '🏕' => 'go thibelela',
    '🏖' => 'bothoko jwa lewatle ka sekhukhu',
    '🏜' => 'sekaka',
    '🏝' => 'setlhaketlhake sa sekaka',
    '🏞' => 'serapa sa bosetšhaba',
    '🏟' => 'setadiamo',
    '🏛' => 'kago ya tlelasiki',
    '🏗' => 'go agiwa ga kago',
    '🏘' => 'matlo',
    '🏚' => 'ntlo ya letlotla',
    '🏠' => 'ntlo',
    '🏡' => 'ntlo ka tshingwana',
    '🏢' => 'kago ya ofisi',
    '🏣' => 'ofisi ya poso ya Japane',
    '🏤' => 'kantoro ya poso',
    '🏥' => 'bookelo',
    '🏦' => 'banka',
    '🏨' => 'hotele',
    '🏩' => 'hotele ya marato',
    '🏪' => 'lebentlele la go reka',
    '🏫' => 'sekolo',
    '🏬' => 'lebentlele la dithoto',
    '🏭' => 'madirelo',
    '🏯' => 'kagophemelo ya Japane',
    '🏰' => 'kagophemelo',
    '💒' => 'mokete wa lenyalo',
    '🗼' => 'tora ya Tokyo',
    '🗽' => 'Sefikantswe sa Kgololesego',
    '⛪' => 'kereke',
    '🕌' => 'mosque',
    '🕍' => 'sinagoge',
    '⛩' => 'sefikantswe sa shinto',
    '🕋' => 'kaaba',
    '⛲' => 'motswedi',
    '⛺' => 'tente',
    '🌁' => 'tletse mouwane',
    '🌃' => 'bosigo ka dinaledi',
    '🏙' => 'boalo jwa toropo',
    '🌄' => 'tlhabo ya letsatsi mo dithabeng',
    '🌅' => 'tlhabo ya letsatsi',
    '🌆' => 'motsesetoropo ka phirimo ya letsatsi',
    '🌇' => 'phirimo ya letsatsi',
    '🌉' => 'borogo bosigo',
    '♨' => 'metswedi e e fisang',
    '🎠' => 'pitse ya carousel',
    '🎡' => 'maotwana a ferris',
    '🎢' => 'ya godimo le tlase',
    '💈' => 'pale ya mobeodi',
    '🎪' => 'tente ya disorokisi',
    '🚂' => 'tlhogo ya terena',
    '🚃' => 'kara ya ralawe',
    '🚄' => 'terena ya lobelo',
    '🚅' => 'terena ya lobelo ka ntlha ya lerumo',
    '🚆' => 'terena',
    '🚇' => 'metro',
    '🚈' => 'lebone la seporo',
    '🚉' => 'seteišene',
    '🚊' => 'teroli',
    '🚝' => 'seporo se le sengwe',
    '🚞' => 'seporo mo thabeng',
    '🚋' => 'kara ya teroli',
    '🚌' => 'bese',
    '🚍' => 'bese e e tlang',
    '🚎' => 'bese ya teroli',
    '🚐' => 'minibese',
    '🚑' => 'ambulense',
    '🚒' => 'enjini ya molelo',
    '🚓' => 'kara ya mapodise',
    '🚔' => 'kara ya mapodise e e tlang',
    '🚕' => 'tekesi',
    '🚖' => 'tekesi e e tlang',
    '🚗' => 'sejanaga',
    '🚘' => 'sejanaga se se tlang',
    '🚙' => 'koloi e e thusang ya metshameko',
    '🚚' => 'lori ya dithomelo',
    '🚛' => 'lori ya diteroko tse di tshwaragantsweng',
    '🚜' => 'terekere',
    '🏎' => 'kara ya bothubalebelo',
    '🏍' => 'sekuta',
    '🛵' => 'sethuthuthu sa enjene',
    '🚲' => 'baesekele',
    '🛴' => 'sethuthuthu',
    '🚏' => 'boemelabese',
    '🛣' => 'tsela ya dikoloi',
    '🛤' => 'seporo sa ralawe',
    '🛢' => 'moropa wa oli',
    '⛽' => 'pompo ya mafura',
    '🚨' => 'lebone la kara ya mapodise',
    '🚥' => 'lebone la pharakano le le phekameng',
    '🚦' => 'lebone la pharakano le le emeng',
    '🛑' => 'letshwao la go ema',
    '🚧' => 'kago',
    '⚓' => 'tshetledi',
    '⛵' => 'mokorwana',
    '🛶' => 'kanoe',
    '🚤' => 'mokoro wa lobelo',
    '🛳' => 'sekepe sa bapagami',
    '⛴' => 'seketswana',
    '🛥' => 'mokoro wa enjene',
    '🚢' => 'sekepe',
    '✈' => 'sefofane',
    '🛩' => 'sefofane se sennye',
    '🛫' => 'go tloga ga sefofane',
    '🛬' => 'go goroga ga sefofane',
    '💺' => 'setulo',
    '🚁' => 'helikopetere',
    '🚟' => 'seporo se se kwa godimo',
    '🚠' => 'mogala wa seporo wa mo thabeng',
    '🚡' => 'tselana ya teroli e e mo moweng',
    '🛰' => 'sathelaete',
    '🚀' => 'rokete',
    '🛸' => 'piring e e fofang',
    '🛎' => 'tleloko ya motlhokomedi wa hotele',
    '⌛' => 'galase ya sesupaura',
    '⏳' => 'galase ya sesupaura ka santa e e elelang',
    '⌚' => 'lebelela',
    '⏰' => 'tshupanako ya alamo',
    '⏱' => 'setopowatšhe',
    '⏲' => 'tshupanako ya sesupanako',
    '🕰' => 'tshupanako ya mo šelefong',
    '🕛' => 'ura ya lesomepedi',
    '🕧' => 'masometharo morago ga lesomepedi',
    '🕐' => 'ura ya bongwe',
    '🕜' => 'masometharo morago ga ura ya bongwe',
    '🕑' => 'ura ya bobedi',
    '🕝' => 'masometharo morago ga ura ya bobedi',
    '🕒' => 'ura ya boraro',
    '🕞' => 'masometharo morago ga ura ya boraro',
    '🕓' => 'ura ya bone',
    '🕟' => 'masometharo morago ga ura ya bone',
    '🕔' => 'ura ya botlhano',
    '🕠' => 'masometharo morago ga ura ya botlhano',
    '🕕' => 'ura ya borataro',
    '🕡' => 'masometharo morago ga ura ya borataro',
    '🕖' => 'ura ya bosupa',
    '🕢' => 'masometharo morago ga ura ya bosupa',
    '🕗' => 'ura ya borobedi',
    '🕣' => 'masometharo morago ga ura ya borobedi',
    '🕘' => 'ura ya borobonngwe',
    '🕤' => 'masometharo morago ga ura ya borobonngwe',
    '🕙' => 'ura ya lesome',
    '🕥' => 'masometharo morago ga ura ya lesome',
    '🕚' => 'ura ya lesomenngwe',
    '🕦' => 'masometharo morago ga ura ya lesomenngwe',
    '🌑' => 'ngwedi o mošwa',
    '🌒' => 'sephatlo sa ngwedi o o phatsimang',
    '🌓' => 'kotara ya ntlha ya ngwedi',
    '🌔' => 'kotara ya boraro ya ngwedi o o phatsimang',
    '🌕' => 'ngwedi o o tletseng',
    '🌖' => 'kotara ya boraro ya ngwedi o o batlang o fifala',
    '🌗' => 'kotara ya bofelo ya ngwedi',
    '🌘' => 'sephatlo sa ngwedi o o fifalang',
    '🌙' => 'sephatlo sa ngwedi',
    '🌚' => 'sefatlhego sa ngwedi o mošwa',
    '🌛' => 'kotara ya ntlha ya ngwedi ka sefatlhego',
    '🌜' => 'kotara ya bofelo ya ngwedi ka sefatlhego',
    '🌡' => 'selekanyamogote',
    '☀' => 'letsatsi',
    '🌝' => 'ngwedi o o tletseng ka sefatlhego',
    '🌞' => 'letsatsi ka sefatlhego',
    '⭐' => 'naledi e e mo magareng e tshweu',
    '🌟' => 'naledi e e galalelang',
    '🌠' => 'naledi e e thunyang',
    '🌌' => 'molalatladi',
    '☁' => 'leru',
    '⛅' => 'letsatsi kafa teng ga maru',
    '⛈' => 'leru ka legadima le pula',
    '🌤' => 'letsatsi kafa teng ga leru le lennye',
    '🌥' => 'letsatsi kafa teng ga leru le legolo',
    '🌦' => 'letsatsi kafa teng ga leru la pula',
    '🌧' => 'leru ka pula',
    '🌨' => 'leru ka semathana',
    '🌩' => 'leru ka legadima',
    '🌪' => 'phefo ya ledimo',
    '🌫' => 'mouwane',
    '🌬' => 'sefatlhego sa phefo',
    '🌀' => 'setsuatsue',
    '🌈' => 'motshewagodimo',
    '🌂' => 'sekhukhu se se tswetsweng',
    '☂' => 'sekhukhu',
    '☔' => 'sekhukhu ka marothodi a pula',
    '⛱' => 'sekhukhu mo mmung',
    '⚡' => 'motlakase o o maatla',
    '❄' => 'ditlhaka tsa semathana',
    '☃' => 'monna wa semathana',
    '⛄' => 'monna wa semathana ntle le semathana',
    '☄' => 'khomete',
    '🔥' => 'molelo',
    '💧' => 'lerothodinyana',
    '🌊' => 'lekhubu la metsi',
    '🎃' => 'jack-o-lantern',
    '🎄' => 'setlhare sa Keresemose',
    '🎆' => 'ditlelabore',
    '🎇' => 'sedira matlhasedi',
    '✨' => 'matlhasedi',
    '🎈' => 'balune',
    '🎉' => 'sethunyi mo moketeng',
    '🎊' => 'bolo ya confetti',
    '🎋' => 'setlhare sa tanabata',
    '🎍' => 'sekgabisi sa phaene',
    '🎎' => 'bompopo ba Majapane',
    '🎏' => 'khapo seterima',
    '🎐' => 'tshipi e e dirang ka phefo',
    '🎑' => 'mokete wa go leba ngwedi',
    '🎀' => 'ribone',
    '🎁' => 'mpho e e phuthetsweng',
    '🎗' => 'ribone ya segakolodi',
    '🎟' => 'ditekete tsa kamogelo',
    '🎫' => 'tekete',
    '🎖' => 'metale wa sesole',
    '🏆' => 'sekgele',
    '🏅' => 'metale wa metshameko',
    '🥇' => 'metale wa maemo a bo1',
    '🥈' => 'metale wa maemo a bo2',
    '🥉' => 'metale wa maemo a bo3',
    '⚽' => 'kgwele ya dinao',
    '⚾' => 'beisebolo',
    '🏀' => 'baseketebolo',
    '🏐' => 'bolibolo',
    '🏈' => 'kgwele ya dinao ya amerika',
    '🏉' => 'kgwele ya dinao ya rakabi',
    '🎾' => 'thenese',
    '🎳' => 'boula',
    '🏏' => 'motshameko wa kirikete',
    '🏑' => 'hokhi ya mo lebaleng',
    '🏒' => 'hokhi ya aese',
    '🏓' => 'ping pong',
    '🏸' => 'badminton',
    '🥊' => 'tlelafo ya mabole',
    '🥋' => 'yuniforomo ya metshameko ya martial arts',
    '🥅' => 'letloa la dino',
    '⛳' => 'folaga mo mosimeng',
    '⛸' => 'sekeite sa aese',
    '🎣' => 'pale ya go tshwara ditlhapi',
    '🎽' => 'hempe ya go taboga',
    '🎿' => 'skis',
    '🛷' => 'kariki ya dipitse',
    '🥌' => 'letlapa le le obegileng',
    '🎯' => 'titeo e e tlhamaletseng',
    '🔫' => 'phisitolo',
    '🎱' => 'bolo ya pool 8',
    '🔮' => 'bolo e e tsabakelang',
    '🎮' => 'motshameko wa bidio',
    '🕹' => 'joesetiki',
    '🎰' => 'motšhine wa selote',
    '🎲' => 'go swa ga motshameko',
    '♠' => 'sutu ya sepeite',
    '♥' => 'sutu ya pelo',
    '♦' => 'sutu ya taemane',
    '♣' => 'sutu ya tlelapo',
    '🃏' => 'joukha',
    '🀄' => 'kgwanyape e khibidu ya mahjong',
    '🎴' => 'dikarata tsa go tshameka ka dithunya',
    '🎭' => 'tiragatso',
    '🖼' => 'setshwantsho se se foreimilweng',
    '🎨' => 'phalete ya modiragatsi',
    '👓' => 'digalase',
    '🕶' => 'diborele tsa letsatsi',
    '👔' => 'thae ya molala',
    '👕' => 'sekipa',
    '👖' => 'dijine',
    '🧣' => 'sekhafo',
    '🧤' => 'ditlelafo',
    '🧥' => 'jase',
    '🧦' => 'dikausu',
    '👗' => 'mosese',
    '👘' => 'kimono',
    '👙' => 'bikini',
    '👚' => 'diaparo tsa basadi',
    '👛' => 'sepatšhe',
    '👜' => 'kgetsi ya letsogo',
    '👝' => 'kgetsana e e tshwarwang',
    '🛍' => 'dikgetsana tsa go reka',
    '🎒' => 'sephuthelo se se belegwang sa sekolo',
    '👞' => 'setlhako sa banna',
    '👟' => 'ditlhako tsa go taboga',
    '👠' => 'dikwaekwae tse di kwa godimo',
    '👡' => 'ditlepetlepe tsa basadi',
    '👢' => 'dibutshe tsa basadi',
    '👑' => 'serwalo sa bogosi',
    '👒' => 'hutshe ya basadi',
    '🎩' => 'hutshe e e godimo',
    '🎓' => 'kepisi ya kalogo',
    '🧢' => 'kepisi e e duelang',
    '⛑' => 'helemete ya modiri wa monamodi',
    '📿' => 'melogo ya thapelo',
    '💄' => 'setshaso sa molomo',
    '💍' => 'palamonwana',
    '💎' => 'leje la botlhokwa',
    '🔇' => 'sepikara se se timilweng modumo',
    '🔈' => 'modumo o o kwa tlase wa sepikara',
    '🔉' => 'modumo o o mo magareng wa sepikara',
    '🔊' => 'modumo o o kwa godimo wa sepikara',
    '📢' => 'sebuelagodimo',
    '📣' => 'founokgolo',
    '📯' => 'lenaka la poso',
    '🔔' => 'tleloko',
    '🔕' => 'tleloko e e nang le mosego',
    '🎼' => 'dintlha tsa mmino',
    '🎵' => 'ntlhana ya mmino',
    '🎶' => 'dintlhana tsa mmino',
    '🎙' => 'maekerofouno wa setudio',
    '🎚' => 'selaetara sa lebele',
    '🎛' => 'dikonopo tsa go laola',
    '🎤' => 'maekerofouno',
    '🎧' => 'sereetsaditsebeng',
    '📻' => 'radio',
    '🎷' => 'sekesofouno',
    '🎺' => 'lenaka',
    '🎸' => 'katara',
    '🎹' => 'khiiboto ya mmino',
    '🎻' => 'bayolene',
    '🥁' => 'moropa',
    '📱' => 'founo ya mobaele',
    '📲' => 'founo ya mobaele ka motsu',
    '☎' => 'thelefouno',
    '📞' => 'seamogela thelefouno',
    '📟' => 'pheijara',
    '📠' => 'motšhine wa go fekesa',
    '🔋' => 'beteri',
    '🔌' => 'polaka ya motlakase',
    '💻' => 'khomphiutha ya lepothopo',
    '🖥' => 'khompiutha ya desekethopo',
    '🖨' => 'porinthara',
    '⌨' => 'khiiboto',
    '🖱' => 'mause wa khomphiutha',
    '🖲' => 'therekebolo',
    '💽' => 'disike ya khomphiutha',
    '💾' => 'folopi disike',
    '💿' => 'disike ya pono',
    '📀' => 'dvd',
    '🎥' => 'khemera ya baesekopo',
    '🎞' => 'diforeime tsa filimi',
    '📽' => 'porojeketara ya filimi',
    '🎬' => 'boto ya sediramodumo',
    '📺' => 'thelebišene',
    '📷' => 'khemera',
    '📸' => 'khemera ka foleše',
    '📹' => 'khemera ya bidio',
    '📼' => 'khasete ya bidio',
    '🔍' => 'galase ya segodisi e e supileng kwa molemeng',
    '🔎' => 'galase ya segodisi e e supileng kwa mojeng',
    '🕯' => 'kerese',
    '💡' => 'tleloupu',
    '🔦' => 'lebone la foleše',
    '🏮' => 'kerese ya pampiri e khibidu',
    '📔' => 'buka ya dintlha ka sekhurumelo se se kgabisang',
    '📕' => 'buka e e tswetsweng',
    '📖' => 'buka e e bulegileng',
    '📗' => 'buka e tala',
    '📘' => 'buka e pududu',
    '📙' => 'buka ya mmala wa namune',
    '📚' => 'dibuka',
    '📓' => 'buka ya dintlha',
    '📒' => 'lejara',
    '📃' => 'tsebe ka motshopo',
    '📜' => 'sekorolo',
    '📄' => 'tsebe e e lebileng godimo',
    '📰' => 'lekwalodikgang',
    '🗞' => 'lekwalodikgang le le rotsweng',
    '📑' => 'dithebo tsa matshwaotsebe',
    '🔖' => 'letshwaotsebe',
    '🏷' => 'leibole',
    '💰' => 'kgetsana ya madi',
    '💴' => 'madi a pampiri a yen',
    '💵' => 'madi a pampiri a dolara',
    '💶' => 'madi a pampiri a euro',
    '💷' => 'madi a pampiri a ponto',
    '💸' => 'madi ka diphuka',
    '💳' => 'karata ya sekoloto',
    '💹' => 'tšhate e e oketsegang ka yen',
    '✉' => 'enfelopo',
    '📧' => 'imeile',
    '📨' => 'enfelopo e e tlang',
    '📩' => 'enfelopo ka motsu',
    '📤' => 'terei ya makwalo a a tswang',
    '📥' => 'terei ya makwalo a a tsenang',
    '📦' => 'sephuthelwana',
    '📫' => 'lebokoso la makwalo le le tswetsweng ka folaga e e kwa godimo',
    '📪' => 'lebokoso la makwalo le le tswetsweng ka folaga e e isitsweng tlase',
    '📬' => 'lebokoso la makwalo le le bulegileng ka folaga e e goleditsweng',
    '📭' => 'lebokoso la makwalo le le butsweng ka folaga e e isitsweng tlase',
    '📮' => 'lebokoso la poso',
    '🗳' => 'lebokoso la balote ka dibalote',
    '✏' => 'pensele',
    '✒' => 'nibi e ntsho',
    '🖋' => 'pene ya motswedi',
    '🖊' => 'pene',
    '🖌' => 'boraše jwa pente',
    '🖍' => 'kherayone',
    '📝' => 'memo',
    '💼' => 'borifikheisi',
    '📁' => 'setsholadifaele sa faele',
    '📂' => 'bula setsholadifaele sa faele',
    '🗂' => 'dikgaoganyi tsa karatatshupane',
    '📅' => 'khalendara',
    '📆' => 'gagola khalendara',
    '🗒' => 'phete ya go kwalela e e motshopo',
    '🗓' => 'khalendara ya motshopo',
    '📇' => 'karatatshupane',
    '📈' => 'tšhate e a oketsega',
    '📉' => 'tšhate e a fokotsega',
    '📊' => 'tšhate ya bara',
    '📋' => 'peelodimamaretswa',
    '📌' => 'kgorometsaphine',
    '📍' => 'kgorometsaphine e kgolokwe',
    '📎' => 'lenathwana la pampiri',
    '🖇' => 'lenathwana la pampiri le le gokagantsweng',
    '📏' => 'rulara e e tlhamaletseng',
    '📐' => 'rulara e e khutlotharo',
    '✂' => 'sekere',
    '🗃' => 'lebokoso la faele ya dikarata',
    '🗄' => 'khabinete ya faele',
    '🗑' => 'basekete ya matlakala',
    '🔒' => 'notletswe',
    '🔓' => 'notlolotswe',
    '🔏' => 'notletswe ka pene',
    '🔐' => 'notletswe ka selotlolo',
    '🔑' => 'senotlolo',
    '🗝' => 'senotlolo sa bogologolo',
    '🔨' => 'hamore',
    '⛏' => 'sela',
    '⚒' => 'hamore le sela',
    '🛠' => 'hamore le koba',
    '🗡' => 'tšhaka',
    '⚔' => 'ditšhaka tse di fapaantsweng',
    '💣' => 'bomo',
    '🏹' => 'bora le motsu',
    '🛡' => 'sireletsa',
    '🔧' => 'koba',
    '🔩' => 'sekurufu le konopo',
    '⚙' => 'kere',
    '🗜' => 'tlelempe',
    '⚖' => 'sekale sa balanse',
    '🔗' => 'gokaganya',
    '⛓' => 'dikeetane',
    '⚗' => 'alembiki',
    '🔬' => 'maekerosekoupo',
    '🔭' => 'thelesekoupo',
    '📡' => 'setshwara satelaete',
    '💉' => 'sirintšhe',
    '💊' => 'pilisi',
    '🚪' => 'lebati',
    '🛏' => 'bolao',
    '🛋' => 'soufa le lebone',
    '🚽' => 'pitsana ya boithomelo',
    '🚿' => 'shawara',
    '🛁' => 'bata',
    '🛒' => 'kolotsana ya go reka',
    '🚬' => 'sekerete',
    '⚰' => 'khofine',
    '⚱' => 'ene ya phitlho',
    '🗿' => 'moai',
    '🏧' => 'letshwao la ATM',
    '🚮' => 'letshwao la moteme wa matlakala',
    '🚰' => 'metsi a a kgonang go tshwarwa',
    '♿' => 'letshwao la setulo sa maotwana',
    '🚹' => 'kamotshana ya banna',
    '🚺' => 'kamotshana ya basadi',
    '🚻' => 'ntlwana ya boithomelo',
    '🚼' => 'letshwao la masea',
    '🚾' => 'tlelosete ya metsi',
    '🛂' => 'taolo ya phasepoto',
    '🛃' => 'dikhasetomo',
    '🛄' => 'tleleime ya dithoto',
    '🛅' => 'dithoto kafa molemeng',
    '⚠' => 'tlhagiso',
    '🚸' => 'bokgabaganyo jwa bana',
    '⛔' => 'ga go tsenwe',
    '🚫' => 'thibetswe',
    '🚳' => 'ga go dibaesekele',
    '🚭' => 'ga go gogwe',
    '🚯' => 'ga go latlhelwe matlakala',
    '🚱' => 'metsi a a sa tshwaregeng',
    '🚷' => 'ga go batsamaya ka dinao',
    '📵' => 'ga go na difouno tsa mobaele',
    '🔞' => 'ga go yo o kwa tlase ga dingwaga tse di lesomerobedi',
    '☢' => 'marang a radio',
    '☣' => 'kotsi mo ditsheding',
    '⬆' => 'motsu wa godimo',
    '↗' => 'motsu wa godimomojeng',
    '➡' => 'motsu wa moja',
    '↘' => 'motsu wa mojatlase',
    '⬇' => 'motsu wa tlase',
    '↙' => 'motsu wa molematlase',
    '⬅' => 'motsu wa molema',
    '↖' => 'motsu wa godimo molemeng',
    '↕' => 'motsu wa tlasegodimo',
    '↔' => 'motsu wa molemamojeng',
    '↩' => 'motsu wa moja o o kobegelang molemeng',
    '↪' => 'motsu wa molema o o kobegelang molemeng',
    '⤴' => 'motsu wa moja o o kobegelang godimo',
    '⤵' => 'motsu wa moja o o kobegelang tlase',
    '🔃' => 'metsu e e tlhamaletseng e e tswang molemeng go ya mojeng',
    '🔄' => 'dikonopo tsa metsu go tswa mojeng go ya molemeng',
    '🔙' => 'motsu WA BOA',
    '🔚' => 'motsu WA BOKHUTLONG',
    '🔛' => 'motsu WA TSHUBA!',
    '🔜' => 'motsu WA BONAKO',
    '🔝' => 'motsu o o kwa GODIMO',
    '🛐' => 'lefelo la kobamelo',
    '⚛' => 'letshwao la athomo',
    '🕉' => 'om',
    '✡' => 'naledi ya ga Dafide',
    '☸' => 'lebili la ga dharma',
    '☯' => 'yin yang',
    '✝' => 'sefapaano sa latine',
    '☦' => 'sefapaano se se tlwaelegileng',
    '☪' => 'naledi le sephatlo sa yone',
    '☮' => 'letshwao la kagiso',
    '🕎' => 'menorah',
    '🔯' => 'naledi e e dintlha di thataro e e marontho',
    '♈' => 'Aries',
    '♉' => 'Taurus',
    '♊' => 'Gemini',
    '♋' => 'Kankere',
    '♌' => 'Leo',
    '♍' => 'Virgo',
    '♎' => 'Libra',
    '♏' => 'Scorpius',
    '♐' => 'Sagittarius',
    '♑' => 'Capricorn',
    '♒' => 'Aquarius',
    '♓' => 'Pisces',
    '⛎' => 'Ophiuchus',
    '🔀' => 'konopo ya fetofetola dipina',
    '🔁' => 'konopo ya poeletso',
    '🔂' => 'konopo ya boeletsa singele',
    '▶' => 'konopo ya tshameka',
    '⏩' => 'konopo ya isa pele ka bonako',
    '⏭' => 'konopo ya pina e e latelang',
    '⏯' => 'konopo ya tshameka kgotsa kgaotsa go sekae',
    '◀' => 'konopo ya boela morago',
    '⏪' => 'konopo ya boela morago ka bonako',
    '⏮' => 'konopo ya pina ya pofelo',
    '🔼' => 'konopo ya godimo',
    '⏫' => 'konopo ya godimo ka bonako',
    '🔽' => 'konopo ya tlase',
    '⏬' => 'konopo ya tlase ka bonako',
    '⏸' => 'konopo ya kgaotsa go sekae',
    '⏹' => 'konopo ya go emisa',
    '⏺' => 'konopo ya rekoto',
    '⏏' => 'konopo ya ntsha',
    '🎦' => 'sinema',
    '🔅' => 'konopo ya fokotsa lesedi',
    '🔆' => 'konopo ya phatsimo',
    '📶' => 'dibara tsa manaka',
    '📳' => 'mokgwa wa thoromo',
    '📴' => 'founo ya mobaele e timile',
    '♀' => 'letshwao la mosadi',
    '♂' => 'letshwao la monna',
    '✖' => 'katiso e e tseneletseng ya x',
    '➕' => 'letswao la tlhakanya le le boima',
    '➖' => 'letshwao la ntsha le le boima',
    '➗' => 'letshwao la arola le le boima',
    '‼' => 'letshwao la kgakgamatso le le gabedi',
    '⁉' => 'letshwao la potso la kgakgamatso',
    '❓' => 'letshwao la potso',
    '❔' => 'letshwao la potso le lesweu',
    '❕' => 'letshwao la kgakgamatso le lesweu',
    '❗' => 'letshwao la kgakgamatso',
    '〰' => 'thaladi e e kobegileng',
    '💱' => 'kananyo ya madi',
    '💲' => 'letshwao la dolara e e boima',
    '⚕' => 'letshwao la tsa bongaka',
    '♻' => 'letshwao la tsosoloso',
    '⚜' => 'fleur-de-lis',
    '🔱' => 'letshwao la teritente',
    '📛' => 'betšhe ya leina',
    '🔰' => 'letshwao la sejapane la mosimolodi',
    '⭕' => 'sekele e kgolo e e boima',
    '✅' => 'letshwao le le boima le lesweu',
    '☑' => 'lebokoso la balote ka tlholo',
    '✔' => 'letshwao le le boima',
    '❌' => 'letshwao la sefapaano',
    '❎' => 'konopo ya letshwao la sefapaano',
    '➰' => 'sediko se se motshopo',
    '➿' => 'sediko se se motshopo se se gabedi',
    '〽' => 'letshwao la phetolo la karolo',
    '✳' => 'naletsana e e metsu e robedi',
    '✴' => 'naledi e e dintlha di robedi',
    '❇' => 'benya',
    '™' => 'letshwao la thekiso',
    '🔠' => 'tlhakakgolo ya tsenyoteng ya selatine',
    '🔡' => 'tlhakannye ya tsenyoteng ya selatine',
    '🔢' => 'dinomoro tsa tsenyoteng',
    '🔣' => 'matshwao a tsenyoteng',
    '🔤' => 'ditlhaka tsa tsenyoteng tsa selatine',
    '🅰' => 'konopo ya A (mofuta wa madi)',
    '🆎' => 'konopo ya AB (mofuta wa madi)',
    '🅱' => 'konopo ya B (mofuta wa madi)',
    '🆑' => 'konopo ya CL',
    '🆒' => 'konopo ya TSIDITSANA',
    '🆓' => 'konopo ya GOLOLA',
    'ℹ' => 'tshedimosetso',
    '🆔' => 'konopo ya ID',
    'Ⓜ' => 'dirilwe sekele ya M',
    '🆕' => 'konopo ya NTŠHWA',
    '🆖' => 'konopo ya NG',
    '🅾' => 'konopo ya O (mofuta wa madi)',
    '🆗' => 'konopo ya SIAME',
    '🅿' => 'konopo ya P',
    '🆘' => 'konopo ya SOS',
    '🆚' => 'konopo ya VS',
    '🈁' => 'konopo ya Sejapane ya "fano"',
    '🈂' => 'konopo ya Sejapane ya "tuediso ya tirelo"',
    '🈷' => 'konopo ya Sejapane ya "madi a kgwedi le kgwedi"',
    '🈶' => 'konopo ya Sejapane ya "ga se mahala"',
    '🈯' => 'konopo ya Sejapane ya "bolokilwe"',
    '🉐' => 'konopo ya Sejapane ya "sesolo"',
    '🈹' => 'konopo ya Sejapane ya "phokoletso"',
    '🈚' => 'konopo ya Sejapane ya "mahala"',
    '🈲' => 'konopo ya Sejapane ya "thibetswe"',
    '🉑' => 'konopo ya sejapane ya "amogetswe"',
    '🈸' => 'konopo ya Sejapane ya "kopo"',
    '🈴' => 'konopo ya sejapane ya "kereite ya phalolo"',
    '🈳' => 'konopo ya Sejapane ya "phatlatiro"',
    '㊗' => 'konopo ya Sejapane ya "re a go lebogisa"',
    '㊙' => 'konopo ya Sejapane ya "sephiri"',
    '🈺' => 'konopo ya Sejapane ya "bulegetse kgwebo"',
    '🈵' => 'konopo ya Sejapane ya "ga go phatlatiro"',
    '🔴' => 'sekele e khibidu',
    '🔵' => 'sekele e pududu',
    '⚫' => 'sekele e ntsho',
    '⚪' => 'sekele e tshweu',
    '⬛' => 'sekwere se segolo se sentsho',
    '⬜' => 'sekwere se segolo se sesweu',
    '◼' => 'sekwere se se mo magareng se sentsho',
    '◻' => 'sekwere se se mo magareng se sesweu',
    '◾' => 'sekwere sa bonnye jo bo magareng jo bontsho',
    '◽' => 'sekwere sa bonnye jo bo magareng jo bosweu',
    '▪' => 'sekwere se sentsho se sennye',
    '▫' => 'sekwere se sesweu se sennye',
    '🔶' => 'teemane e kgolo ya mmala wa lamune',
    '🔷' => 'teemane e kgolo e pududu',
    '🔸' => 'teemane e nnye ya mmala wa lamune',
    '🔹' => 'teemane e nnye e pududu',
    '🔺' => 'khutlotharo e khibidu e lebile kwa godimo',
    '🔻' => 'khutlotharo e khibidu e lebile kwa tlase',
    '💠' => 'teemane ka lerontho',
    '🔘' => 'konopo ya radio',
    '🔳' => 'konopo e tshweu e e sekwere',
    '🔲' => 'konopo e ntsho e e sekwere',
    '🏁' => 'folaga e e ditšheke',
    '🚩' => 'folaga e e dikhutlotharo',
    '🎌' => 'difolaga tse di difapaano',
    '🏴' => 'folaga e ntsho',
    '🏳' => 'folaga e tshweu',
];
